function data = viz_sv(varargin)
%% About viz_sv
%
% 'viz_sv' is a 'MATLAB' function to read and visualise IMOS Bioacoustics
% NetCDF file.
%
% For more information about IMOS Bioacoustics sub-Facility visit:
% https://imos.org.au/facilities/shipsofopportunity/bioacoustic
%
%
%% Syntax
%
%   data_struct = viz_sv
%   viz_sv(data)
%   viz_sv(data,plot_request)
%   viz_sv(___,'all')
%   viz_sv(___,'image',imagefile)
%   viz_sv(___,'imagesize',[width height])
%   viz_sv(___,'title',title)
%   viz_sv(___,'cmap',cmap)
%   viz_sv(___,'range',[min max])
%   viz_sv(___,'location',{start end})
%   viz_sv(___,'channel', channel)
%   viz_sv(___,'multi-channel')
%   viz_sv(___,'depth',[min max])
%   viz_sv(___,'noplot')
%   viz_sv(___,'overlay',data_vector)
%   viz_sv(___,'sun')
%   viz_sv(___,'axis',ticktype)
%   viz_sv(___,'xfactor',xfactor)
%   viz_sv(___,'ypos',ypos)
%   viz_sv(___,'fit')
%   viz_sv(___,'sync',axes)
%   viz_sv(___,'panel',panel)
%   viz_sv(___,'blank',panel)
%
%% Description
%
% The first argument, |data|, may be either a character string or a
% data structure.
% If it is not provided it is treated as an empty character string.
% If |data| is a character string it is used as the filename for a NetCDF
% file to read the data structure from.
%
% *Using a NetCDF file*
%
% |viz_sv| : without arguments will ask you to select a NetCDF file.
% It will then read the NetCDF file into a data structure suitable for
% use for future calls of viz_sv and returns the structure. It also
% displays the standard set of plots (see plot_request '').
%
% |viz_sv(ncfile)| : as above, except that if ncfile exists as a file then
% it is read without asking you. Otherwise ncfile is used as the
% default value for asking you, so passing a directory name will ask
% you for the NetCDF file starting in that directory.
%
% The NetCDF file to be read should have the following properties (IMOS
% BASOOP NetCDF files have these properties):
%
% * Variables: Time, Depth, Latitude, Longitude
% * Time, Latitude and Longitude have the same length
%
%
% *Using a data structure*
%
% The data structure option for viz_sv requires a data structure with the
% following fields (structures returned by viz_sv contain these fields):
%
% * ' |time| ' : a vector
% * ' |depth| ' : a vector
%
% Other fields which may be used if present in ' |data_struct| ' are:
%
% * |longitude| : vector with same size as |time| .
% * |latitude| : vector with same size as |time| .
% * |file| : string (usually containing filename) used in title.
% * |location| : cell array of two strings to label start and end of an
% echogram.
% * |grid_distance| : scalar value containing the distance between cells.
%
% *Plot Requests*
%
% The second argument for viz_sv indicates the data to be plotted. Possible
% values include:
%
% * |[]| : if plot requests is empty produce the set of standard plots for
% the data.
% * |'-'| : do not produce any plots.
% * |array| : array with dimensions |length(depth)| x |length(time)|
% [x |length(channels)|] is plotted as an echogram. The array may be a
% field of the data structure, derived from a field of the data structure,
% or generated by some other means.
% * |vector| : vector with |length(time)| (or array with first dimension
% equal to |length(time)| is plotted as a line (or set of lines).
% * field_name : the name of a field of the data structure will plot the
% named field as above with the field name used as the title (unless
% another title is specified. i.e. |viz_sv(data, 'Sv')| is equivalent to
% |viz_sv(data_struct, data_struct.Sv, 'title', 'Sv')|.
% * plot_name : the name of one of the standard plots
% (plot names start with a ':' to distinguish them from fields):
% ':processed', ':unprocessed', ':good', ':motion', ':nasc', ':map', ':image'.
%
% *Options*
%
% |viz_sv(___,'all')| : returns a data structure with all numeric (float or
% double) fields contained in the NetCDF file. The |'all'| option does
% nothing when the first argument is a data structure. To read all the
% numeric variables from a NetCDF file already read into a data structure
% use:
%
% data_struct = viz_sv(data_struct.file,'-','all');
%
% |viz_sv(___,'image',imagefile)| : creats an echogram of the processed
% data based on the following imagefile argument:
%
% * |[]| : no file is created.
% * |''(empty string)| : a Portable Network Graphic (PNG) file will be
% created with the same name and directory as ncfile.
% * |dir| : if imagefile is a valid directory, PNG file will be created
% with the same name as ncfile in the directory specified.
% * |'-dformat'| : an image of the specified format will be created with the
% same name as ncfile. See MATLAB |print| help page for a list of supported
% formats.
% * |filename| : anything else is treated as the name of the file to write
% an image.
% * |'*?'| : if a '?' is added to the end of the image name the name
% determined as above (without the '?') will be the default name used for
% asking the user to specify the imagename.
%
% |viz_sv(___,'imagesize',[width height])| : defines the width and height
% (in pixels) of echogram created.
%
% |viz_sv(___,'title',title)| : will display the given
% title (along with the file name found in the |data_struct| ). To prevent
% the file name appearing in the title define the title in a cell as
% |viz_sv(data_struct,plot_request,'title',{'nofilename'})|.
%
% |viz_sv(___,'cmap',cmap)| : cmap will be used as the colourmap
% for the raw and processed echograms. cmap may be any MATLAB colormap,
% one of the strings 'ek80', 'ek500', or 'RdBu', or the name of any
% function in your path that returns a colormap.
%
% |viz_sv(___,'range',[min max])| : will set the defined range for the
% colorbar. An empty range ([]) will be replaced by the default Sv range
% [-84, -48]. Specifying range is recommended for displaying backscatter
% data (Sv).
%
% |viz_sv(___,'location',{start end})| : will display the given start and end
% locations on the echogram, replacing the location field of the data
% structure (if any).
%
% |viz_sv(___,'channel',channel)| : identifies which channel of a
% multi-channel (multi-frequency) data set is to be displayed. Channel may
% be either the integer index of the channel (1 for first channel), the
% name of the channel or the frequency of the channel (the first channel
% with that frequency). If the channel can not be identified or there is
% only one channel, the first channel is used.
%
% |viz_sv(___,'multi-channel')| : will display an echogram for each channel
% contained in |plot_request|. Plots produced by the |multi-channel| option
% will be automatically synchronized. Shorter version 'multi' is supported.
%
% |viz_sv(___,'depth',[min max])| : will limit the range for the vertical
% depth axis. An empty range will be replaced by the range covering valid
% (non-NaN) Sv data. A scalar range of 0 will go from 0 to cover the valid
% data. A non-zero scalar range will go from 0 to the value given.
%
% |viz_sv(___,'noplot')| : if the 'noplot' option is specified no plots
% will be produced but an image file will be generated if the |'image'|
% opton is specified. (If the plot request is '-' no plots are produced by
% no images can be generated).
%
% |viz_sv(___,'overlay',data_vector)| : will overlay the data vector on
% the echogram. If the 'multi-channel' option is used and data_vector is an
% array with height equal to the number of channels then the coresponding
% vector will be plotted on each echogram. Better results will usually be
% obtained by plotting the echogram using viz_sv then manually using
% |yyaxis right| and |plot(data_vector)|.
%
% |viz_sv(___,'sun')| : will overlay the state of the sun: Night (high),
% Dusk, Day (low) or Dawn on the raw and processed echograms. Note
% mandatory variable (day) should be present in the NetCDF to work with
% this option.
%
% |viz_sv(___,'axis',ticktype)| : defines X-axis tick labels for echograms
% and associated plots. The ticktype is one of 'time', 'interval',
% 'latitude', 'longitude', 'latitude:minutes', or 'longitude:minutes'.
% Shorter versions are acceptable, e.g.: 'time', 'int', 'lat', 'lon',
% 'latm', 'lonm'.
%
% |viz_sv(___,'xfactor',xfactor)| : xfactor is the fraction of a day or
% degree at which to plot tick marks. For example
% |viz_sv(___,'xfactor',12)| will display ticks every 2 hours in Time or every
% 5 minutes in latitude and longitude.
%
% |viz_sv(___,'ypos',ypos)| : ypos is the number of graph heights from the
% top of the screen to place the plot.
%
% |viz_sv(___,'sync',axes)| : will allow the user to synchronise the X-axes
% of plots to the axes specified (e.g. |gca| of the first plot). The 'Sync
% plot' checkbox must be checked to synchronise the axes.
%
% |viz_sv(___,'panel',panel)| : will place the plot in the given panel
% instead of creating a new figure. Panel may be a uipanel or a figure.
%
% |viz_sv(___,'blank',panel)| : will create an empty axes in the given
% panel with the transect ui controls. You may plot and data you want in
% the axes and the controls will work. For best results the x axis should
% be the length of the time variable.
%
% |viz_sv(___,'fit')| : will fit the entire data to the figure window.
% The default for an echogram is one pixel per cell.
%
% |viz_sv(___,'inf')| : will generate MBSystem style .inf files and
% Echoview style .gps.csv files for the data. The .inf file contains a
% metadata summary and .gps.csv file will have the position information.
% CSV file name and location follow NetCDF file.
%
% |viz_sv(___,'csv',filename)| : will write a .csv file containing time,
% longitude, latitude, sun cycle information, and summary layer metrics to
% the file specified. If the file name is empty then NetCDF file name and
% location will be used. The summary layer metrics are the processed
% backscatter data (Sv) averaged in epipelagic (20-200 m), upper
% mesopelagic (200-400 m), and lower mesopelagic (400-800 m) depth layers.
% Note mandatory variables (day, epipelagic, upper_mesopelagic, and
% lower_mesopelagic) should be present in the NetCDF to work this option.
%
% |viz_sv(___,'sv.csv',filename)| : will generate Echoview style .sv.csv and
% .gps.csv files for the data. A .sv.csv file is written for each channel
% of the requested data. A .gps.csv file will have the
% position information. Channel name and '.sv.csv' is appended to the
% provided filename. If no filename is provided the original NetCDF file
% name is used.
%
%
%% Examples
%
% * To view a standard set of plots implemented, the user can run |viz_sv|
% without arguments. The user will be asked for the NetCDF file to open and
% the standard plots will be displayed. A data structure containing
% selected data variables will be returned.
%
%       viz_sv
%
% * To read selected data variables from a NetCDF file to MATLAB Workspace
% for further analysis and plotting.
%
%       data_struct = viz_sv('','-');
%
% * To display processed backscatter data (Sv) for each channel overlaid
% with corresponding epipelagic layer (20-200 m) backscatter data.
%
%       viz_sv(data_struct,data_struct.Sv,'range',[],'cmap','ek80','multi','overlay',data_struct.epipelagic);
%
% * To view Sv data where 100% of the data was retained at the end of
% post-processing.
%
%       verygood = data_struct.Sv;
%       verygood(data_struct.pg < 100) = NaN;
%       viz_sv(data_struct,verygood,'range',[],'cmap','ek80','title','100% good');
%
% * To compare raw data, processed data and very good data in detail.
%
%       viz_sv(data_struct,data_struct.Svraw,'range',[],'cmap','ek80','title','Raw');
%       sync = gca;
%       viz_sv(data_struct,data_struct.Sv,'range',[],'cmap','ek80','ypos',2,'sync',sync,'title','Processed');
%       Check 'Sync plot'.
%       viz_sv(data_struct,verygood,'range',[],'cmap','ek80','ypos',3,'sync',sync,'title','100% good');
%       Check 'Sync plot'.
%       Press the 'Play' button and watch the data scroll through.
%
% * To view the signal-to-noise-ratio (SNR) with an overlay of the
% background noise level for the whole transect visible in the figure.
%
%       viz_sv(data_struct,'snr','range',[0 40],'cmap','rdbu','overlay','background_noise','fit');
%
% * To generate the same image file from a data structure as is generated
% by |viz_sv(ncfile,'image','','noplots')| option.
%
%       viz_sv(data_struct,data_struct.Sv,'title','Mean {\itS_v} (dB re 1 m^2 m^-^3)',...
%           'range',[],'image',[data_struct.file '.png'],'multi','noplots');
%
% * To plot processed and raw Sv echograms in the same figure:
%
%       fig = figure('Units','normalized', 'Position',[.1 .2 .8 .6]);
%       top = uipanel(fig, 'Position',[0 .5 1 .5]);
%       bottom = uipanel(fig, 'Position',[0 0 1 .5]);
%       viz_sv(data_struct, 'Sv', 'range',[], 'channel',1, 'panel',top);
%       sync_to = gca;
%       viz_sv(data_struct, 'Svraw', 'range',[], 'channel',1, 'panel',bottom, 'sync',sync_to);
%
% * To plot Sv for all channels in the same figure
%
%       n = length(data.channels);
%       fig = figure('Units','normalized', 'Position',[.1 .1 .8 .8]);
%       for i = 1:n
%           panel(i) = uipanel(fig, 'Position', [0 1-i/n 1 1/n]);
%       end
%       viz_sv(data, 'Sv', 'panel',panel, 'range',[]);
% 
%% Author and version
%               Gordon Keith <gordon@keith.id.au>
%               Tim Ryan <tim.ryan@csiro.au>
% Contributor:  Haris Kunnath <haris.kunnath@csiro.au>
%
%               Version: 3.1
%               Date: 2021-04-14

%#ok<*STRIFCND> contains() is recommended but was introduced in R2016b

%% Constants
settings.TIME           = 1;
settings.LAT            = 2;
settings.LONG           = 3;
settings.INTERVAL       = 4;

%% defaults
settings.tickformat     = settings.TIME;
settings.minutes        = false;
settings.xfactor        = 0;
settings.min_sv         = -84;
settings.max_sv         = settings.min_sv + 36;
settings.range          = [];
settings.dpthrange      = [-Inf Inf];

%% options
settings.filename       = '';
settings.chn            = '';
settings.location       = {'' ''};
settings.all_data       = false;
settings.debug          = 0;
settings.channel        = [];
settings.cmap           = [];
settings.csv_file       = '';
settings.svcsv_file     = '';
settings.fit            = false;
settings.imagefile      = [];
settings.imagesize      = [];
settings.inf_file       = false;
settings.overlay        = [];
settings.plotpane       = [];
settings.blank          = false;
settings.blankpanel     = [];
settings.plots          = true;
settings.resolution     = 300;
settings.sun            = false;
settings.sv_csv         = false;
settings.sync_to        = [];
settings.ttle           = '';
settings.write_csv      = false;
settings.ypos           = 1;
settings.tight          = [0.01 0.16 0.01 0]; % [left bottom right top]

%% Predefined NetCDF variable and structure field names

% first column: variable name defined in the NetCDF
% second column: field names of structure (used for plotting)

netvars = { 
    'TIME'                      'time';
    'time'                      'time';
    'time_jul'                  'time';
    'DEPTH'                     'depth';
    'depth'                     'depth';
    'RANGE'                     'depth';
    'LATITUDE'                  'latitude';
    'latitude'                  'latitude';
    'lat'                       'latitude';
    'LONGITUDE'                 'longitude';
    'longitude'                 'longitude';
    'lon'                       'longitude';
    'frequency'                 'frequency';
    'CHANNEL'                   'channels';
    'channel'                   'channels';
    'Sv'                        'sv';
    'Sv_quality_control'        'qc';
    'Sv_pcnt_good'              'pg';
    'Sv_unfilt'                 'svraw';
    'background_noise'          'background_noise';
    'signal_noise'              'snr';
    'motion_correction_factor'  'motion_correction_factor';
    'amplifier_linearity_correction_factor' 'amplifier_linearity_correction_factor';
    'temperature'               'temperature';
    'salinity'                  'salinity';
    'sound_speed'               'soundspeed';
    'absorption'                'soundabsorption';
    'abs_corrected_sv'          'abs_sv';
    'uncorrected_Sv'            'uncorrected_sv';
    'epipelagic'                'epipelagic';
    'upper_mesopelagic'         'upper_mesopelagic';
    'lower_mesopelagic'         'lower_mesopelagic';
    'day'                       'day';
    };
    
oldnetvars = {
    'Sv_%d'                     'sv';
    'Sv_%d_quality_control'     'qc';
    'Sv_pcnt_good_%d'           'pg';
    'Sv_unfilt_%d'              'svraw';
    };

%% Input arguments 
data = [];
ncfile = [];

% first argument (determine data structure or NetCDF file)
if nargin == 0
    ncfile = '';
    
elseif isstruct(varargin{1})
    data = varargin{1};
    
    if isfield(data, 'file')
        fullpath = strsplit(data.file,'\');
        settings.filename = fullpath{end};
    end
    
else
    % first arg is not a struct - it is an ncfile to read and plot
    ncfile = varargin{1};
end

% Second argument is plot request
if nargin < 2
    plotrequest = [];
else
    plotrequest = varargin{2};
end

% read remaining arguments
arg = 2;
while  arg < nargin
    arg = arg + 1;
    if strncmpi('all', varargin{arg},3)
        settings.all_data = true;
    elseif strcmpi('axis', varargin{arg})
        arg = arg+1;
        form = varargin{arg};
        if strncmpi(form, 'lat',3)
            settings.tickformat = settings.LAT;
        elseif strncmpi(form, 'lon',3)
            settings.tickformat = settings.LONG;
        elseif strncmpi(form, 'int',3)
            settings.tickformat = settings.INTERVAL;
        end
        settings.minutes = any(form == 'm') || any(form == 'M');
    elseif strcmpi('blank', varargin{arg})
        arg = arg+1;
        settings.blank = true;
        settings.blankpanel = varargin{arg};
    elseif strncmpi('channel', varargin{arg},2)
        arg = arg+1;
        settings.channel = varargin{arg};
    elseif strncmpi('cmap', varargin{arg},2)
        arg = arg+1;
        settings.cmap = varargin{arg};
    elseif strncmpi('csv', varargin{arg},3)
        settings.write_csv = true;
        if arg < nargin
            arg = arg + 1;
            settings.csv_file = varargin{arg};
        end
    elseif strncmpi('debug', varargin{arg},3)
        if arg < nargin && isnumeric(varargin{arg+1})
            arg = arg + 1;
            settings.debug = varargin{arg};
        else
            settings.debug = 1;
        end
    elseif strncmpi('defaults', varargin{arg},3)
        if arg < nargin
            arg = arg + 1;
            defaults = varargin{arg};
            fnames = fieldnames(defaults);
            for fn = 1:length(fnames)
                settings.(fnames{fn}) = defaults.(fnames{fn});
            end
        end
    elseif strncmpi('depth', varargin{arg},3)
        if arg < nargin && isnumeric(varargin{arg+1})
            arg = arg + 1;
            settings.dpthrange = varargin{arg};
            if isscalar(settings.dpthrange) && settings.dpthrange > 0
                settings.dpthrange = [0 settings.dpthrange];
            end
        else
            settings.dpthrange = [];
        end
    elseif strncmpi('fit', varargin{arg},3)
        settings.fit = true;
    elseif strncmpi('imagesize', varargin{arg},6)
        arg = arg+1;
        settings.imagesize = varargin{arg};
    elseif strncmpi('image', varargin{arg},2)
        if arg < nargin
            arg = arg+1;
            settings.imagefile = varargin{arg};
        else
            settings.imagefile = '';
        end
    elseif strncmpi('inf', varargin{arg},3)
        settings.inf_file = true;
    elseif strncmpi('location', varargin{arg},3)
        arg = arg+1;
        settings.location = varargin{arg};
    elseif strncmpi('multi', varargin{arg},4)
        settings.channel = [];
    elseif strncmpi('noplots', varargin{arg},2)
        settings.plots = false;
    elseif strncmpi('overlay', varargin{arg},2)
        arg = arg+1;
        settings.overlay = varargin{arg};
    elseif strncmpi('panel', varargin{arg},3)
        arg = arg+1;
        settings.plotpane = varargin{arg};
    elseif strncmpi('range', varargin{arg},2)
        if arg < nargin && isnumeric(varargin{arg+1})
            arg = arg+1;
            settings.range = varargin{arg};
        else
            settings.range = [];
        end
        if isempty(settings.range)
            settings.range = [settings.min_sv, settings.max_sv];
        end
    elseif strncmpi('resolution', varargin{arg},3)
        if arg < nargin && isnumeric(varargin{arg+1})
            arg = arg+1;
            settings.resolution = varargin{arg};
        else
            settings.resolution = 300;
        end
    elseif strncmpi('sun', varargin{arg},3)
        settings.sun = true;
    elseif strncmpi('sv.csv', varargin{arg},2)
        settings.sv_csv = true;
        if arg < nargin
            arg = arg + 1;
            settings.svcsv_file = varargin{arg};
        end
    elseif strncmpi('sync', varargin{arg},2)
        arg = arg+1;
        settings.sync_to = varargin{arg};
    elseif strncmpi('title', varargin{arg}, 2)
        arg = arg+1;
        settings.ttle = varargin{arg};
    elseif strncmpi('xfactor', varargin{arg}, 2)
        arg = arg+1;
        settings.xfactor = varargin{arg};
    elseif strncmpi('ypos', varargin{arg}, 1)
        arg = arg+1;
        settings.ypos = varargin{arg};
    else
        warning('VIZ_SV:ARGS', 'Ignored unrecognised argument: %s', varargin{arg})
    end
end

%% Read a NetCDF file and populate 'data' structure

if isempty(data) 
    % Ask user for NetCDF file if not provided
    if exist(ncfile, 'file') ~= 2
        [filename, pathname] = uigetfile(...
            {'*.nc' '*.nc NetCDF file'; '*' 'All files'}, ...
            'Select the NetCDF file', ncfile);
        if isequal(filename,0)
            error('NetCDF filename required');
        end
        ncfile = fullfile(pathname,filename);
    end
    
    if ischar(settings.imagefile) && isempty(settings.imagefile) && isempty(settings.channel)
        settings.imagefile = [ncfile '.png'];         % includes full path to ncfile in imagefile
    end
    
    % Open the NetCDF file
    ncid = netcdf.open(ncfile, 'NC_NOWRITE');
    data.file = ncfile;
    [~, filename, ~] = fileparts(ncfile);
    settings.filename = filename;
    
    ncnumeric = [
        netcdf.getConstant('NC_FLOAT')
        netcdf.getConstant('NC_DOUBLE')
        netcdf.getConstant('NC_SHORT')
        ];
    
    % transit start and end location (global attributes)
    locatn = {'' ''};
    try
        locatn{1} = netcdf.getAtt(ncid, ...
            netcdf.getConstant('NC_GLOBAL'), 'transit_start_locality');
    catch
    end
    try
        locatn{2} = netcdf.getAtt(ncid, ...
            netcdf.getConstant('NC_GLOBAL'), 'transit_end_locality');
    catch
    end
    data.location = locatn;
    
    % horizontal resolution of data (global attribute)
    try
        grid_distance = netcdf.getAtt(ncid, ...
            netcdf.getConstant('NC_GLOBAL'), 'dataset_ping_axis_size');
    catch
        grid_distance = 'unknown';
    end
    data.grid_distance = grid_distance;
            
    % audit trail for modifications to NetCDF (global attribute)
    try
        data.history = netcdf.getAtt(ncid,netcdf.getConstant('NC_GLOBAL'), 'history');
    catch
    end
    
    % read NetCDF variables
    try
        ncvar = netvars(:,1);
        [~,nvars,~,~] = netcdf.inq(ncid);
        for varid = 0:nvars-1
            [varname,xtype,~,~] = netcdf.inqVar(ncid,varid);
            fno = find(strcmp(ncvar, varname));
            if ~isempty(fno)
                fieldname = netvars{fno,2};
                if ~isfield(data, fieldname)
                    data.(fieldname) = getNetcdfVar(ncid,varid);
                    if strcmp(fieldname, 'time')
                        try
                            time_base = netcdf.getAtt(ncid, timeid, 'units');
                            if strncmpi(time_base, 'days since', 10)
                                data.time = data.time + datenum(time_base(12:31));
                            end
                        catch 
                            data.time = data.time + datenum([1950 01 01]);
                        end
                    end
                end
            else
                % support for old format variable names
                for old = 1:size(oldnetvars,1)
                    frq = sscanf(varname, oldnetvars{old,1});
                    if ~isempty(frq) && strcmp(varname, sprintf(oldnetvars{old,1},frq))
                        % handle old format variables
                        if isfield(data, 'frequency')
                            ch = find(data.frequency == frq, 1);
                            if isempty(ch)
                                data.frequency(end+1) = frq;
                                ch = length(data.frequency);
                            end
                        else
                            data.frequency = frq;
                            ch = 1;
                        end
                        olddata = getNetcdfVar(ncid,varid);
                        oldfield = oldnetvars{old,2};
                        if ch == 1
                            data.(oldfield) = olddata;
                        else
                            if ndims(data.(oldfield)) == 2 %#ok<ISMAT>
                                od(ch,:,:) = olddata; %#ok<AGROW>
                                od(1,:,:) = data.(oldfield);
                                data.(oldfield) = od;
                            else
                                data.(oldfield)(ch,:,:) = olddata;
                            end
                        end
                        xtype = 0; % don't read in all_data
                    end
                end
                
                if settings.all_data && any(find(ncnumeric == xtype, 1))
                    if ~isfield(data, varname)
                        data.(varname) = getNetcdfVar(ncid,varid);
                    end
                end
                
            end
        end
        
    catch exception
        warning('VIZ_SV:BAD_READ', [ 'Unable to read NetCDF: ' exception.message ])
    end
    
    
    % frequency information
    if ~isfield(data, 'frequency')
        try
            data.frequency = netcdf.getAtt(ncid,netcdf.getConstant('NC_GLOBAL'), 'frequency');
        catch
            if isfield(data, 'sv') && ndims(data.sv) == 3
                data.frequency = zeros(size(data.sv,3),1);
            else
                data.frequency = 38;
            end
        end
    end
    
    % channel information
    if isfield(data, 'channels')
        if isnumeric(data.channels)
            channels = num2str(data.channels);
        else
            channels = data.channels';
        end
        data.channels = {};
        for c = size(channels,1):-1:1
            ch = channels(c,:);
            ch(ch == 0) = [];
            data.channels{c} = strtrim(ch);
        end
    else
        try
            data.channels = {netcdf.getAtt(ncid,netcdf.getConstant('NC_GLOBAL'), 'channel')};
        catch
            data.channels = cellstr(num2str(data.frequency));
        end
    end
    
    % close the NetCDF file
    netcdf.close(ncid);
    
    % Convert dimensions from netcdf order to matlab order
    if isfield(data, 'sv') && ndims(data.sv) == 3
        fields = fieldnames(data);
        for f = 1:length(fields)
            if size(data.(fields{f}),1) == length(data.channels) && size(data.(fields{f}),2) ~= 1
                data.(fields{f}) = shiftdim(data.(fields{f}),1);
            end
        end
    end
    
    % calculate data fields from netCDF values. 
    nrange = (data.depth(end) - data.depth(1)) * (1 + 1/(length(data.depth)-1));
    
    if isfield(data, 'sv')
        if isfield(data, 'qc')
            data.sv(data.qc > 2) = NaN;
        end
        % data.Sv is in dB, data.sv is linear
        % determine which one we have and calculate the other
        if any(data.sv < 0, 'all')      
            data.Sv = data.sv;
            data.sv = 10.^(data.Sv/10);
        else
            data.sv(data.sv == 0) = NaN;
            data.Sv = 10 * log10(data.sv);
        end
        data.sv(data.Sv < -998) = NaN;
        data.Sv(data.Sv < -998) = NaN;
        data.mean_Sv = 10*log10(shiftdim(nmean(data.sv),1));
        data.NASC = 4*pi*1852*1852*10.^(data.mean_Sv./10)*nrange;
    end
    if isfield(data, 'svraw')
        data.svraw(data.svraw == 0) = NaN;
        if any(data.svraw < 0, 'all')   % Svraw is already in dB
            data.Svraw = data.svraw;
            data.svraw = 10.^(data.Svraw/10);
        else
            data.Svraw = 10 * log10(data.svraw);
        end
        data.mean_Svraw = 10*log10(shiftdim(nmean(data.svraw),1));
        data.NASCraw = 4*pi*1852*1852*10.^(data.mean_Svraw./10)*nrange;
    end
    if isfield(data, 'abs_sv')
        data.abs_Sv = 10 * log10(data.abs_sv);
    end
    if isfield(data, 'uncorrected_sv')
        if isfield(data, 'qc')
            data.uncorrected_sv(data.qc > 2) = NaN;
        end
        data.uncorrected_Sv = 10 * log10(data.uncorrected_sv);
    end
end

%% data is now a populated structure either from input or reading NetCDF

if ~isfield(data, 'latitude')
    data.latitude = NaN(size(data.time));
end
if ~isfield(data, 'longitude')
    data.longitude = NaN(size(data.time));
end

% transit start and end location
if isempty(settings.location{1}) && isempty(settings.location{2})
    if isfield(data, 'location')
        settings.location = data.location;
    end
else
    data.location = settings.location;
end

if isfield(data, 'grid_distance')
    grid_distance = data.grid_distance;
else
    grid_distance = '1 km';
end

if height(grid_distance) > 1
   grid_distance = grid_distance'; 
end

settings.XLABELS = {'Time (UTC)', 'Latitude', 'Longitude', ['Distance (' grid_distance ')'] };

tlength = length(data.time);
dlength = length(data.depth);
depth = data.depth;

%% Parse plot request

stdplot = [];
allstd = isempty(plotrequest);
if ischar(plotrequest)
    colon = find(plotrequest == ':',1);
    if ~isempty(colon)
        stdplot = plotrequest(colon:end);
        plotrequest = plotrequest(1:colon-1);
        allstd = allstd || length(stdplot) == 1;
    end
    if isfield(data, plotrequest)
        plotdata = data.(plotrequest);
        if isempty(settings.ttle)
            settings.ttle = strrep(plotrequest, '_', '\_');
        end
    else
        plotdata = [];
        if ~isempty(plotrequest) && ~strcmp(plotrequest, '-')
            warning('Plot request ''%s'' not recognised', plotrequest);
        end
    end
else
    plotdata = plotrequest;
end

if ischar(settings.overlay) && isfield(data, settings.overlay)
    settings.overlay = data.(settings.overlay);
end


%% Parse channel

channel = settings.channel;
if isempty(channel)                                             
    % no channel specified use all channels
    if isfield(data, 'channels')
        channel = 1:length(data.channels);
    end
else
    if ischar(channel) && isfield(data, 'channels')
        % e.g. '38kHz'
        channel=strtrim(channel);
        chf = find(strcmpi(channel, data.channels),1);
        if ~isempty(chf)
            channel = chf;
        end
    end
    if ischar(channel)
        % e.g. '1', '1 2', '18 38'
        channel = str2num(channel); %#ok<ST2NM>
    end
    
    if iscell(channel) && isfield(data, 'channels')
        % e.g. {'18kHz' '38kHz'}
        chf(length(channel)) = 0;
        for c = length(channel):-1:1
            fnd = find(strcmpi(channel{c}, data.channels),1);
            if isempty(fnd)
                chf(c) = [];
            else
                chf(c)= fnd;
            end
        end
        channel = chf;
    end
    
    if ~isnumeric(channel) 
        % failed to interpret channel
        channel = [];
    end
    if isfield(data, 'channels') && isfield(data, 'frequency') && max(channel) > length(data.channels)
        % e.g. [18 38]
        chf = [];
        for c = length(channel):-1:1
            fnd = find(channel(c) == data.frequency,1);
            if isempty(fnd)
                chf = [chf channel(c)];  %#ok<AGROW>
            else
                chf = [chf fnd]; %#ok<AGROW>
            end
        end
        channel = chf;
    end
    
    % remove invalid channels
    if isfield(data, 'channels')
        channel(channel > length(data.channels)) = [];
    end
    channel(isnan(channel)) = [];
    channel = floor(channel);
    channel(channel < 1) = [];
    if isempty(channel)
        warning('VIZ_SV:CHAN1', 'Using channel 1')
        channel = 1;
    end
end

% determine range of valid data, if requested
drange = settings.dpthrange;
if length(drange) < 2
    if drange > 0
        drange = [0 drange];
    else
        if isfield(data, 'Sv')
            dptdata = data.Sv(:,:,channel(1));
        else
            dptdata = plotdata;
        end
        hasdata = any(isfinite(dptdata),2);
        if isempty(drange)
            drange(1) = depth(find(hasdata,1, 'first'));
        end
        drange(2) = depth(find(hasdata,1, 'last'));
        if isempty(drange)
            error('No valid data to plot');
        end
    end
end

% trim data to selected depth range
select = true(size(depth));
if drange(end) < depth(end) || drange(1) > depth(1)
    select = depth >= drange(1) & depth <= drange(end);
    settings.use_depth = depth(select) + (depth(2) - depth(1))/2;
else
    settings.use_depth = depth + (depth(2) - depth(1))/2;
end

%% plot requested data (see plot requests on help page)
if settings.plots && ~isempty(plotdata)
    if size(plotdata,1) == dlength && size(plotdata,2) == tlength
        if size(plotdata,3) == 1
            channl = 1;     % if plotdata doesn't have channel only use 1
            haschan = false;
        else
            channl = channel;
            haschan = true;
        end
        for c = 1:length(channl)
            ch = channl(c);
            pltdata = plotdata(select,:,ch);
            if isfield(data, 'channels')
                if size(settings.overlay,2) == size(plotdata,3)
                    ovrlay = settings.overlay(:,ch);
                else
                    ovrlay = settings.overlay;
                end
                if haschan && isfield(data, 'channels')
                    chn = data.channels{ch};
                else
                    chn = '';
                end
                if iscell(settings.ttle)
                    ttl = settings.ttle;
                else
                    ttl = { [strrep(settings.filename,'_','\_') ' ' chn];  settings.ttle };
                end
                if ~isempty(settings.plotpane) && c <= length(settings.plotpane)
                    eax = echogram(data, settings, pltdata, settings.plotpane(c), ...
                        ttl, settings.range, settings.cmap, ovrlay);
                else
                    eax = echogram(data, settings, pltdata, settings.ypos+c-1, ...
                        ttl, settings.range, settings.cmap, ovrlay);
                end
                if isempty(settings.sync_to);   settings.sync_to = eax;     end
                
                if settings.sun && isfield(data, 'day')
                    if verLessThan('matlab', '9.1') || settings.debug
                        hold(eax, 'on')
                        ud = settings.use_depth;
                        dscale = 2*ud(1) - ud(2) + (ud(end) - ud(1)) / 5;
                        plot(eax, dscale * data.day, 'r', 'LineWidth',1);
                    else
                        yyaxis(eax, 'right')
                        plot(eax, data.day, 'r', 'LineWidth',1);
                        ylabel(eax, 'Diurnal sun cycle')
                        ylim(eax, [0 5])
                        set(eax, 'YTick', 1:4)
                        set(eax, 'YTickLabel', {'Day' 'Dusk' 'Dawn' 'Night'});
                        yyaxis(eax, 'left');
                        set(eax, 'Units', 'Pixels')
                        epos = get(eax, 'Position');
                        epos(3) = epos(3) - 10 * get(eax, 'FontSize');
                        set(eax, 'Position', epos);
                    end
                end
            end
        end
        
    elseif size(plotdata,1) == tlength
        if isempty(settings.plotpane)
            plotpane = figure('Units', 'normalized', 'Position', [.1 .5 .8 .3]);
        else
            plotpane = settings.plotpane;
        end
        plax = transect_viewer(plotpane, data, settings);
        if isempty(settings.sync_to);   settings.sync_to = plax;     end
        if isfield(data, 'channels') && length(data.channels) == size(plotdata,2)
            plot(plax, plotdata(:,channel))
        else
            plot(plax, plotdata)
        end
        xlim(plax, [1 tlength])
        xlabel(plax, settings.XLABELS{settings.tickformat});
        if ~isempty(settings.ttle)
            title(plax, settings.ttle)
        end
        ticks(plotpane, plax, data, settings)
    else
        error('Data array size (%d x %d) does not match axes size (%d x %d)', ...
            size(plotdata,1), size(plotdata,2), dlength, tlength);
    end
end

% create image file of echogram of requested data (vector not supported)
if ischar(settings.imagefile) && ~isempty(plotdata) && isempty(strfind(stdplot, ':im')) %#ok<*STREMP>
    if size(plotdata,1) == length(settings.use_depth) && size(plotdata,2) == tlength
        wfig = [];
        if size(plotdata,3) == 1
            channl = 1;     % if plotdata doesn't have channel only use 1
            haschan = false;
        else
            channl = channel;
            haschan = true;
        end
        for ch = channl
            pltdata = plotdata(select,:,ch);
            if haschan && isfield(data, 'channels')
                chn = data.channels{ch};
            else
                chn = '';
            end
            if ch == channel(end)
                write_echogram(data, settings, pltdata, [settings.imagefile '+'],chn, settings.ttle, wfig);
            else
                wfig = write_echogram(data, settings, pltdata, '-', chn, settings.ttle, wfig, settings.imagesize);
            end
        end
    else % only echograms supported for 'image' option.
        error('Data array size (%d x %d) does not match axes size (%d x %d)', ...
            size(plotdata,1), size(plotdata,2), dlength, tlength);
    end
end

% create an empty axes in the given panel with the transect ui controls
if settings.blank
    tv = transect_viewer(settings.blankpanel, data, settings);
    if isempty(settings.sync_to);   settings.sync_to = tv;     end
end

% write a .csv file containing time, longitude, latitude, sun cycle
% information, and summary layer metrics
if settings.write_csv
    csv(data, settings.csv_file)
end

% generate MBSystem style .inf files and Echoview style .gps.csv files for
% the data
if settings.inf_file
    info(data);
end

% generate Echoview style .sv.csv and .gps.csv files for the requested data
if settings.sv_csv
    svcsv(data, plotdata, settings.svcsv_file);
end


%% hard coded standard plots
if ~(allstd || ischar(stdplot))
    return
end

% Display standard set of plots implemented
imagefig = [];
if isempty(settings.range)
    settings.range = [settings.min_sv settings.max_sv];
end

for c = 1: length(channel)
    chann = channel(c);
    
    % determine range of valid data, if requested
    drange = settings.dpthrange;
    if length(drange) < 2
        if isfield(data, 'Sv')
            hasdata = any(isfinite(data.Sv(:,:,chann)),2);
            if isempty(drange)
                drange(1) = depth(find(hasdata,1, 'first'));
            end
            drange(2) = depth(find(hasdata,1, 'last'));
        else
            drange = [depth(1) depth(end)];
        end
        if isempty(drange)
            warning('No valid data to plot for channel %d', chann);
            continue
        end
    end
    
    cselect = depth >= drange(1) & depth <= drange(end);
    settings.use_depth = depth(cselect) + (depth(2) - depth(1))/2; % display depth of bottom of cell
        
    % -----------------------------------------------
    
    % If 'image' argument was given write Sv image to file
    if ((allstd && ischar(settings.imagefile)) || any(strfind(stdplot, ':im'))) && isfield(data, 'Sv')
        Sv = data.Sv(cselect,:,chann);
        
        imagefile = settings.imagefile;
        if isempty(imagefile)
            imagefile = [data.file '.png'];
        end
        tle = 'Mean {\itS_v} (dB re 1 m^2 m^-^3)';
        if c == length(channel)
            write_echogram(data, settings, Sv, imagefile, data.channels{chann}, tle, ...
                imagefig);
        else
            imagefig = write_echogram(data, settings, Sv, '-', data.channels{chann}, tle, ...
                imagefig);
        end
    end
    
    % Skip to next channel if no plots are wanted.
    if ~settings.plots
        continue
    end
    
    % plot 'processed', 'unprocessed' Sv data, and percentage of Sv retained (%)
    
    % add space to channel name between frequency and kHz
    chan_name = data.channels{chann};
    idx = regexp(chan_name, '[0-9]k');
    if isscalar(idx)
        chan_name = [chan_name(1:idx) ' ' chan_name(idx+1:end) ':'];
    end
    
    % plot processed Sv
    if (allstd || any(strfind(stdplot, ':proc'))) && isfield(data, 'Sv')
        Sv = data.Sv(cselect,:,chann);
        eax = echogram(data, settings, Sv, 2, ...
            strcat(chan_name,' processed mean {\itS_v} (dB re 1 m^2 m^-^3)'), ...
            settings.range, settings.cmap, settings.overlay);
        if isempty(settings.sync_to);   settings.sync_to = eax;     end
    end
    
    % plot unprocessed Sv
    if (allstd || any(strfind(stdplot, ':raw'))) && isfield(data, 'Svraw')
        Svraw = data.Svraw(cselect,:,chann);
        eax = echogram(data, settings, Svraw, 1, ...
            strcat(chan_name,' unprocessed mean {\itS_v} (dB re 1 m^2 m^-^3)'), ...
            settings.range, settings.cmap, settings.overlay);
        if isempty(settings.sync_to);   settings.sync_to = eax;     end
    end

    % plot percentage of Sv retained
    if (allstd || any(strfind(stdplot, ':good'))) && isfield(data, 'pg')
        pg = data.pg(cselect,:,chann);
        eax = echogram(data, settings, pg, 3, ...
            strcat(chan_name,' percentage of {\itS_v} retained (%)'), ...
            [0 100], Hmap);
        if isempty(settings.sync_to);   settings.sync_to = eax;     end
    end
    
    % plot signal-to-noise ratio
    if (allstd || any(strfind(stdplot, ':signal'))) && isfield(data, 'snr')
        snr = data.snr(cselect,:,chann);
        eax = echogram(data, settings, snr, 4, ...
            strcat(chan_name,' signal-to-noise-ratio (dB re 1)'), ...
            [0 40], Hmap);
        if isempty(settings.sync_to);   settings.sync_to = eax;     end
    end
    
    % plot motion correction factor
    if any(strfind(stdplot, ':mcf')) && isfield(data, 'motion_correction_factor')
        mot = data.motion_correction_factor(cselect,:,chann);
        eax = echogram(data, settings, mot, 1.5, ...
            strcat(chan_name,' motion correction factor (%)'), ...
            [0 30], Hmap); 
        if isempty(settings.sync_to);   settings.sync_to = eax;     end
    end
    
    % plot amplifier linearity correction factor
    if any(strfind(stdplot, ':alcf')) && isfield(data, 'amplifier_linearity_correction_factor')
        mot = data.amplifier_linearity_correction_factor(cselect,:,chann);
        eax = echogram(data, settings, mot, 2.5, ...
            strcat(chan_name,' amplifier linearity correction factor (%)'), ...
            [10 30], Hmap); 
        if isempty(settings.sync_to);   settings.sync_to = eax;     end
    end
end

% standard plots not per channel
if settings.plots
    p=get(0,'ScreenSize'); 
    settings.use_depth = depth(select) + (depth(2) - depth(1))/2; 

    % plot echointegration NASC values
    if (allstd || any(strfind(stdplot, ':nasc'))) && isfield(data, 'NASC')
        
        nfig = figure;
        set(nfig, 'color', 'w')
        if length(channel) == 1
            set(nfig,'Position',[50 50 p(3)*0.75 p(4)*0.25])
        else
            set(nfig,'Position',[50 50 p(3)*0.75 p(4)*0.60])
        end
        nchannels = length(channel);
        nrange = (data.depth(end) - data.depth(1)) * (1 + 1/(length(data.depth)-1));
        sax(nchannels) = gca; % preallocate space.
        
        for n = 1: nchannels
            chann_n = channel(n);
            subpane = uipanel(nfig, 'Position', [0 (nchannels - n)/nchannels 1 1/nchannels]);
            set(subpane, 'BackgroundColor', 'w')
            % create axes with controls in subpane
            subax = transect_viewer(subpane, data, settings);
            if isempty(settings.sync_to);   settings.sync_to = subax;     end
            sax(n) = subax;
            hold(subax, 'on')
            grid(subax, 'on')
            box(subax, 'on')
            if isfield(data, 'NASCraw')
                plot(subax, data.NASCraw(:,chann_n), 'Color',[.65 .65 .65], 'LineWidth',1);
            end
            plot(subax, data.NASC(:,chann_n), 'Color',[162 20 47]./255, 'LineWidth',1);
            if n == nchannels && isfield(data, 'NASCraw')   % keep legend for last panel only
                legend(subax, 'Raw NASC', 'Processed NASC', 'Orientation','horizontal', 'Location','best');
            end
            xlabel(subax, settings.XLABELS{settings.tickformat})
            ylabel({'NASC'; '(m^2 nmi^-^2)'});
            
            chan_name = data.channels{chann_n};
            idx = regexp(chan_name, '[0-9]k');
            if isscalar(idx)
                chan_name = [chan_name(1:idx) ' ' chan_name(idx+1:end) ':'];
            end
            title(subax,sprintf('%s NASC ({\\its_v} integrated between 0%g m)', chan_name, nrange))
            xlim(subax, [1 tlength]);
            if max(data.NASC(:,chann_n)) > 0
                ylim(subax,[0, max(data.NASC(:,chann_n))]);
            end
            set(subax, 'TickDir', 'out')
            set(subax, 'TickLength', [0.002 0.001])
            if n == 1
                ptight = get(subax, 'TightInset');
            else
                pptight = get(subax, 'TightInset');
                ptight = max([pptight ; ptight], [], 1);
            end
        end
        ptight = ptight + settings.tight;
        for n = 1: nchannels
            set(sax(n), 'Position', [ptight(1) ptight(2) 1-(ptight(1)+ptight(3)) 1-(ptight(2)+ptight(4))])
            set(sax(n), 'LooseInset', ptight);
            ticks(subpane, sax(n), data, settings)
        end
    end
    
    % plot background noise per interval
    if (allstd || any(strfind(stdplot, ':back'))) && isfield(data, 'background_noise')
        bfig = figure;
        set(bfig, 'color', 'w')
        set(bfig, 'Position',[50 50 p(3)*0.75 p(4)*0.25])
        % create axes with controls
        bkax = transect_viewer(bfig, data, settings);
        if isempty(settings.sync_to);   settings.sync_to = bkax;     end
        plot(bkax, data.background_noise(:,channel),'.','MarkerSize',10);
        xlim(bkax, [1 tlength]);
        title(bkax, 'Background noise level', 'Interpreter', 'none')
        ylabel(bkax, {'Background noise';'dB re 1 W'})
        xlabel(bkax, settings.XLABELS{settings.tickformat})
        legend(bkax, data.channels(channel),'Orientation','horizontal','Location','best')
        grid(bkax, 'on')
        set(bkax, 'TickDir', 'out')
        set(bkax, 'TickLength', [0.001 0.002])
        btight = get(bkax, 'TightInset');
        btight = btight + settings.tight;
        set(bkax, 'Position', [btight(1) btight(2) 1-(btight(1)+btight(3)) 1-(btight(2)+btight(4))])
        set(bkax, 'LooseInset', btight);
        
        % draw ticks on plot
        ticks(bfig, bkax, data, settings);
    end
    
    % plot summary layer metrics
    if (allstd || any(strfind(stdplot, ':sum'))) && isfield(data, 'lower_mesopelagic')
        
        sfig = figure;
        set(sfig, 'color', 'w')
        set(sfig,'Position',[50 50 p(3)*0.75 p(4)*0.6])
        
        % epipelagic layer (20-200 m)
        epi_pane = uipanel(sfig, 'Position', [0 2/3 1 1/3]);
        set(epi_pane, 'BackgroundColor', 'w')
        epi_ax = transect_viewer(epi_pane, data, settings);
        if isempty(settings.sync_to);   settings.sync_to = epi_ax;     end
        pwidth = tlength;
        if verLessThan('matlab', '9.1') || settings.debug
            % yyaxis only available from version 9.1, R2016b
            if isfield(data, 'day')
                axs = plotyy(epi_ax, 1:pwidth, data.epipelagic(:,channel), 1:pwidth, data.day); %#ok<PLOTYY>
                xlim(axs(1), [1 pwidth])
                xlim(axs(2), [1 pwidth])
                ylabel(axs(2), 'Diurnal sun cycle')
                ylim(axs(2), [0 5]);
                set(axs(2), 'YTick', 1:4)
                set(axs(2), 'YTickLabel', {'Day' 'Dusk' 'Dawn' 'Night'});
            else
                plot(epi_ax, data.epipelagic(:,channel),'LineWidth',1)
                xlim(epi_ax, [1 pwidth])
            end
        else
            plot(epi_ax, data.epipelagic(:,channel),'LineWidth',1)
            xlim(epi_ax, [1 pwidth])
            if isfield(data, 'day')
                yyaxis(epi_ax, 'right')
                plot(epi_ax, data.day,'LineWidth',1);
                ylabel(epi_ax, 'Diurnal sun cycle')
                ylim(epi_ax, [0 5])
                set(epi_ax, 'YTick', 1:4)
                set(epi_ax, 'YTickLabel', {'Day' 'Dusk' 'Dawn' 'Night'});
                yyaxis(epi_ax, 'left');
            end
        end
        
        ylabel(epi_ax, {'Mean {\itS_v}'; '(dB re 1 m^2 m^-^3)'})
        xlabel(epi_ax, settings.XLABELS{settings.tickformat})
        title(epi_ax, 'Epipelagic layer (20-200 m)')
        set(epi_ax, 'TickDir', 'out')
        set(epi_ax, 'TickLength', [0.002 0.001])
        hold(epi_ax, 'on')
        grid(epi_ax,  'on');
        
        % upper mesopelagic layer (200-400 m)
        meso_pane = uipanel(sfig, 'Position', [0 1/3 1 1/3]);
        set(meso_pane, 'BackgroundColor', 'w')
        meso_ax = transect_viewer(meso_pane, data, settings);
        plot(meso_ax, data.upper_mesopelagic(:,channel),'LineWidth',1)
        xlim(meso_ax, [1 tlength])
        xlabel(meso_ax, settings.XLABELS{settings.tickformat})
        ylabel(meso_ax, {'Mean {\itS_v}'; '(dB re 1 m^2 m^-^3)'})
        title(meso_ax, 'Upper mesopelagic layer (200-400 m)')
        grid(meso_ax, 'on')
        set(meso_ax, 'TickDir', 'out')
        set(meso_ax, 'TickLength', [0.002 0.001])
        
        % lower mesopelagic layer (400-800 m)
        low_pane = uipanel(sfig, 'Position', [0 0 1 1/3]);
        set(low_pane, 'BackgroundColor', 'w')
        low_ax = transect_viewer(low_pane, data, settings);
        plot(low_ax, data.lower_mesopelagic(:,channel),'LineWidth',1)
        xlim(low_ax, [1 tlength])
        legend(low_ax, data.channels(channel),'Orientation','horizontal','Location','best')
        xlabel(low_ax, settings.XLABELS{settings.tickformat})
        ylabel(low_ax, {'Mean {\itS_v}'; '(dB re 1 m^2 m^-^3)'})
        title(low_ax, 'Lower mesopelagic layer (400-800 m)')
        grid(low_ax,  'on')
        set(low_ax, 'TickDir', 'out')
        set(low_ax, 'TickLength', [0.002 0.001])
        
        % optimise and match fit (tight inset)
        sltight = max([get(epi_ax, 'TightInset');get(epi_ax, 'TightInset');get(epi_ax, 'TightInset')],[],1);
        sltight = sltight + settings.tight;
        set(epi_ax,  'Position', [sltight(1) sltight(2) 1-(sltight(1)+sltight(3)) 1-(sltight(2)+sltight(4))])
        set(meso_ax, 'Position', [sltight(1) sltight(2) 1-(sltight(1)+sltight(3)) 1-(sltight(2)+sltight(4))])
        set(low_ax,  'Position', [sltight(1) sltight(2) 1-(sltight(1)+sltight(3)) 1-(sltight(2)+sltight(4))])
        
        % draw ticks
        ticks(epi_pane, epi_ax, data, settings);
        ticks(meso_pane, meso_ax, data, settings);
        ticks(low_pane, low_ax, data, settings);
    end
    
    % plot motion correction factor, box plot or line plot
    if (allstd || any(strfind(stdplot, ':mot'))) && isfield(data, 'motion_correction_factor')
        bpfig = figure;
        set(bpfig, 'color', 'w')
        if length(channel) == 1
            set(bpfig,'Position',[p(3)/3 p(4)/3 p(3)*0.22 p(4)*0.4])
        else
            set(bpfig,'Position',[p(3)/3 p(4)/3 p(3)*0.4 p(4)*0.5])
        end
        
        for m = 1: length(channel)
            chann_m = channel(m);
            motax = subplot(1,length(channel),m);
            mot = data.motion_correction_factor(select,:,chann_m);
            
            if ~verLessThan('matlab', '9.8') && ~settings.debug % boxchart introduced in R2020a
                [mot, yts] = flatten(mot', settings);
                boxchart(mot,'MarkerStyle','+','MarkerColor','#D95319','orientation','horizontal');
                set(motax, 'YTickLabel', yts(get(motax, 'YTick')));
            elseif license('test','statistics_toolbox') && settings.debug < 2 % try box plot
                factors = [1 2 5 10 20 50 100 200 500 1000];
                rang = settings.use_depth(end) - settings.use_depth(1);
                bin = factors(find(rang ./ factors < 20, 1));
                depth_bin = ceil(settings.use_depth ./ bin) * bin;
                boxplot(motax, mot', depth_bin, 'orientation','horizontal');
                yts = depth_bin(1) : 100 : depth_bin(end);
                set(motax, 'YTickLabel', yts(get(motax, 'YTick')));
            else
                % if box plot is not available
                warning('No box plot for motion correction factor')
                plot(mot, settings.use_depth);
            end
            
            xlabel(motax, 'Correction (%)')
            if m == 1
                ylabel(motax,'Depth (m)')
            end
            
            chan_name = data.channels{chann_m};
            idx = regexp(chan_name, '[0-9]k');
            if isscalar(idx)
                chan_name = [chan_name(1:idx) ' ' chan_name(idx+1:end) ':'];
            end
            title(motax, {chan_name; 'Motion correction factor'})
            set(motax,'YDir','reverse')
            set(motax,'xlim',[0 100])
            hold(motax, 'on');
            box(motax, 'on');
            grid(motax, 'on');
        end
    end
    
    % plot amplifier linearity correction factor, box plot or line plot
    if (allstd || any(strfind(stdplot, ':alcf'))) && isfield(data, 'amplifier_linearity_correction_factor')
        bpfig = figure;
        set(bpfig, 'color', 'w')
        if length(channel) == 1
            set(bpfig,'Position',[p(3)/3 p(4)/3 p(3)*0.22 p(4)*0.4])
        else
            set(bpfig,'Position',[p(3)/3 p(4)/3 p(3)*0.4 p(4)*0.5])
        end
        
        for m = 1: length(channel)
            chann_m = channel(m);
            ampax = subplot(1,length(channel),m);
            amp = data.amplifier_linearity_correction_factor(select,:,chann_m);
            
            if ~verLessThan('matlab', '9.8') && ~settings.debug % boxchart introduced in R2020a
                [amp, yts] = flatten(amp', settings);
                boxchart(amp,'MarkerStyle','+','MarkerColor','#D95319','orientation','horizontal');
                set(ampax, 'YTickLabel', yts(get(ampax, 'YTick')));
            elseif license('test','statistics_toolbox') && settings.debug < 2 % try box plot
                factors = [1 2 5 10 20 50 100 200 500 1000];
                rang = settings.use_depth(end) - settings.use_depth(1);
                bin = factors(find(rang ./ factors < 20, 1));
                depth_bin = ceil(settings.use_depth ./ bin) * bin;
                boxplot(ampax, amp', depth_bin, 'orientation','horizontal');
                yts = depth_bin(1) : 100 : depth_bin(end);
                set(ampax, 'YTickLabel', yts(get(ampax, 'YTick')));
            else
                plot(amp, settings.use_depth);
            end
            xlabel(ampax, 'Correction (%)')
            if m == 1
                ylabel(ampax,'Depth (m)')
            end
            
            chan_name = data.channels{chann_m};
            idx = regexp(chan_name, '[0-9]k');
            if isscalar(idx)
                chan_name = [chan_name(1:idx) ' ' chan_name(idx+1:end) ':'];
            end
            title(ampax, {chan_name; 'Amplifier linearity correction factor'})
            set(ampax, 'YDir','reverse')
            set(ampax,'xlim',[0 50])
            hold(ampax, 'on');
            box(ampax, 'on');
            grid(ampax, 'on');
        end
    end
    
    % plot voyage track
    if (allstd || any(strfind(stdplot, ':map'))) && isfield(data, 'latitude') && any(data.latitude)
        tfig = figure; % plot voyage track on globe
        set(tfig, 'color', 'w')
        
        % deal with 180 degree crossover
        if any(data.longitude < 170) && any(data.longitude > 170)
            lngitude = double(mod(data.longitude, 360));
        else
            lngitude = double(data.longitude);
        end
        latitude = double(data.latitude);
        
        if verLessThan('matlab', '9.5') || any(strfind(stdplot, ':maps')) % geoplot introduced in R2018b
            set(tfig,'Position',[p(3)/3 p(4)/3 p(3)*0.54 p(4)*0.5])
            
            % globe without using mapping toolbox
            % source: https://au.mathworks.com/matlabcentral/answers/350195
            R = 6371; % earth radius in km
            latspacing = 10;
            lonspacing = 20;
            
            % lines of longitude:
            [lon1,lat1] = meshgrid(-180:lonspacing:180,linspace(-90,90,300));
            [x1,y1,z1] = sph2cart(lon1*pi/180,lat1*pi/180,R);
            
            tax = subplot(1,2,1);
            plot3(tax, x1,y1,z1,'-','color',[0.9 0.9 0.9])
            hold(tax, 'on')
            
            % lines of latitude:
            [lat2,lon2] = meshgrid(-90:latspacing:90,linspace(-180,180,300));
            [x2,y2,z2] = sph2cart(lon2*pi/180,lat2*pi/180,R);
            plot3(tax, x2,y2,z2,'-','color',[0.9 0.9 0.9])
            axis(tax, 'equal', 'tight', 'off')
            
            [X,Y,Z] = sphere(100);
            surf(tax, X*R*.99,Y*R*.99,Z*R*.99,'facecolor','w','edgecolor','none')
            
            % Coastline data is predefined to avoid dependency
            [coastlat,coastlon] = coastline();
            
            [xtmp,ytmp,ztmp] = sph2cart(deg2rad(coastlon),deg2rad(coastlat),R);
            plot3(tax, xtmp,ytmp,ztmp,'Color',[0 0.447 0.741], 'linewidth',0.85)% plot coastline
            
            [xtmpn,ytmpn,ztmpn] = sph2cart(deg2rad(lngitude),deg2rad(latitude),R);
            plot3(tax, xtmpn, ytmpn, ztmpn, 'r', 'MarkerSize',4)% plot voyage track
            
            p3line = plot3(tax, xtmpn(1), ytmpn(1), ztmpn(1), 'r');
            if ~isempty(settings.sync_to)
                synchs = get(settings.sync_to, 'User');
                if isempty(synchs)
                    synchs = struct;
                    synchs.axes = [];
                    synchs.functions = {};
                end
                synchs.functions{end+1} = @(x)(globetrack(p3line, xtmpn, ytmpn, ztmpn, x));
                set(settings.sync_to, 'User', synchs);
            end
            
            % set azimuth and elevation for southern ocean
            view(tax, -153, -36);
            title(tax, {settings.filename; 'Platform track'}, 'FontSize',9, 'Interpreter', 'none');
            
            % Standard plot (as subplot)
            vax = subplot(1,2,2);
            hold(vax,  'on')
            box(vax, 'on')
            grid(vax, 'on')
            
            plot(vax, lngitude,latitude,'r.');
            pline = plot(vax, lngitude(1), latitude(1), 'r.');
            
            % midnight positions
            day = floor(data.time);
            newday = 1+find(day(1:end-1) ~= day(2:end));
            lt = latitude(newday);
            ln = lngitude(newday);
            text(vax, ln, lt, datestr(data.time(newday), ' yyyy-mm-dd'))
            plot(vax, ln, lt, '+')
            
            xlabel(vax, 'Longitude (degrees)');
            ylabel(vax, 'Latitude (degrees)');
            set(vax, 'TickDir' , 'out');
            
            %{
            lat = median(latitude);
            set(vax, 'DataAspectRatio', [1 cosd(lat) 1 ]);
            axis(vax, 'manual')
            %}
            
            if ~isempty(settings.sync_to)
                synchs = get(settings.sync_to, 'User');
                if isempty(synchs)
                    synchs = struct;
                    synchs.axes = [];
                    synchs.functions = {};
                end
                synchs.functions{end+1} = @(x)(voyagetrack(pline, latitude, lngitude, x));
                set(settings.sync_to, 'User', synchs);
            end
            
        else
            % geoplot introduced in R2018b
            set(tfig,'Position',[p(3)/3 p(4)/3 p(3)*0.4 p(4)*0.5])
            
            gx = geoaxes(tfig);
            geoplot(gx, latitude, lngitude, 'r.')
            hold(gx, 'on')
            geoline = geoplot(gx, latitude(1), lngitude(1), 'r.');
            if ~isempty(settings.sync_to) && isvalid(settings.sync_to)
                synchs = get(settings.sync_to, 'User');
                if isempty(synchs)
                    synchs = struct;
                    synchs.axes = [];
                    synchs.functions = {};
                end
                synchs.functions{end+1} = @(x)(geotrack(geoline, latitude, lngitude, x));
                set(settings.sync_to, 'User', synchs);
            end
            title(gx, {settings.filename; 'Platform track'}, 'Interpreter','none');
            gx.TickDir = 'out';
            set(gcf,'color','w')
            
            % midnight positions as text
            day = floor(data.time);
            newday = 1+find(day(1:end-1) ~= day(2:end));
            text(latitude(newday),lngitude(newday),...
                datestr(data.time(newday),'  yyyy-mm-dd'))
            geoplot(gx,latitude(newday),lngitude(newday),...
                '+k','MarkerSize',8)
            
            % change the basemap (try 'colorterrain' if internet access is there)
            try
                java.net.InetAddress.getByName('www.google.com');
                geobasemap colorterrain
            catch % No access to DNS, assume no internet
                geobasemap darkwater
            end
        end
    end
end
end

%% --------- Functions ---------

%% Function to read a variable from NetCDF

function vardata = getNetcdfVar(ncid, vid)
% read a variable from netcdf
if ischar(vid)
    vid = netcdf.inqVarID(ncid, vid);
end
vardata = netcdf.getVar(ncid, vid);
try
    vfill = netcdf.getAtt(ncid, vid, '_FillValue');
    vardata(vardata == vfill) = NaN;
catch
end
try
    vscale = netcdf.getAtt(ncid, vid, 'scale_factor');
    vardata = vardata .* vscale;
catch
end
try
    voffset = netcdf.getAtt(ncid, vid, 'add_offset');
    vardata = vardata + voffset;
catch
end
end

%% Function to calculate mean ignoring NaN values

function nmean = nmean(data)
% calculate mean ignoring NaN values
nan = isnan(data);
data(nan) = 0;
count = sum(~nan);
count(count==0) = NaN;      % prevent divide by 0
nmean = sum(data)./count;
end

%% Function for generating echogram plots of the dataset as an image

function plotax = echogram(data, settings, dataset, position, ttle, range, cmap, overlay)
%   echogram plots the dataset as an image.
%   INPUTS
%   data        data structure containing time used to draw ticks
%   settings    settings structure including tickformat
%   dataset     2D data to plot (if more than 2D only first slice is
%               plotted)
%   position    number of figure heights from top of screen to place
%               the base of this figure or panel to place plot in
%   ttle        Title of plot
%   range       Range of colortable used to display data.
%   cmap        Colormap used to display data [EK500colourmap]
%   sun         Optional vector drawn on image, usually 1 = day 4 = night

% Modified GJK Feb 2021 - split function into transect_viewer and added
% zoom buttons

[dheight, dwidth] = size(dataset);

if isnumeric(position)
    fig = figure;
    set(fig, 'color', 'w');
    
    drawnow;
    screen = getScreen();
    
    % fit figure on "screen"
    % calculate image size
    width = dwidth + 160;
    height = dheight * 1.25 + 80;
    if width > screen(3) * 0.95
        width = screen(3) * 0.95;
    end
    if height > screen(4)
        height = screen(4);
    end
    base = screen(4) - floor(position * (height+100));
    set(fig, 'Position',  [screen(3) * 0.02 base width height]);
    pos = get(fig, 'Position');
    
    % keep figure from going over top of screen
    opos = get(gcf, 'OuterPosition');
    above = opos(2) + opos(4) - screen(4);
    if above > 0
        pos(2) = pos(2) - above;
        set(fig, 'Position', pos);
    end
    if pos(2) < 0
        pos(2) = 0;
        set(fig, 'Position', pos);
    end
    
else
    fig = position;
end
plotax = transect_viewer(fig, data, settings);

slide_width = 0.01;
if verLessThan('matlab', '9.1')
    % Style slider not supported before R2016b
    slider = [];
else
    slider = uicontrol(fig, ...
        'Style',    'slider', ...
        'Units',    'normalized', ...
        'Position', [0 0.15 slide_width 0.85], ...
        'User',     plotax, ...
        'Callback', {@yslide, data, settings}, ...
        'Tag',      'YSlider', ...
        'Max',      dheight, ...
        'Min',      1, ...
        'Value',    1);
end

if nargin < 6 || isempty(range)
    range = settings.range;
end
if isempty(range)
    range = [floor(min(dataset, [], 'all')) ceil(max(dataset, [], 'all')) ];
end
if range(1) == -Inf ; range(1) = -100; end
if range(2) ==  Inf ; range(2) =  100; end
if range(1) == range(2) ; range(2) = range(2) + 1; end

imagesc(plotax, dataset(:,:,1), range)
if nargin < 7 || isempty(cmap)
    colormap(plotax, EK500colourmap())
elseif strcmpi(cmap, 'ek500')
    colormap(plotax, EK500colourmap())
elseif strcmpi(cmap, 'ek80')
    colormap(plotax, EK80colourmap())
elseif strcmpi(cmap, 'rdbu')
    colormap(plotax, Hmap())
else
    colormap(plotax, cmap)
end

set(plotax, 'Tag', 'echogram')
title(plotax, ttle, 'Interpreter','tex','FontSize',11); % Haris 30/09/2020 changed Interpreter to 'tex' and defined font size
text(plotax, 0, -10, settings.location{1});
text(plotax, dwidth, -10, settings.location{2}, 'HorizontalAlignment', 'right');
cb = colorbar(plotax);
set(cb, 'TickDir', 'out')
xlabel(plotax, settings.XLABELS{settings.tickformat});
ylabel(plotax, 'Depth (m)');
set(plotax, 'TickDirMode', 'manual');
set(plotax, 'TickDir', 'out');
set(plotax, 'TickLength', [0.002 0.001]);

drawnow
% optimise fit, note that TightInset does not allow for colorbar or
% title
tight = get(plotax, 'TightInset');
tight = tight + [slide_width 0.15 1.4*tight(1) 0.05];
tpos = [tight(1) tight(2) 1-2.4*tight(1) 1-(tight(2)+tight(4))];
set(plotax, 'Position', max(tpos, [0 0 0.1 0.1]));
set(plotax, 'LooseInset', tight);
set(plotax, 'Units', 'pixels')
pos = get(plotax, 'Position');
pos(4) = dheight;
set(plotax, 'Position', pos);
set(plotax, 'Units', 'normalized')
if settings.fit
    xlim(plotax, [1 dwidth])
else
    xlim(plotax, [1 pos(3)]);
end
ylim(plotax, [1 pos(4)]);
zoom(plotax, 'reset');
if dheight > pos(4) && isscalar(slider)
    set(slider, 'Value', dheight - pos(4));
end

if nargin > 7 && ~isempty(overlay)
    % plot overlay between 1/4 and 3/4 height of image.
    hold on
    yl = ylim;
    scl = 0.5 * (yl(1) - yl(2)) / (max(overlay) - min(overlay));
    off = yl(2) + 0.25 * (yl(1) - yl(2)) - min(overlay) * scl;
    plot(plotax, overlay * scl + off, 'r')
end

% update axis
doticks(fig, plotax, data, settings)

end

%% Function to calculate plottable area of screen

% This gets hairy for multiple monitors. Returns [left top width height].

function screen = getScreen()
screen = get(0, 'ScreenSize');

mpos = get(0,'MonitorPosition');
if ispc
    screen(1) = min(mpos(:,1));
    screen(3) = max(mpos(:,3));
elseif isunix
    screen(1) = min(mpos(:,1));
    screen(3) = max(mpos(:,1) + mpos(:,3));
elseif ismac
end
end

%% Function to place ui object for a transect in a panel

function plotax = transect_viewer(panel, data, settings)
% viewer populates a panel (figure or uipanel) with the controls
% to enable switching x-axis lables between distance, time, latitude
% and longitude.
% INPUTS
% panel     this will normally be figure but may be a uipanel if you
%           don't want the plot taking up the whole figure (i.e.
%           uipanels can be used to simulate subplots).

% Added Feb 2021 GJK - split from echogram, generalised for any plot
% with transect as the x axis. Added sync checkbox to allow syncing of
% axes.

enable = {'off' 'on'};

if isempty(panel)
    panel = figure('Units', 'Normalized', 'Position', [.1 .5 .8 .3]);
end

plotax = axes(panel);
set(plotax, 'Position', [0.085 0.35 0.855 0.5]);
fs = get(plotax, 'fontsize'); % scale ui object to fontsize.

set(zoom,'ActionPostCallback', {@ticks, data, settings})
set(pan,'ActionPostCallback',  {@ticks, data, settings})
if strcmp(get(panel, 'Type'), 'figure')
    set(panel, 'SizeChangedFcn', {@(x,y)(ticks(x, plotax, data, settings))})
end

if settings.fit
    xlim(plotax, [1 length(data.time)])
end

sync_to = settings.sync_to;
if isempty(sync_to)
    sync_to = plotax;
end

controlpanel = uipanel(panel, ...
    'Units',        'pixels', ...
    'Position',     [0 0 86*fs 2*fs], ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'BorderWidth',  0);

xformat_panel = uibuttongroup(controlpanel, ...
    'SelectionChangeFcn', {@xFormat, data, settings}, ...
    'Units',        'pixels', ...
    'Position',     [0 0 40*fs 2*fs], ...
    'Tag',          'XFormat', ...
    'User',         [settings.tickformat settings.minutes]);

set(xformat_panel, 'Units', 'normalized');

uicontrol(xformat_panel, ...
    'Style',        'radiobutton', ...
    'TooltipString', 'Show time across X axis', ...
    'Tag',          'time', ...
    'String',       'Time', ...
    'Value',        settings.tickformat == settings.TIME, ...
    'User',         settings.TIME, ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [0 0 10*fs 2*fs]);
uicontrol(xformat_panel, ...
    'Style',        'radiobutton', ...
    'TooltipString', 'Show distance number across X axis', ...
    'Tag',          'distance', ...
    'String',       'Distance', ...
    'Value',        settings.tickformat == settings.INTERVAL, ...
    'User',         settings.INTERVAL, ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [10*fs 0 10*fs 2*fs]);
uicontrol(xformat_panel, ...
    'Style',        'radiobutton', ...
    'TooltipString', 'Show latitude across X axis', ...
    'Tag',          'latitude', ...
    'String',       'Latitude', ...
    'Value',        settings.tickformat == settings.LAT && ~settings.minutes, ...
    'Enable',       enable{1 + any(data.latitude)}, ...
    'User',         settings.LAT, ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [20*fs 0 10*fs 2*fs]);
uicontrol(xformat_panel, ...
    'Style',        'radiobutton', ...
    'TooltipString', 'Show longitude across X axis', ...
    'Tag',          'longitude', ...
    'String',       'Longitude', ...
    'Value',        settings.tickformat == settings.LONG && ~settings.minutes, ...
    'Enable',       enable{1 + any(data.longitude)}, ...
    'User',         settings.LONG, ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [30*fs 0 10*fs 2*fs]);
uicontrol(xformat_panel, ...
    'Style',        'radiobutton', ...
    'TooltipString', 'Show latitude across X axis in deg:min', ...
    'Tag',          'lat:min', ...
    'String',       'Lat (d:m)', ...
    'Value',        settings.tickformat == settings.LAT && settings.minutes, ...
    'Enable',       enable{1 + any(data.latitude)}, ...
    'User',         settings.LAT, ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [40*fs 0 0 2*fs]); % width 0 = disabled
uicontrol(xformat_panel, ...
    'Style',        'radiobutton', ...
    'TooltipString', 'Show longitude across X axis in deg:min', ...
    'Tag',          'long:min', ...
    'String',       'Long (d:m)', ...
    'Value',        settings.tickformat == settings.LONG && settings.minutes, ...
    'Enable',       enable{1 + any(data.longitude)}, ...
    'User',         settings.LONG, ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [40*fs 0 0 2*fs]); % disabled

syncpanel = uipanel(controlpanel, ...
    'Units',        'pixels', ...
    'Position',     [40*fs 0 10*fs 2*fs]);

uicontrol(syncpanel, ...
    'Style',        'checkbox', ...
    'TooltipString', 'Synchronise axes with the processed data plot', ...
    'String',       'Sync plot', ...
    'Tag',          'Sync', ...
    'Value',        0, ...
    'Callback',     {@sync, data, settings}, ...
    'User',         sync_to, ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [0 0 10*fs 2*fs]);

zoompanel = uipanel(controlpanel, ...
    'Units',        'pixels', ...
    'Position',     [50*fs 0 20*fs 2*fs]);

uicontrol(zoompanel, ...
    'Style',        'pushbutton', ...
    'String',       'Zoom 100%', ...
    'TooltipString', 'Zoom to one pixel per data point', ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [10*fs 0 10*fs 2*fs], ...
    'User',         plotax, ...
    'Callback',     {@fullsize, data, settings});

uicontrol(zoompanel, ...
    'Style',        'pushbutton', ...
    'String',       'Zoom to Fit', ...
    'TooltipString', 'Zoom to make the whole plot visible', ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [0 0 10*fs 2*fs], ...
    'User',         plotax, ...
    'Callback',     {@fitview, data, settings});

playpanel = uipanel(controlpanel, ...
    'Units',        'pixels', ...
    'Position',     [70*fs 0 16*fs 2*fs]);

playbutton = uicontrol(playpanel, ...
    'Style',        'pushbutton', ...
    'String',       'Play', ...
    'TooltipString', 'Automatically scroll through the data', ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [0 0 5*fs 2*fs], ...
    'User',         0, ...
    'Callback',     {@play, data, settings});

uicontrol(playpanel, ...
    'Style',        'pushbutton', ...
    'String',       'Stop', ...
    'TooltipString', 'Stop play', ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [11*fs 0 5*fs 2*fs], ...
    'User',         playbutton, ...
    'Callback',     @stopplay);

uicontrol(playpanel, ...
    'Style',        'pushbutton', ...
    'String',       '+', ...
    'TooltipString', 'Increase speed of play', ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [5*fs 0 2*fs 2*fs], ...
    'User',         playbutton, ...
    'Callback',     @faster);

uicontrol(playpanel, ...
    'Style',        'pushbutton', ...
    'String',       '-', ...
    'TooltipString', 'Slow rate of play', ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [7*fs 0 2*fs 2*fs], ...
    'User',         playbutton, ...
    'Callback',     @slower);

uicontrol(playpanel, ...
    'Style',        'pushbutton', ...
    'Tag',          'Reverse', ...
    'String',       '<', ...
    'TooltipString', 'Reverse direction of play', ...
    'BackgroundColor', [0.9 0.9 0.9], ...
    'Units',        'pixels', ...
    'Position',     [9*fs 0 2*fs 2*fs], ...
    'User',         playbutton, ...
    'Callback',     @reverse);

dwidth = length(data.time);
slider = uicontrol(panel, ...
    'Style',        'slider', ...
    'Units',        'normalized', ...
    'Position',     [0 0.1 1 0.05], ...
    'User',         plotax, ...
    'Callback',     {@slide, data, settings},...
    'Tag',          'XSlider', ...
    'Max',          dwidth, ...
    'Min',          1);

set(slider, 'Value', 1);

end

%% 

function slide(slider, ~, data, settings)
% Callback function for the slider,
% set the start of the x axis to the slider value.

% Added Feb 2021 GJK

slid = get(slider, 'Value');
pax = get(slider, 'User');
xl = xlim(pax);
delta = slid - xl(1);
if delta
    xlim(pax, xl + delta);
end

% update slider range to match current size of plot.
dwidth = length(data.time);
smax = dwidth + xl(1) - xl(2);
update_slider(slider, slid, smax);

caxes = findaxes(slider);
if isscalar(caxes)
    ticks(slider, caxes, data, settings);
end
end


function yslide(slider, ~, data, settings)
% Callback function for the depth slider,
% set the start of the Y axis to the slider value.

% Added Feb 2021 GJK

dheight = length(settings.use_depth);
val = get(slider, 'Value');
pax = get(slider, 'User');
yl = ylim(pax);
delta = dheight - val - yl(2);
if delta
    ylim(pax, yl + delta);
end

smax = dheight + yl(1) - yl(2);
update_slider(slider, val, smax);

caxes = findaxes(slider);
if isscalar(caxes)
    ticks(slider, caxes, data, settings);
end
end


function sync(handle, ~, data, settings)
% Callback function for the sync button,
% if checked add the axes for this plot to the list of synced axes
% if unchecked remove the axes from the list of synced axes
% if this is the master plot unchecking will unsync all.

% Added Feb 2021 Gordon Keith

master = get(handle, 'User');
if ~isvalid(master)
    return  % can't sync if master has been deleted
end
value = get(handle, 'Value');
slave = findaxes(handle);   % slave may be a vector if yyplot used (version < R2016b)
syncs = get(master, 'User'); % master has a vector of currently synced axes
if isempty(syncs)
    syncs = struct;
    syncs.axes = [];
    syncs.functions ={};
end

if isempty(master)      % if master is not defined then this is the master
    master = slave(1);
    set(handle, 'User', master)
end

if slave ~= master
    found = find(slave(1) == syncs.axes, 1);
    if value == 0
        if found
            linkaxes(syncs.axes, 'off');
            syncs.axes(found) = [];
        else
            return
        end
    else
        if isempty(syncs.axes)
            syncs.axes = [ master slave' ];
            sb = findobj(get(master, 'Parent'), 'Tag', 'Sync');
            if isscalar(sb)
                set(sb, 'Value', 1)
            end
        elseif isempty(found)
            syncs.axes = [syncs.axes slave'];
        else
            return
        end
    end
    
    linkaxes(syncs.axes, 'x');
    set(master, 'User', syncs);
    ticks(master, master, data, settings)
else
    % unsync on master turns off all syncs
    if value == 0 && ~isempty(syncs.axes)
        linkaxes(syncs.axes, 'off');
        for i = 1:length(syncs.axes)
            sb = findobj(get(syncs.axes(i), 'Parent'), 'Tag', 'Sync');
            if isscalar(sb)
                set(sb, 'Value', 0)
            end
        end
        syncs.axes = [];
        set(master, 'User', syncs);
    end
end
end


function play(button, ~, data, settings)
% callback function called when the user presses the play button.
% this functions scrolls across the current axes until the end is
% reached.
% The speed of playback is stored as the 'User' property of the
% button and may be changed by 'Stop', '+' and '-' buttons while
% this function is running.

dwidth = length(data.time);
colr = get(button, 'BackgroundColor');
set(button, 'BackgroundColor', 'green')
paxes = findaxes(button);

if get(button, 'User') == 0
    panel = get(button, 'Parent');
    rev = findobj(panel, 'Tag', 'Reverse');
    
    xl = xlim(paxes);
    if xl(2) < dwidth
        set(button, 'User', 1)
        set(rev, 'String', '<')
    else
        set(button, 'User', -1)
        set(rev, 'String', '>')
    end
end

if isscalar(paxes)
    speed = get(button, 'User');
    while speed ~= 0
        xl = xlim(paxes);
        xl = xl + (xl(2) - xl(1))*speed/200; % each frame advance x axis speed/2 %
        if xl(1) < 0 && speed < 0
            xl = xl - xl(1);
            set(button, 'User', 0)
        elseif xl(2) > dwidth && speed > 0
            xl = xl -xl(2) + dwidth;
            set(button, 'User', 0)
        end
        xlim(paxes, xl)
        ticks(button, paxes, data, settings)
        drawnow
        pause(1/50)
        
        if isvalid(button)
            speed = get(button, 'User');
        else
            speed = 0;
        end
    end
end

if isvalid(button)
    set(button, 'BackgroundColor', colr)
end
end

function stopplay(button, ~)
playbutton = get(button, 'User');
set(playbutton, 'User', 0);
end

function faster(button, ~)
playbutton = get(button, 'User');
speed = get(playbutton, 'User') * 1.5;
if speed == 0
    speed = 1.5;
end
set(playbutton, 'User', speed);
end

function slower(button, ~)
playbutton = get(button, 'User');
speed = get(playbutton, 'User') / 1.5;
if speed == 0
    speed = 2/3;
end
set(playbutton, 'User', speed);
end

function reverse(button, ~)
playbutton = get(button, 'User');
speed = get(playbutton, 'User') * -1;
if speed == 0
    speed = -1;
end
set(playbutton, 'User', speed);
if speed < 0
    set(button, 'String', '>');
else
    set(button, 'String', '<');
end
end


function xFormat(panel, event, data, settings)
% Callback used when the user selects a different X axis label
% INPUTS
% panel     The xformat_panel uibuttongroup. The format selected is
%           stored as a pair of integers in its 'User' field.
% event     The selection event indicating which format the user has
%           chosen. The format is stored as in integer in the button's
%           'User' field. Degrees and minutes is indicated by the
%           button's 'Tag' ending in 'min'.
%
% The tick format and degree format are stored in the button group
% 'User' field as integers. ticks is called to apply the new format.

% Added Feb 2021 GJK

% retrive new format
tick_format = get(event.NewValue, 'User');

tag = get(event.NewValue, 'Tag');
minutes = length(tag) > 3 && strcmp(tag(end-2:end), 'min');

% store new format
set(panel, 'User', [tick_format minutes]);

% update axes
caxes = findaxes(panel);
if isscalar(caxes)
    xlabel(caxes, settings.XLABELS{tick_format});
    ticks(panel, caxes, data, settings)
end
end


function fullsize(button, ~, data, settings)
% Callback function for the zoom to 1:1 (100%) button

% Added Feb 2021 GJK
caxes = findaxes(button);
if isscalar(caxes)
    set(caxes, 'Units', 'pixels');
    pos = get(caxes, 'Position');
    set(caxes, 'Units', 'normalized');
    xl = xlim(caxes);
    x0 = max(1, min(xl(1), length(data.time) - pos(3)));
    xlim(caxes, [x0 x0 + pos(3)]);
    if strcmp(get(caxes, 'Tag'), 'echogram')
        yl = ylim(caxes);
        y0 = max(1, min(yl(1), length(settings.use_depth) - pos(4)));
        ylim(caxes, [y0 y0 + pos(4)]);
    end
    
    ticks(button, caxes, data, settings);
end
end

function fitview(button, ~, data, settings)
% Callback function for the zoom to fit button

% Added Feb 2021 GJK

caxes = findaxes(button);
if isscalar(caxes)
    xlim(caxes, [1 length(data.time)]);
    if strcmp(get(caxes, 'Tag'), 'echogram')
        ylim(caxes, [1 length(settings.use_depth)]);
    end
    ticks(button, caxes, data, settings);
end
end

function paxes = findaxes(panel)
% Find the axes associated with this object.
% That is the axes most closely related in the object hierarchy.
% This function is a helper for uicontrols associated with an axes
% but which may have a number of levels of panel in between.
paxes = [];
while isempty(paxes) && ~isempty(panel)
    paxes = findobj(panel, 'type', 'axes');
    panel = get(panel, 'Parent');
end
end


%% Function to update the ticks for a plot and its synchronized axes

function ticks(v, caxes, data, settings)
if isstruct(caxes)
    caxes = caxes.Axes;
end

xl = xlim(caxes);

panel = get(caxes, 'Parent');
sync = findobj(panel, 'Tag', 'Sync');
if isscalar(sync)
    master = get(sync , 'User');
    if isscalar(master) && isvalid(master)
        syncs = get(master, 'User');
        if ~isempty(syncs)
            for i = 1:length(syncs.functions)
                syncs.functions{i}(xl);
            end
            if get(sync, 'Value')
                found = find(syncs.axes == caxes, 1);
                if ~isempty(found)
                    for i = 1:length(syncs.axes)
                        if isvalid(syncs.axes(i))
                            doticks(v, syncs.axes(i), data, settings)
                        end
                    end
                    return
                end
            end
        end
    end
end

doticks(v, caxes, data, settings)
end

%% Function to calculate and display the ticks for a transect view

function doticks(~, caxes, data, settings)
% Callback used to draw tick marks
% The first parameter is the figure affected (not used).
% The second parameter is the axes affected.
%

% Modified Feb 2021 GJK - added slider updates

% Constants
LAT = settings.LAT;
LONG = settings.LONG;
INTERVAL = settings.INTERVAL;

if isstruct(caxes)
    caxes = caxes.Axes;
end

panel = get(caxes, 'Parent');
xformat = findobj(panel, 'Tag', 'XFormat');
if isempty(xformat) % write_echogram
    tick_format = settings.tickformat;
    minutes = settings.minutes;
else
    format = get(xformat, 'User');
    tick_format = format(1);
    minutes = format(2);
end

x_lim=get(caxes,'XLim');
fontsize = get(caxes, 'FontSize');
set(caxes,'Units','Pixels');
pos = get(caxes, 'Position');
set(caxes,'Units','Normalized');
width = pos(3);

% Label X axis using latitude or longitude

if tick_format == LAT || tick_format == LONG
    
    if tick_format == LONG
        ticker = data.longitude;
    else
        ticker = data.latitude;
    end
    
    visible = ticker(max(1,floor(x_lim(1))):min(length(ticker),ceil(x_lim(2))));
    mint = min(visible);
    maxt = max(visible);
    cpd = width / fontsize / (maxt - mint);     % characters per degree
    if settings.xfactor
        tock = settings.xfactor;
    else
        if minutes
            if cpd < 2
                tock = .1;      % show every 10 degrees
            elseif cpd < 4
                tock = .2;      % show every 5 degrees
            elseif cpd < 12
                tock = 1;       % show each degree
            elseif cpd < 100
                tock = 4;       % show 15 minutes
            elseif cpd < 300
                tock = 12;      % show 5 minutes
            else
                tock = 60;      % show minutes
            end
        else
            if cpd < 2
                tock = .1;      % show every 10 degrees
            elseif cpd < 4
                tock = .2;      % show every 5 degrees
            elseif cpd < 12
                tock = 1;       % show each degree
            elseif cpd < 60
                tock = 2;       % show half degrees
            else
                tock = 10;      % show tenth degrees
            end
        end
    end
    
    tickedge = floor(ticker * tock);
    tk=tickedge;
    tk(end) = [];
    tickedge(1) = [];
    xtick = find(tk ~= tickedge);
    xtick = xtick + 1;
    xlabels = num2str(ticker(xtick),'%4.0f');
    if tock > 1
        if minutes
            xdeg = round(ticker(xtick)*60)/60;
            xmin = xdeg - fix(xdeg);
            xmin = abs(xmin) * 60;
            coln = char(ones(length(xmin),1) * ':');
            xlabels = [ num2str(fix(xdeg)) coln num2str(xmin, '%02.0f') ];
        else
            if tock <= 10
                xlabels = num2str(ticker(xtick),'%6.1f');
            else
                xlabels = num2str(ticker(xtick),'%7.2f');
            end
        end
    end
    
elseif tick_format == INTERVAL
    xtick = 0:max(1,10^(floor((log10((x_lim(2) - x_lim(1))/width*fontsize*30))))):x_lim(2);
    xlabels = xtick;
    
else

    % Label X Axis using Time
    
    start = data.time(max(1,ceil(x_lim(1))));
    finish= data.time(min(length(data.time),floor(x_lim(2))));
    
    cpd = width/fontsize/(finish-start); % characters per day
    if settings.xfactor
        tock = settings.xfactor;
    else
        if cpd > 4500
            tock = 1440;      % 1 minute
        elseif cpd > 1500
            tock = 288;       % 5 minute
        elseif cpd > 720
            tock = 144;       % 10 minute
        elseif cpd > 480
            tock = 96;        % quarter hour
        elseif cpd > 120
            tock = 24;        % hour
        elseif cpd > 60
            tock = 4;         % 6 hr
        elseif cpd < 5 && (verLessThan('matlab', '9.9.1') || settings.debug) % ver 9.9.1 automatically rotates ticklabels to fit
            tock = 1 / ceil(5/cpd);
        else
            tock = 1;         % day
        end
    end
    if cpd < 12 && (verLessThan('matlab', '9.9.1') || settings.debug)
        format = 'mmm-dd';
    elseif tock <= 1
        format = 29;      % 'yyyy-mm-dd'
    elseif tock <= 4
        format = 'yyyy-mm-dd HH:MM';
    else
        format = 15;    % 'HH:MM'
    end
    
    xtock = (ceil(start*tock):1:finish*tock)/tock;
    if isempty(xtock); xtock = start; end
    xtick(length(xtock))=0;
    for i=1:length(xtock)
        xtick(i)=find(data.time>=xtock(i),1);
    end
    
    xtick(diff(xtick) == 0) = [];
    xlabels = datestr(data.time(xtick), format);
end

set(caxes, 'XTick',xtick);
set(caxes, 'XTickLabel',xlabels);

% update slider
xslider = findobj(panel, 'Tag', 'XSlider');
if isscalar(xslider)
    new_value = max(1, x_lim(1));
    set(xslider, 'Value', x_lim(1));
    
    dwidth = length(data.time);
    smax = dwidth + x_lim(1) - x_lim(2);
    update_slider(xslider, new_value, smax);
end

if strcmp(get(caxes, 'Tag'), 'echogram')
    ytick=get(caxes,'YTick');
    yticklabel{length(ytick)} = '';
    for i = 1:length(ytick)
        if ytick(i) < 1 || ytick(i) > length(settings.use_depth)
            yticklabel{i} = '';
        else
            yticklabel{i} = num2str(settings.use_depth(floor(ytick(i))));
        end
    end
    set(caxes, 'YTickLabel',yticklabel);
    
    yslider = findobj(panel, 'Tag', 'YSlider');
    if isscalar(yslider)
        dheight = length(settings.use_depth);
        y_lim = ylim(caxes);
        new_value = max(1, dheight - y_lim(2));
        symax = dheight + y_lim(1) - y_lim(2);
        update_slider(yslider, new_value, symax);
    end
end
end


function update_slider(slider, new_value, smax)
% helper function to update slider with a new value
% the maximum range is also checked and the slider made invisible
% if the range is null.

% Added Feb 2021 GJK

if new_value > smax
    new_value = smax;
end
if get(slider, 'Value') ~= new_value
    set(slider, 'Value', new_value);
end
if get(slider, 'Max') ~= smax
    set(slider, 'Max', smax)
    set(slider, 'Visible', smax > 1)
end
end

%% Function to export echogram as image file

function pane = write_echogram(data, settings, dataset, imagefile, ...
    channel, ttle, pane, imagesize)
% write_echogram writes the echogram to an image file.

file = settings.filename;
location = settings.location;
cmap = settings.cmap;
res = settings.resolution;

range = settings.range;
if isempty(range)
    range = [min(plotdata, [], 'all') max(plotdata, [], 'all')];
    if range(2) - range(1) > 1 || range(2) == range(1)
        range = [floor(range(1)) ceil(range(2))];
    end
end
if range(1) == -Inf ; range(1) = -100; end
if range(2) ==  Inf ; range(2) =  100; end
if range(1) == range(2) ; range(2) = range(2) + 1; end

[~, name, ext] = fileparts(file);

if nargin < 8 || isempty(imagesize)
    imagesize = settings.imagesize;
end

if isempty(imagesize)
    imagesize = [2400 300];
end

width = imagesize(1);
height = imagesize(2);

fontsize = 12;

if height == 0
    vmargin = 1.1 * size(dataset, 1);
    height = size(dataset, 1) + vmargin;
else
    vmargin = 1.1 * height / 2.1;
end

% imagesize of 0 is a request for 1 pixel per data point (old behaviour)
hmargin = 16 * fontsize;
if width == 0
    width = size(dataset,2);
    % 2^14 limit for matlab graphics objects at March 2021
    while width > 16000
        width = width / 2;
    end
    width = width + hmargin;
end

axpos = []; % first axes position determined by matlab, then used by other channels.

if nargin < 7 || isempty(pane)   % first or only channel
    if verLessThan('matlab', '9.8') || strncmpi(settings.imagefile, '-d', 2) || settings.debug
        % print figure (figure will be smaller than screen)
        pane = figure('Units', 'pixels', 'Position', [0, 50, width, height]);
        set(pane, 'Color', 'w');
        drawnow
        fpos = get(pane, 'Position');
        if fpos(3) < width
            width = fpos(3);
        end
    else
        % exportgraphics from uipanel
        % panel may be bigger than figure and screen
        fig0 = figure('Units', 'pixels', 'Position', [0, 50, width, height ], 'PaperPositionMode', 'auto');
        set(fig0, 'Color', 'w')
        pane = uipanel(fig0, 'Units','pixels', 'Position',[0, 0, width, height ]);
        set(pane, 'BackgroundColor', 'white');
    end
else % subsequent channels
    % make room for a new channel by increasing fig size and moving
    % existing axes up
    oldpos = get(pane, 'Position');
    width = oldpos(3);
    children = get(pane, 'Children');
    for i = length(children):-1:1
        if ~strcmp(get(children(i), 'Tag'), 'Colorbar')
            set(children(i), 'Units', 'pixels');
            chpos = get(children(i), 'Position');
            if isempty(axpos) || axpos(2) > chpos(2)
                axpos = chpos;
            end
            chpos(2) = chpos(2) + height;
            set(children(i), 'Position', chpos);
        end
    end
    set(pane, 'Units', 'pixels', 'Position', [0, 0, width, height + oldpos(4)] );
end

ax = axes(pane);
imagesc(ax, dataset, range);

if isempty(cmap)
    colormap(ax, EK500colourmap)
elseif strcmpi(cmap, 'ek500')
    colormap(ax, EK500colourmap())
elseif strcmpi(cmap, 'ek80')
    colormap(ax, EK80colourmap())
elseif strcmpi(cmap, 'rdbu')
    colormap(ax, Hmap())
else
    colormap(ax, cmap)
end

set(ax, 'Tag', 'echogram')
set(ax, 'FontSize', fontsize);
set(ax, 'TickDir', 'out')
set(ax, 'TickLength', [0.001 0.0001])
xlabel(ax, settings.XLABELS{settings.tickformat}, 'FontSize', fontsize)
ylabel(ax, 'Depth (m)','FontSize', fontsize)

if ~iscell(ttle)
    ttle = {[ strrep(name,'_','\_') ext ' ' channel ]; ttle};
end
title(ax, ttle, 'FontSize', fontsize)

step = 10^ceil(log10((range(2) - range(1)) / 6));
if (range(2) - range(1)) / step < 1.5
    step = step / 5;
elseif (range(2) - range(1)) / step < 3
    step = step / 2;
end

colorbar('EastOutside', 'peer', ax, 'FontSize', fontsize-2,'TickDirection', 'out', 'LineWidth', 1,'YTick', step * ceil(range(1)/step):step:range(2)); % For text - color bar
text(ax, 0, -fontsize * 1.5, location{1}, 'FontSize', fontsize); % For text - transect start
text(ax, size(dataset,2), -fontsize * 1.5, location{2}, 'HorizontalAlignment', 'right', 'FontSize', fontsize); % For text - transect end

tight = get(ax, 'TightInset');
tight = tight + [0 0 0.01 0];
set(ax, 'LooseInset', tight)
set(ax,'LineWidth',1,'TickLength',ax.TickLength*3)
set(ax, 'Units', 'pixels')

if isempty(axpos)
    if imagesize(1) == 0 || imagesize(2) == 0
        axpos = get(ax, 'Position');
        axpos(3) = width - hmargin;
        axpos(4) = height - vmargin;
        set(ax, 'Units', 'pixels', 'Position', axpos);
    end        
else
    set(ax, 'Units', 'pixels', 'Position', axpos);
end

ticks(pane,ax, data, settings)
ticks(pane,ax, data, settings) % for some reason ticks are not updating for multifrequency and repeated command
drawnow;

driver = [];
if strcmp(imagefile, '-')
    % don't write file or close figure (multichannel)
else
    if ~isempty(channel)
        channel = ['_' channel];
    end
    
    % trailing + indicates last of multichannel, don't include
    % channel in name.
    if ~isempty(imagefile) && imagefile(end) == '+'
        channel = '';
        imagefile = imagefile(1:end-1);
    end
    % does image file end in a '?'
    ask = 0;
    if ~isempty(imagefile) && imagefile(end) == '?'
        ask = 1;
        imagefile = imagefile(1:end-1);
    end
    % is an empty character string
    if isempty(imagefile)
        imagefile = [ file channel '.png' ];
    end
    % is a driver
    if strncmpi(imagefile, '-d', 2)
        driver = imagefile;
        imagefile = [ file channel '.' imagefile(3:end) ];
    end
    % is a directory
    if verLessThan('matlab','9.3') || settings.debug % isfolder from R2017b
        if isdir(imagefile) %#ok<ISDIR>
            imagefile = fullfile(imagefile, [ name channel '.png' ]);
        end
    else
        if isfolder(imagefile)
            imagefile = fullfile(imagefile, [ name channel '.png' ]);
        end
    end
    % ask the user if the image file ended in ?
    if ask
        [imagefile, ipath] = uiputfile(imagefile);
        if imagefile == 0
            return
        end
        imagefile = fullfile(ipath, imagefile);
    end
    
    if verLessThan('matlab', '9.8') || ~isempty(driver) || settings.debug
        if isempty(driver)
            driver = '-dpng';
        end
        while ~strcmp(get(pane, 'Type'), 'figure')
            pane = get(pane, 'Parent');
        end
        print(pane, driver, imagefile, ['-r' num2str(res)])
        % saveas(fig, imagefile)
        close(pane)
    else
        exportgraphics(pane, imagefile, 'resolution', res)
        close(get(pane, 'Parent'));
    end
end
end

%% Functions to overlay xlim range from another plot on platform track

% Set the plotline data to match the set marked by overlay. pline is a Line
% object in a plot overlaying the full track. overlay is the xlim range
% from another plot to be overlayed on this plot.
%
% These functions are written to be called via an anonymous function in the
% list of sync functions.



function voyagetrack(pline, latitude, longitude, overlay)
if isvalid(pline)
    if isempty(overlay)
        set(pline, 'XData', longitude(1), 'YData', latitude(1), 'Color', [1 0 0 ]);
    else
        first = max(1, ceil(overlay(1)));
        last = min(length(latitude), floor(overlay(2)));
        over = first:last;
        set(pline, 'XData', longitude(over), 'YData', latitude(over),'Color', [0 0 1]);
    end
end
end

function geotrack(pline, latitude, longitude, overlay)
if isvalid(pline)
    if isempty(overlay)
        set(pline, 'LongitudeData', longitude(1), 'LatitudeData', latitude(1), 'Color', [1 0 0 ]);
    else
        first = max(1, ceil(overlay(1)));
        last = min(length(latitude), floor(overlay(2)));
        over = first:last;
        set(pline, 'LongitudeData', longitude(over), 'LatitudeData', latitude(over),'Color', [0 0 1]);
    end
end
end

function globetrack(pline, x, y, z, overlay)
if isvalid(pline)
    if isempty(overlay)
        set(pline, 'XData', x(1), 'YData', y(1), 'ZData', z(1), 'Color', [1 0 0 ]);
    else
        first = max(1, ceil(overlay(1)));
        last = min(length(x), floor(overlay(2)));
        over = first:last;
        set(pline, 'XData', x(over), 'YData', y(over), 'ZData', z(over), 'Color', [0 0 1]);
    end
end
end

%% Function for reducing rows of a matrix to make boxchart look better

function [flat, yticks] = flatten(array, settings)
dl = size(array,2);
scale = 1;
if dl > 200 && mod(dl, 50) == 0
    scale = 50;
elseif dl > 200 && mod(dl, 20) == 0
    scale = 20;
elseif dl >= 100 && mod(dl, 10) == 0
    scale = 10;
elseif dl > 20 && mod(dl, 5) == 0
    scale = 5;
elseif dl > 20 && mod(dl, 2) == 0
    scale = 2;
end
if scale == 1
    flat = array;
else
    flat = reshape(array, size(array,1)*scale, dl/scale);
end
yticks = settings.use_depth(scale:scale:dl);
end


%% Function for generating *.sv.csv and *.gps.csv file from data structure

% To generate Echoview style .sv.csv and .gps.csv files for the data.
% A .sv.csv file is written for each channel of the requested data.
% A .gps.csv file will have the position information. Channel name and
% '.sv.csv' is appended to the provided filename.

function svcsv(data, dataset, file)
% generate .sv.csv and .gps.csv file from data structure
if isempty(dataset) && isfield(data, 'Sv')
    dataset = data.Sv;
end
if isempty(file)
    file = data.file;
end
[path,name,ext] = fileparts(file);

ns = length(data.depth);
rows = length(data.time);
h = (data.depth(end) - data.depth(1)) / (ns-1);
srange = sprintf('%g,%g,%g', data.depth(1) - h/2, data.depth(end) + h/2, ns);
rangestr = repmat(srange, rows, 1);

if size(dataset,3) > 1 && isfield(data, 'channels')
    for s = length(data.channels):-1:1
        sv(s) = fopen(fullfile(path,[name ext '_' data.channels{s} '.sv.csv']),'w');
    end
else
    sv = fopen(fullfile(path,[name ext '.sv.csv']),'w');
end

if isfield(data, 'latitude') && isfield(data, 'longitude')
    timestr = datestr(data.time, 'yyyy-mm-dd,HH:MM:SS,FFF');
    latstr = num2str(data.latitude, '%.5f');
    lonstr = num2str(data.longitude, '%.5f');
    comma = ones(rows,1) * ',';
    newline = ones(rows,1) * '\n';
    gpsstr = [timestr comma latstr comma lonstr newline];
    
    gps = fopen(fullfile(path,[name ext '.gps.csv']),'w');
    fprintf(gps,'GPS_date,GPS_time,GPS_milliseconds,Latitude,Longitude\n');
    fprintf(gps, gpsstr');
    fclose(gps);
    
    for s = 1 : length(sv)
        fprintf(sv(s), 'Ping_date,Ping_time,Ping_milliseconds,Range_start,Range_stop,Sample_count,\n');
        svstr = num2str(dataset(:,:,s)', ',%.3f');
        txt = [ timestr comma rangestr svstr newline ];
        fprintf(sv(s), txt');
        fclose(sv(s));
    end
end
end

%% Function for generating *.csv file from summary layer metrics

% To write a .csv file containing time, longitude, latitude, sun cycle
% information, and summary layer metrics to the file specified. The summary
% layer metrics are the processed backscatter data (Sv) averaged in
% epipelagic (20-200 m), upper mesopelagic (200-400 m), and lower
% mesopelagic (400-800 m) depth layers. Note mandatory variables (day,
% epipelagic, upper_mesopelagic, and lower_mesopelagic) should be present
% to work this option.

function csv(data, file)
Time = datestr(data.time, 'yyyy-mm-dd HH:MM:SS');
Longitude = data.longitude;
Latitude = data.latitude;
if isfield(data, 'day')
    dsrn = 'DSRN';
    Daylight = dsrn(data.day)';
end
csv = table(Time, Longitude, Latitude, Daylight);
for layer = {'epipelagic', 'upper_mesopelagic', 'lower_mesopelagic'}
    if isfield(data, layer)
        if isfield(data, 'channels') && length(data.channels) > 1
            for i = 1 : length(data.channels)
                field = sprintf('%s_%s', layer{1}, data.channels{i});
                csv.(field) = data.(layer{1})(:,i);
            end
        else
            csv.(layer{1}) = data.(layer{1});
        end
    end
end
if isempty(file)
    file = [data.file '.csv'];
end
writetable(csv, file);
end

%% Function for generating *.inf and *.gps.csv files from data structure

% To generate MBSystem style .inf files and Echoview style .gps.csv files.
% The .inf file contains a metadata summary and .gps.csv file will have the
% position information.

function info(data)
if height(data.file) > 1
    data.file = data.file';
end
[path,name,ext] = fileparts(data.file);

% write gps.csv
timestr = datestr(data.time, 'yyyy-mm-dd,HH:MM:SS,FFF,');
latstr = num2str(data.latitude, '%.5f');
lonstr = num2str(data.longitude, '%.5f');
comma = ones(length(data.time),1) * ',';
newline = ones(length(data.time),1) * '\n';
txt = [ timestr latstr comma lonstr newline ];
gps = fopen(fullfile(path,[name ext '.gps.csv']),'w');
fprintf(gps,'GPS_date,GPS_time,GPS_milliseconds,Latitude,Longitude\n');
fprintf(gps, txt');
fclose(gps);

% write .inf
inf = fopen(fullfile(path,[name ext '.inf']),'w');
fprintf(inf,'\nData File:     ');
fprintf(inf, [name ext]);

% try getting vessel name
try
    ship_name = ncreadatt(data.file, '/', 'ship_name');
    fprintf(inf,'\n\nVessel: %s\n', ship_name);
catch
    warning('No vessel name written')
end

fprintf(inf,'\nIntervals: %d\n', length(data.time));

distance = length(data.time)/1000;
scale = data.grid_distance;
if scale(end) == 'm'
    scale(end) = [];
    if scale(end) == 'k'
        scale(end) = [];
        distance = distance * 1000;
    end
    if scale(end) == 'N'
        scale(end) = [];
        distance = distance * 1852;
    end
end
try
    distance = distance * str2double(scale);
catch
    distance = distance * 1000; % if unparsable assume 1km
end

duration = (data.time(end) - data.time(1)) * 24;
speed = distance / duration;
fprintf(inf,'\nNavigation Totals:\nTotal Time:         % 9.4f hours\n', duration);
fprintf(inf,'Total Track Length: % 9.4f km\n', distance);
fprintf(inf,'Average Speed:    % 9.4f km/hr (%.4f knots)\n', speed, speed / 1.852);

fprintf(inf,'\nStart of Data:\nTime:  ');
fprintf(inf,datestr(data.time(1),'yyyy-mm-dd HH:MM:SS.FFF'));
dv=datevec(data.time(1));
dv(2:6)=0;
fprintf(inf,'  JD%d\n',floor(data.time(1) - datenum(dv)));
fprintf(inf,'Lon:  % 9.4f    Lat: % 9.4f\n', data.longitude(1), data.latitude(1));

fprintf(inf,'\nEnd of Data:\nTime:  ');
fprintf(inf,datestr(data.time(end),'yyyy-mm-dd HH:MM:SS.FFF'));
dv=datevec(data.time(end));
dv(2:6)=0;
fprintf(inf,'  JD%d\n',floor(data.time(end) - datenum(dv)));
fprintf(inf,'Lon:  % 9.4f    Lat: % 9.4f\n', data.longitude(end), data.latitude(end));

fprintf(inf,'\nLimits\n');
fprintf(inf,'Minimum Longitude:     % 9.4f   Maximum Longitude:     % 9.4f\n', ...
    min(data.longitude), max(data.longitude));
fprintf(inf,'Minimum Latitude:      % 9.4f   Maximum Latitude:      % 9.4f\n', ...
    min(data.latitude), max(data.latitude));

fclose(inf);
end

%% Colormap: used by Simrad EK500 echosounder

function [EK500cmap] = EK500colourmap()
EK500cmap = [
    255 255 255 % white
    159 159 159 % light grey
    095 095 095 % grey
    000 000 255 % dark blue
    000 000 127 % blue
    000 191 000 % green
    000 127 000 % dark green
    255 255 000 % yellow
    255 127 000 % orange
    255 000 191 % pink
    255 000 000 % red
    166 083 060 % light brown
    120 060 040 % dark brown
    ]./255;
end

%% Colormap: used by Simrad EK80 echosounder

function [EK80cmap] = EK80colourmap()
EK80cmap = [
    255 255 255
    156 138 168
    141 125 150
    126 113 132
    112 100 114
    097 088 096
    082 076 078
    068 076 094
    053 083 129
    039 090 163
    024 096 197
    009 103 232
    009 102 249
    009 084 234
    015 066 219
    022 048 204
    029 030 189
    036 012 174
    037 049 165
    038 086 156
    039 123 147
    040 160 138
    041 197 129
    037 200 122
    030 185 116
    024 171 111
    017 156 105
    010 141 099
    021 139 092
    068 162 082
    114 185 072
    161 208 062
    208 231 052
    255 255 042
    254 229 043
    253 204 044
    253 179 045
    252 153 046
    252 128 047
    252 116 063
    252 110 085
    252 105 108
    252 099 130
    252 093 153
    252 085 160
    252 073 139
    253 061 118
    253 048 096
    254 036 075
    255 024 054
    240 030 052
    226 037 051
    212 044 050
    198 051 049
    184 057 048
    176 057 049
    170 054 051
    165 051 054
    159 047 056
    153 044 058
    150 039 056
    151 031 045
    153 023 033
    154 015 022
    155 007 011
    ] ./ 255;
end

%% Colormap: RdBu diverging

% Source: Charles (2021). cbrewer: colorbrewer schemes for Matlab
% flipud(cbrewer('div','RdBu',256,'linear'))
function [cmap] = Hmap()
cmap = [
    005 048 097
    006 050 100
    007 052 103
    008 054 106
    009 057 109
    011 059 112
    012 061 115
    013 063 118
    014 065 121
    015 067 124
    016 070 127
    017 072 130
    018 074 133
    020 076 136
    021 078 139
    022 080 142
    023 083 145
    024 085 148
    025 087 151
    026 089 154
    027 091 157
    029 093 160
    030 096 163
    031 098 166
    032 100 169
    033 102 172
    034 104 173
    036 105 174
    037 107 175
    038 109 176
    040 111 176
    041 112 177
    042 114 178
    043 116 179
    045 118 180
    046 119 181
    047 121 182
    049 123 183
    050 125 184
    051 126 184
    053 128 185
    054 130 186
    055 131 187
    057 133 188
    058 135 189
    059 137 190
    060 138 191
    062 140 191
    063 142 192
    064 144 193
    066 145 194
    067 147 195
    070 149 196
    073 151 197
    076 153 198
    080 155 199
    083 157 200
    086 159 201
    089 161 203
    092 163 204
    095 165 205
    099 167 206
    102 169 207
    105 171 208
    108 173 209
    111 175 210
    114 177 211
    118 179 212
    121 181 213
    124 183 214
    127 185 216
    130 187 217
    133 189 218
    137 191 219
    140 193 220
    143 195 221
    146 197 222
    148 198 223
    151 199 223
    153 201 224
    156 202 225
    158 203 225
    161 204 226
    163 206 227
    165 207 228
    168 208 228
    170 209 229
    173 211 230
    175 212 230
    178 213 231
    180 214 232
    182 215 232
    185 217 233
    187 218 234
    190 219 234
    192 220 235
    194 222 236
    197 223 237
    199 224 237
    202 225 238
    204 227 239
    207 228 239
    209 229 240
    211 230 240
    212 230 241
    214 231 241
    215 232 241
    217 233 241
    218 233 242
    220 234 242
    221 235 242
    223 235 243
    224 236 243
    226 237 243
    227 238 243
    229 238 244
    230 239 244
    232 240 244
    233 241 244
    235 241 245
    236 242 245
    238 243 245
    239 243 246
    241 244 246
    242 245 246
    244 246 246
    245 246 247
    247 247 247
    247 246 245
    247 245 243
    248 244 241
    248 243 240
    248 242 238
    248 241 236
    249 239 234
    249 238 232
    249 237 230
    249 236 229
    250 235 227
    250 234 225
    250 233 223
    250 232 221
    250 231 219
    251 230 217
    251 229 216
    251 228 214
    251 227 212
    252 225 210
    252 224 208
    252 223 206
    252 222 205
    253 221 203
    253 220 201
    253 219 199
    253 217 196
    252 215 193
    252 213 191
    252 210 188
    251 208 185
    251 206 182
    250 204 180
    250 202 177
    250 200 174
    249 197 171
    249 195 169
    249 193 166
    248 191 163
    248 189 160
    248 187 158
    247 184 155
    247 182 152
    247 180 149
    246 178 147
    246 176 144
    245 174 141
    245 171 138
    245 169 136
    244 167 133
    244 165 130
    243 162 128
    242 160 126
    241 157 124
    239 154 122
    238 152 120
    237 149 118
    236 146 116
    235 144 114
    234 141 112
    232 138 110
    231 136 108
    230 133 106
    229 131 104
    228 128 101
    227 125 099
    226 123 097
    224 120 095
    223 117 093
    222 115 091
    221 112 089
    220 109 087
    219 107 085
    217 104 083
    216 101 081
    215 099 079
    214 096 077
    213 093 076
    211 090 074
    210 087 073
    208 084 072
    207 082 070
    205 079 069
    204 076 067
    202 073 066
    201 070 065
    200 067 063
    198 064 062
    197 061 061
    195 059 059
    194 056 058
    192 053 057
    191 050 055
    190 047 054
    188 044 053
    187 041 051
    185 038 050
    184 036 048
    182 033 047
    181 030 046
    179 027 044
    178 024 043
    175 023 043
    172 022 042
    169 021 042
    166 020 041
    164 019 041
    161 018 040
    158 018 040
    155 017 039
    152 016 039
    149 015 038
    146 014 038
    143 013 037
    141 012 037
    138 011 037
    135 010 036
    132 009 036
    129 008 035
    126 007 035
    123 006 034
    120 006 034
    117 005 033
    115 004 033
    112 003 032
    109 002 032
    106 001 031
    103 000 031
    ] ./ 255;
end

%% Coastline data

% Used to display platform track on globe if MATLAB version is less than
% R2018b.
function [coastlat,coastlon] = coastline()
coastlat = [-83.830002,-84.330002,-84.500000,-84.669998,-84.919998,-85.419998,-85.419998,-85.580002,-85.330002,-84.830002,-84.500000,-84,-83.500000,-83,-82.500000,-82,-81.500000,-81.169998,-81,-80.919998,-80.669998,-80.330002,-80,-79.669998,-79.250000,-78.830002,-78.747818,-78.665421,-78.582809,-78.500000,-78.480568,-78.460754,-78.440567,-78.419998,-78.500000,-78.169998,-78.169998,-78.080002,-77.830002,-77.500000,-77.169998,-77,-77.169998,-77.580002,-77.830002,-77.669998,-77.250000,-76.750000,-76.330002,-75.919998,-75.830002,-75.580002,-75.750000,-75.419998,-75.250000,-75,-74.750000,-74.750000,-75,-75.419998,-75.750000,-76,-76,-75.669998,-75.169998,-74.669998,-74.330002,-74.330002,-73.830002,-73.250000,-73.250000,-73.750000,-74,-73.580002,-73.603729,-73.626648,-73.648735,-73.669998,-73.671219,-73.671623,-73.671219,-73.669998,-73.710052,-73.750069,-73.790054,-73.830002,-73.915771,-74.001038,-74.085785,-74.169998,-74.294998,-74.419998,-74.544998,-74.669998,-74.795731,-74.920982,-75.045746,-75.169998,-75.192856,-75.213806,-75.232864,-75.250000,-75,-74.500000,-74.375015,-74.250015,-74.125015,-74,-73.917694,-73.835258,-73.752693,-73.669998,-74,-74.500000,-75,-75.169998,-74.669998,-74.500000,-74,-74,-74.330002,-74.669998,-75.080002,-75.080002,-74.919998,-74.919998,-74.580002,-74.580002,-74.750000,-75,-74.750000,-74.330002,-74,-73.750000,-73.500000,-73.580002,-73.419998,-73.080002,-73.250000,-72.750000,-72.669998,-73,-72.919998,-73.330002,-73.080002,-73.419998,-73.750000,-73.750000,-73.419998,-73.080002,-72.919998,-72.500000,-72.169998,-72.108353,-72.046135,-71.983345,-71.919998,-71.878166,-71.835884,-71.793159,-71.750000,-72,-72,-71.830002,-72.080002,-72.419998,-72.580002,-72.750000,-72.919998,-72.919998,-72.919998,-73.080002,-72.919998,-72.830002,-72.919998,-73,-73.250000,-72.830002,-72.419998,-72.580002,-72.830002,-73,-73.500000,-73.419998,-73.330002,-73.169998,-73.080002,-72.830002,-72.330002,-71.830002,-71.500000,-70.919998,-70.419998,-70.419998,-70,-69.419998,-69.419998,-69.080002,-68.830002,-68.500000,-68.080002,-67.750000,-67.419998,-67.750000,-67.750000,-67.330002,-66.919998,-66.669998,-67.080002,-67,-67.330002,-66.830002,-66.580002,-66.250000,-65.919998,-65.500000,-65.080002,-65.169998,-64.750000,-64.669998,-64.250000,-64,-63.830002,-63.580002,-63.580002,-63.330002,-63.250000,-63.580002,-63.580002,-63.642956,-63.705612,-63.767960,-63.830002,-63.830547,-63.830730,-63.830547,-63.830002,-64.419998,-64.330002,-64,-64.500000,-64.330002,-64.669998,-65,-65.419998,-65.750000,-66.080002,-66.500000,-66.250000,-66.500000,-66.919998,-66.919998,-67.330002,-67.830002,-67.892754,-67.955338,-68.017754,-68.080002,-68.142639,-68.205185,-68.267639,-68.330002,-68.435135,-68.540184,-68.645142,-68.750000,-68.750000,-69.080002,-69.669998,-70.169998,-70.169998,-70.580002,-70.919998,-71.169998,-71.580002,-72,-72.330002,-72.669998,-72.753128,-72.835838,-72.918137,-73,-73.082550,-73.165070,-73.247551,-73.330002,-73.419998,-73.750000,-74.330002,-74.669998,-75.080002,-75.169998,-75.669998,-76.080002,-76.500000,-77,-77.169998,-77.080002,-77.080002,-77.250000,-77.580002,-77.919998,-78.250000,-78.500000,-78.750000,-78.830002,-78.830002,-78.830002,-78.750000,-78.330002,-77.830002,-77.500000,-77.169998,-76.830002,-76.500000,-76.080002,-75.669998,-75.330002,-74.750000,-74.419998,-74.080002,-73.750000,-73.419998,-73.080002,-72.919998,-72.830002,-72.580002,-72.250000,-71.919998,-71.669998,-71.330002,-71.250000,-71.580002,-71.250000,-71,-71.169998,-71.419998,-71.830002,-71.830002,-71.790665,-71.750885,-71.710663,-71.669998,-71.607559,-71.545074,-71.482559,-71.419998,-71.335060,-71.250076,-71.165054,-71.080002,-71.017555,-70.955078,-70.892555,-70.830002,-70.810356,-70.790482,-70.770355,-70.750000,-70.750000,-71,-71.330002,-71.330002,-71.250000,-70.669998,-70.419998,-70.250000,-70.419998,-70.669998,-71,-71.250000,-71.500000,-71.250000,-70.919998,-70.580002,-70.330002,-70.330002,-70.080002,-70.080002,-70.169998,-70.080002,-70.080002,-70.169998,-70.169998,-70.169998,-70.169998,-70.169998,-70.330002,-70.419998,-70.580002,-70.419998,-70.169998,-70.169998,-69.919998,-69.830002,-69.580002,-69.500000,-69.500000,-69,-68.669998,-68.580002,-68.919998,-69.330002,-69.500000,-69.580002,-70.080002,-69.669998,-69.500000,-69.169998,-68.830002,-68.500000,-68.169998,-67.830002,-67.750000,-67.750000,-67.750000,-67.580002,-67.669998,-67.419998,-67.419998,-67.830002,-67.580002,-67,-66.500000,-66.250000,-65.919998,-65.830002,-65.919998,-66.250000,-66.419998,-66.669998,-66.750000,-66.919998,-67,-67.169998,-67.500000,-67.330002,-67.580002,-67.669998,-67.500000,-67.580002,-67.750000,-67.830002,-67.830002,-67.669998,-68.169998,-68.169998,-68.580002,-69,-69.169998,-69.580002,-70.080002,-70.500000,-70.419998,-70.080002,-69.750000,-69.580002,-69.669998,-69.830002,-69.500000,-69.169998,-69.080002,-68.500000,-68.250000,-68,-67.830002,-67.330002,-67.169998,-67,-66.830002,-66.669998,-66.750000,-66.750000,-66.669998,-66.500000,-66.580002,-66.580002,-66.580002,-66.500000,-66.669998,-66.500000,-66.669998,-66.500000,-66.580002,-66.419998,-66.419998,-66.080002,-65.830002,-65.919998,-66.080002,-66.250000,-66.500000,-66.580002,-66.830002,-66.580002,-66.669998,-66.419998,-66.080002,-65.919998,-65.830002,-65.750000,-66,-66.330002,-66.500000,-66.750000,-66.830002,-66.830002,-66.669998,-66.669998,-66.419998,-66.750000,-66.750000,-66.500000,-66.580002,-66.250000,-66.250000,-66.500000,-66.919998,-67,-67.169998,-66.919998,-66.330002,-66.080002,-66.169998,-66.080002,-66.169998,-66.080002,-66.330002,-66.330002,-66.500000,-66.580002,-66.669998,-66.750000,-67,-66.830002,-67,-67.500000,-67.580002,-67.500000,-67.500000,-67.830002,-68.250000,-68.419998,-68.250000,-68.500000,-68.330002,-68.669998,-68.580002,-68.580002,-69.080002,-69.330002,-69,-69.080002,-69.250000,-69.500000,-69.669998,-70.080002,-70.500000,-70.830002,-70.580002,-70.169998,-70.080002,-70.580002,-70.580002,-70.500000,-70.830002,-71.169998,-71.500000,-71.169998,-71.750000,-71.750000,-72,-72.500000,-72.830002,-73.169998,-73.250000,-73.669998,-74.080002,-74.169998,-74.500000,-74.830002,-75.169998,-75.669998,-76.080002,-76.500000,-76.919998,-77.330002,-77.750000,-78,-78.105576,-78.210770,-78.315582,-78.419998,-78.441284,-78.461708,-78.481285,-78.500000,-78.750000,-79.169998,-79.669998,-80,-80.500000,-81,-81.500000,-81.919998,-82.419998,-82.830002,-82.830002,-83.250000,-83.500000,-83.500000,-83.830002,NaN,-77.580002,-77.080002,-77.330002,-77.419998,-77.669998,-77.580002,NaN,-78.750000,-78.750000,-79.080002,-79.500000,-79.919998,-80.250000,-79.830002,-79.330002,-79.080002,-78.750000,NaN,-76.580002,-76.169998,-76.232872,-76.295502,-76.357880,-76.419998,-76.503151,-76.585869,-76.668159,-76.750000,-76.580002,NaN,-71.080002,-71.080002,-71,-70.919998,-70.830002,-70.580002,-70.080002,-69.580002,-69.080002,-68.919998,-68.830002,-69.419998,-70,-70.500000,-71,-71.500000,-71.919998,-72.330002,-72.580002,-72.669998,-72.580002,-72.250000,-72.169998,-71.830002,-71.669998,-71.330002,-71.080002,NaN,-70.580002,-70.250000,-70,-69.750000,-69.919998,-70.250000,-70.500000,-70.580002,-70.580002,NaN,-64.798996,-64.763367,-64.691940,-64.563293,-64.441841,-64.334740,-64.562935,-64.755997,-64.798996,NaN,-64.541351,-64.256035,-64.099403,-64.085098,-64.248779,-64.541351,NaN,-63.250000,-63,-63.105453,-63.210606,-63.315456,-63.419998,-63.440655,-63.460873,-63.480656,-63.500000,-63.250000,NaN,-62.232025,-62.126762,-62.007484,-61.957989,-61.985928,-62.077095,-62.161507,-62.232025,NaN,-62.788345,-62.689720,-62.668785,-62.506897,-62.457500,-62.478474,-62.569904,-62.675510,-62.788345,NaN,-60.630001,-60.330002,-60.423199,-60.515934,-60.608204,-60.700001,-60.683739,-60.666649,-60.648735,-60.630001,NaN,0,0.67000002,1,1.2500000,1.6700000,1.7500000,2.1700001,2.6700001,2.6700001,3.2500000,3.6700001,4,4.5000000,5,5.5000000,6.1700001,6.5799999,7,7.4200001,8,8.3299999,8.3299999,8.7500000,9,9,8.5799999,8.3299999,8.3299999,8.1700001,7.8299999,7.7475381,7.6650510,7.5825381,7.5000000,7.4375525,7.3750696,7.3125520,7.2500000,7.1700001,7.7500000,7.7500000,8.0799999,8.2500000,8.3299999,8.1700001,8.4200001,8.5000000,9,9.3299999,9.6700001,10,9.6700001,9.8299999,9.9200001,10.330000,10.750000,11.170000,11.500000,11.830000,12.250000,12.580000,12.685040,12.790054,12.895041,13,13.000041,13.000055,13.000041,13,13.105042,13.210056,13.315042,13.420000,13.420000,13.170000,13.170000,13.170000,13.420000,13.420000,13.670000,13.920000,13.920000,14.080000,14.330000,14.670000,15,15.420000,15.670000,15.920000,16.080000,16.170000,16.170000,15.920000,15.670000,15.830000,16,16.080000,16.330000,16.580000,16.670000,16.920000,17.080000,17.250000,17.670000,17.670000,18,18,18.080000,18.330000,18.750000,19.080000,19.330000,19.830000,20.330000,20.580000,20.830000,21.170000,21.500000,21.750000,22.420000,22.750000,23.170000,23.500000,24,24.330000,24.670000,25.250000,25.500000,25.750000,26,26.330000,26.670000,26.670000,27,27.420000,27.420000,27.920000,28,28.500000,29,29.500000,29.920000,30.250000,30.750000,31.170000,31.330000,31.580000,31.500000,31.750000,31.420000,31,30.580000,30.170000,29.830000,29.580000,29.170000,28.750000,28.330000,27.830000,27.500000,27,26.500000,26,25.500000,25.170000,24.830000,24.830000,24.670000,24.250000,24.250000,23.750000,23.330000,22.830000,23.500000,23.830000,24.250000,24.580000,24.830000,25.170000,25.670000,26.170000,26.420000,26.750000,26.750000,27,27.170000,27.500000,27.830000,27.750000,28,28.420000,28.750000,29.080000,29.500000,29.670000,30.250000,30.330000,30.330000,30.750000,31,31.250000,31.580000,32,32.500000,33,33.419998,33.750000,33.750000,34.080002,34.080002,34.250000,34.419998,34.580002,35.080002,35.580002,36,36.330002,36.580002,37,37,37.330002,37.750000,37.500000,37.919998,38.080002,38.169998,37.919998,38,38,38.330002,38.580002,38.919998,39.330002,39.669998,40,40.250000,40.500000,41,41.500000,42,42.330002,42.830002,43.419998,44,44.500000,45,45.419998,45.830002,46.169998,46.169998,46.330002,46.669998,47,47.500000,47.919998,48.169998,48.419998,48.169998,48.169998,48.169998,47.919998,47.500000,47.669998,47.500000,48,48.105087,48.210117,48.315090,48.419998,48.460022,48.500027,48.540020,48.580002,48.685089,48.790119,48.895088,49,49.250000,49.750000,49.500000,49.750000,50.080002,50.419998,50.669998,50.830002,51.169998,51.500000,51.830002,52.330002,52.580002,53.169998,53.419998,53.919998,54.169998,54.419998,54.919998,54.750000,55,55.330002,55.330002,55.750000,56.080002,56.080002,56.250000,55.830002,55.250000,54.669998,55.080002,55.330002,55.580002,55.919998,56.330002,56.250000,56.750000,57.080002,56.919998,57.250000,57.580002,57.250000,57,57.419998,57.919998,58.250000,58.669998,58.250000,58.250000,57.919998,57.419998,56.830002,56.169998,56.169998,56.750000,57.250000,57.669998,58.169998,58.419998,58.750000,59.169998,59.419998,59.919998,59.669998,59.750000,60,60,60,60.250000,60.580002,60.830002,60.830002,61,60.419998,59.919998,59.919998,59.580002,59.250000,59.169998,59.500000,59.669998,60.169998,60.750000,60.919998,60.919998,61.002674,61.085232,61.167675,61.250000,61.250389,61.250519,61.250389,61.250000,60.919998,60.580002,60.080002,59.669998,59.419998,59.080002,58.919998,58.500000,58.169998,57.830002,57.419998,57,56.669998,56.419998,56,55.830002,55.580002,55.419998,55.169998,55,54.669998,54.330002,54.580002,55,55.250000,55.669998,55.919998,56,56,56.500000,56.830002,57.250000,57.580002,58.169998,58.750000,58.669998,58.750000,58.419998,58.919998,58.919998,58.750000,59.169998,59.500000,60.080002,59.669998,59.669998,60.080002,60.580002,61.080002,61.500000,62.169998,62.669998,63,63.250000,63,63.419998,63.500000,64,64.419998,64.419998,64.830002,64.669998,64.419998,64.580002,64.500000,64.669998,65,65.330002,65.419998,65.460205,65.500275,65.540207,65.580002,65.685608,65.790817,65.895615,66,66.250000,66.500000,66.500000,66.080002,66.080002,66.419998,66.830002,67.169998,67.669998,67.980003,68.330002,68.830002,68.919998,69.080002,69.449997,69.919998,70.330002,70.419998,70.830002,70.830002,70.870003,71.330002,71.129997,70.870003,70.870003,70.480003,70.480003,70.470001,70.220001,70.220001,70,70.080002,70.080002,69.830002,69.620003,69.580002,69.320000,69,68.750000,69.169998,69.500000,69.580002,69.379997,69.669998,69.980003,70.250000,69.830002,70,70.580002,70.080002,70.080002,69.580002,69.419998,70,69.419998,69.370003,69.830002,69.830002,69.470001,69.220001,69,68.970001,68.720001,68.300003,68.169998,67.830002,67.830002,67.669998,67.830002,68,67.750000,67.580002,68,68.250000,68.580002,68.750000,68.900002,68.349998,68.029999,67.750000,67.580002,67.580002,67.669998,68.250000,68.580002,69,69.330002,69.830002,69.330002,68.750000,68.379997,67.820000,67.500000,67.980003,68,68.500000,69,69.419998,69.830002,70.419998,70.970001,71.500000,71.750000,72.250000,72.669998,73.169998,73.580002,74,74.169998,74.019997,73.830002,73.580002,73.580002,73.169998,72.750000,72.750000,72.580002,72.250000,71.919998,71.419998,71,70.669998,70.169998,69.750000,69.500000,69.080002,68.580002,69.250000,68.750000,68.330002,67.830002,67.250000,67.419998,67.830002,68.169998,68.750000,69.330002,69.830002,69.830002,69.669998,69.330002,69.199997,68.580002,68.580002,68.330002,67.830002,67.580002,67,66.580002,66.169998,66.330002,66.580002,66.500000,66.169998,65.500000,65,64.500000,64,64,63.419998,62.919998,62.750000,62.580002,62.080002,61.919998,61.500000,61,60.580002,60.169998,59.580002,59.080002,58.669998,58.750000,58.669998,58.669998,58.080002,57.669998,57.250000,56.919998,57.080002,57.250000,56.919998,56.750000,56.419998,56.315254,56.210339,56.105255,56,55.957840,55.915455,55.872841,55.830002,55.669998,55.250000,55.250000,55.250000,55,54.250000,53.830002,53.419998,52.919998,52.500000,52.080002,51.750000,51.330002,51,51.330002,51.669998,52.169998,52.669998,53.169998,53.169998,53.750000,54.169998,54.580002,54.830002,55.169998,55.580002,56,56.669998,57.250000,57.669998,58.250000,58.419998,58.750000,59.080002,59.169998,59.580002,60,60.500000,60.750000,61.169998,61.272541,61.375057,61.477543,61.580002,61.642731,61.705307,61.767731,61.830002,62.250000,62.500000,62.419998,62.250000,62.250000,62.419998,62.169998,61.830002,61.830002,61.580002,61.250000,61,61,60.919998,60.500000,60.080002,59.580002,59.250000,58.830002,58.750000,58.169998,58.419998,58.750000,59,59.419998,59.750000,60,60.330002,60,59.500000,59,58.500000,58,57.669998,57.330002,57.080002,56.750000,56.250000,55.919998,55.919998,55.669998,55.250000,55.169998,54.830002,54.750000,54.687695,54.625256,54.562695,54.500000,54.418034,54.335712,54.253033,54.169998,54.148277,54.126038,54.103275,54.080002,53.669998,53.669998,53.169998,52.750000,52.080002,51.830002,51.500000,51.419998,51.169998,50.830002,50.500000,50.169998,50.169998,50.080002,50.250000,50.250000,50.250000,50.330002,50.250000,50.250000,50.250000,50.080002,50.080002,49.750000,49.330002,49.330002,48.919998,48.580002,48.169998,47.830002,47.500000,47.169998,46.830002,47,47.330002,47.669998,48.080002,48.419998,48.669998,48.830002,49.080002,49.169998,49.250000,49.080002,48.830002,48.500000,48.250000,48.080002,48.080002,47.580002,47.750000,47.330002,46.750000,46.750000,46.250000,46.080002,45.750000,45.669998,45.830002,45.750000,46.169998,46.580002,47,46.830002,46.330002,46.247868,46.165489,46.082867,46,45.917786,45.835381,45.752785,45.669998,45.500000,45.169998,45,44.750000,44.500000,44.500000,44.169998,43.830002,43.500000,43.750000,44.169998,44.580002,44.919998,45.080002,45.419998,45.330002,45.669998,45.669998,45.330002,45.169998,45.169998,44.830002,44.580002,44.419998,44.250000,44.419998,44,43.830002,43.669998,43.500000,43.169998,42.830002,42.580002,42.330002,42.169998,41.750000,41.790001,42.020000,41.669998,41.500000,41.669998,41.500000,41.750000,41.419998,41.250000,41.250000,41.250000,41.080002,41.080002,40.830002,40.500000,40.330002,39.830002,39.330002,39,39.330002,39.500000,39,38.855141,38.710186,38.565140,38.419998,38.357552,38.295067,38.232552,38.169998,37.750000,37.250000,37.169998,37.669998,38,38,38.250000,38.419998,38.830002,39.169998,39.500000,39.330002,39,38.500000,38.169998,38.250000,37.919998,37.500000,37.169998,37.169998,36.830002,36.500000,36.110001,35.849998,36.209999,36.169998,36.080002,35.919998,35.919998,35.919998,35.580002,35.330002,35.330002,35,35,34.750000,34.669998,34.330002,34,33.919998,33.669998,33.330002,33,32.669998,32.419998,32,31.500000,31,30.500000,30,30,29.500000,29,28.500000,28.170000,27.580000,27,26.420000,25.830000,25.330000,25.170000,25.080000,25.500000,25.830000,26.330000,26.750000,27.080000,27.165005,27.250006,27.335005,27.420000,27.545017,27.670023,27.795017,27.920000,27.897573,27.875097,27.852573,27.830000,28.170000,28.580000,29.080000,29.170000,29.750000,30.080000,30,29.750000,29.670000,30.080000,30.250000,30.250000,30.500000,30.420000,30.330000,30.330000,30.670000,30.420000,30.500000,30.500000,30.250000,30.500000,30.080000,30,30.080000,30.080000,29.830000,29.670000,29.500000,29.170000,29,29.250000,29.330000,29.170000,29.080000,29.170000,29.500000,29.830000,29.580000,29.670000,29.830000,29.750000,29.750000,29.670000,29.420000,29.830000,29.790077,29.750103,29.710077,29.670000,29.565044,29.460058,29.355043,29.250000,29.187580,29.125107,29.062580,29,28.750000,28.670000,28.330000,28,27.670000,27.170000,26.670000,26.170000,25.750000,25.330000,24.830000,24.330000,23.830000,23.330000,22.830000,22.420000,21.920000,21.580000,21.250000,20.830000,20.500000,20.170000,19.670000,19.250000,19.250000,18.830000,18.670000,18.500000,18.170000,18.170000,18.330000,18.420000,18.670000,18.580000,18.420000,18.580000,18.830000,19.080000,19.250000,19.670000,20,20.420000,21,21.170000,21.250000,21.330000,21.500000,21.580000,21.500000,21.500000,21.330000,20.920000,20.500000,20,19.875004,19.750004,19.625004,19.500000,19.500000,19.500000,19.500000,19.500000,19.375004,19.250004,19.125004,19,18.420000,17.920000,18.330000,17.500000,17,16.330000,16,15.830000,15.580000,15.830000,15.670000,15.750000,15.920000,15.830000,15.920000,15.830000,15.750000,15.330000,15.170000,15,14.250000,13.830000,13.250000,12.750000,12.170000,11.670000,11.250000,10.830000,10.420000,10.420000,10,9.6700001,9.4200001,9,9,8.7500000,8.9200001,9.0799999,9.2500000,9.5799999,9.5799999,9.4200001,9.3299999,9,8.6700001,8.3299999,7.8299999,8.5799999,9,9.4200001,9.5000000,10,10.500000,10.830000,11,10.920000,11.250000,11.170000,11.420000,11.670000,11.670000,11.830000,12.170000,12.420000,12.330000,12.080000,11.670000,11.500000,11,10.580000,10.250000,9.7500000,9.4200001,9,9.1700001,9.7500000,10.330000,10.920000,11.080000,11.250000,11.500000,11.920000,12.170000,11.500000,11.500000,11.420000,11.170000,10.750000,10.420000,10.500000,10.500000,10.500000,10.580000,10.580000,10.330000,10.170000,10.080000,10.250000,10.670000,10.670000,10.670000,10.670100,10.670134,10.670100,10.670000,10.627704,10.585272,10.542704,10.500000,10.170000,9.7500000,9.8299999,9.6700001,9.5000000,9,8.4200001,8.5799999,8.2500000,7.9200001,7.5799999,7.1700001,6.7500000,6.8299999,6.5000000,6.2500000,5.9200001,5.8299999,5.8299999,5.8299999,5.9200001,5.9200001,5.8299999,5.6700001,5.5799999,5.4200001,5.1700001,4.8299999,4.5000000,4.2500000,3.7500000,3.1700001,2.5000000,1.8300000,1.7500000,1,0.50000000,0.17000000,-0.17000000,-0.67000002,-1.2500000,-1,-1.6700000,-1,-0.41999999,-0.17000000,-0.25000000,-0.17000000,-0.33000001,-1,-1,-1.4200000,-1.5800000,-0.82999998,-0.67000002,-0.67000002,-1,-1.1700000,-1.3300000,-1.6700000,-1.5000000,-1.9200000,-2.3299999,-2.8299999,-2.6700001,-2.4200001,-2.5000000,-2.7500000,-2.7500000,-3,-3,-2.8299999,-2.8299999,-3.1700001,-3.5000000,-3.8299999,-4.1700001,-4.5000000,-4.7500000,-5.0799999,-5.1700001,-5.1700001,-5.0799999,-5.2500000,-5.8299999,-6.4200001,-7,-7.5000000,-8.1700001,-8.6700001,-9.1700001,-9.5799999,-10,-10.420000,-10.750000,-11,-11.500000,-12,-12.580000,-13,-13.330000,-14,-14.500000,-15,-15.500000,-16,-16.580000,-17.170000,-17.670000,-18,-18.500000,-19,-19,-19.500000,-20,-20.500000,-21,-21.500000,-22,-22.250000,-22.500000,-22.920000,-22.920000,-23,-23,-22.920000,-23,-23.330000,-23.330000,-23.830000,-23.670000,-24,-24.170000,-24.580000,-25,-25.420000,-25.830000,-26.330000,-27,-27.500000,-28,-28.500000,-28.670000,-28.670000,-29,-29.500000,-30,-30.500000,-31,-31.500000,-31.830000,-32.169998,-32.500000,-33,-33.500000,-33.830002,-34.169998,-34.500000,-34.750000,-34.830002,-34.750000,-34.830002,-34.669998,-34.419998,-34.419998,-34,-34.330002,-34.669998,-35,-35.330002,-35.830002,-36.250000,-36.330002,-36.830002,-36.830002,-37.330002,-37.750000,-38.169998,-38.419998,-38.580002,-38.750000,-38.830002,-38.919998,-39,-39,-38.750000,-39.169998,-39.500000,-39.830002,-40.330002,-40.580002,-40.919998,-41.169998,-41.169998,-41,-40.750000,-40.812595,-40.875126,-40.937595,-41,-41.125023,-41.250031,-41.375023,-41.500000,-42.080002,-42.330002,-42.080002,-42.580002,-42.830002,-42.830002,-42.500000,-42.500000,-42.830002,-43,-43.330002,-43.669998,-44,-44.500000,-44.669998,-45,-45,-45.250000,-45.500000,-46,-46.500000,-46.830002,-47.169998,-47.169998,-47.500000,-48,-48.330002,-48.669998,-49,-49.500000,-50,-50.169998,-50.500000,-51,-51.419998,-51.830002,-52.330002,-52.250000,-52.250000,-52.250000,-52.500000,-52.500000,-52.750000,-53.250000,-53.750000,-53.830002,-53.669998,-53.419998,-53.169998,-52.830002,-52.750000,-53.169998,-53.419998,-53.169998,-52.919998,-52.669998,-52.580002,-52.169998,-52.419998,-52.250000,-51.750000,-51.830002,-51.500000,-51,-51.330002,-51.393047,-51.455734,-51.518051,-51.580002,-51.477589,-51.375114,-51.272587,-51.169998,-50.669998,-50.750000,-50.750000,-50.419998,-50,-50.750000,-50.169998,-50.107590,-50.045116,-49.982586,-49.919998,-49.897701,-49.875267,-49.852703,-49.830002,-49.419998,-49.169998,-48.580002,-48.169998,-47.830002,-47.750000,-48.330002,-47.830002,-47.419998,-46.830002,-46.830002,-46.669998,-46.919998,-46.580002,-46.169998,-45.919998,-45.830002,-45.580002,-45.250000,-45,-44.580002,-44.169998,-43.830002,-44.169998,-44.169998,-44.419998,-44.669998,-45,-45.169998,-45.500000,-45,-44.669998,-44.419998,-44.169998,-43.750000,-43.419998,-43,-42.330002,-42.290051,-42.250069,-42.210052,-42.169998,-42.127552,-42.085068,-42.042549,-42,-41.917549,-41.835068,-41.752552,-41.669998,-41.627705,-41.585270,-41.542702,-41.500000,-41.830002,-41.750000,-41.419998,-41,-40.580002,-40,-39.500000,-39,-38.580002,-38.169998,-37.750000,-37.169998,-37.169998,-37.169998,-36.669998,-36.500000,-36,-35.500000,-35,-34.500000,-34,-33.669998,-33.169998,-32.500000,-32.169998,-31.830000,-31.330000,-30.750000,-30.250000,-30,-29.330000,-29,-28.500000,-28,-27.500000,-27,-26.330000,-25.750000,-25.420000,-25,-24.500000,-24,-23.500000,-23,-23,-22.500000,-22,-21.500000,-21,-20.500000,-20,-19.330000,-18.750000,-18.250000,-17.830000,-17.670000,-17.250000,-17,-16.670000,-16.580000,-16.250000,-15.830000,-15.750000,-15.330000,-15,-14.670000,-14.170000,-13.670000,-13,-12.500000,-12.170000,-11.830000,-11.330000,-10.830000,-10.170000,-10.170000,-9.6700001,-9.1700001,-8.6700001,-8.1700001,-7.8299999,-7.2500000,-6.8299999,-6.5000000,-6.2500000,-6,-5.6700001,-5.1700001,-4.6700001,-4.2500000,-3.8299999,-3.5000000,-3.3299999,-2.8299999,-2.5000000,-2.5000000,-3,-2.5000000,-2.3299999,-2.1700001,-1.6700000,-1,-0.82999998,-0.33000001,0,NaN,66.080002,66.129997,66.250000,66,65.750000,65.580002,65,65,65.330002,65.669998,65.330002,64.830002,65.370003,65.820000,65.669998,66.080002,66.419998,66.330002,66.353714,66.376617,66.398712,66.419998,66.482834,66.545448,66.607834,66.669998,66.919998,67.080002,66.750000,66.580002,66.370003,66.080002,NaN,61.169998,60.830002,60.830002,61,60.919998,61.250000,61.419998,61.580002,62.080002,62.330002,62.353298,62.376064,62.398300,62.419998,62.482578,62.545105,62.607578,62.669998,62.670914,62.671219,62.670914,62.669998,62.830002,62.830002,62.669998,62.419998,62.080002,62,62.169998,62.419998,62.419998,62.169998,62.085228,62.000305,61.915226,61.830002,61.810383,61.790512,61.770382,61.750000,61.419998,61.169998,61.169998,NaN,58.669998,58.580002,58.919998,59.080002,59.080002,59.122997,59.165661,59.207996,59.250000,59.292740,59.335323,59.377743,59.419998,59.419998,59.669998,59.669998,59.250000,59,58.669998,NaN,56.330002,56.580002,57,57.419998,57.669998,58.169998,57.750000,57.667580,57.585106,57.502579,57.419998,57.315083,57.210110,57.105080,57,56.917545,56.835064,56.752548,56.669998,56.330002,NaN,53.330002,53,52.500000,52.250000,51.919998,51.919998,51.419998,51.580002,51.169998,50.750000,50.330002,50.500000,51.169998,51.580002,52.169998,52.669998,53.169998,53.669998,53.750000,53.750000,53.330002,NaN,46.669998,46.669998,46.919998,46.500000,46.750000,47,47.419998,47.419998,47.080002,46.750000,46.830002,46.419998,46.419998,46.669998,46.750000,46.500000,46.500206,46.500271,46.500206,46.500000,46.605049,46.710068,46.815052,46.919998,47.330002,47.580002,47.919998,47.919998,48.250000,48.750000,48.750000,49,48.669998,48.419998,48.080002,47.830002,47.830002,47.669998,47.330002,47,46.669998,NaN,44.580002,44.665459,44.750614,44.835461,44.919998,44.815052,44.710068,44.605049,44.500000,44.417503,44.335007,44.252506,44.169998,43.580002,43.169998,42.750000,42.169998,42.045090,41.920116,41.795090,41.669998,41.670143,41.670193,41.670143,41.669998,41.830002,42.169998,42.750000,43.250000,43.669998,44.080002,44.500000,44.919998,45.169998,45.669998,45.670204,45.670273,45.670204,45.669998,45.627644,45.585194,45.542645,45.500000,45.330002,45,44.419998,43.919998,43.580002,43.919998,44.080002,43.580002,43.580002,43.080002,43.330002,43.919998,44.419998,44.830002,45.169998,44.750000,44.500000,44.582588,44.665119,44.747589,44.830002,44.977703,45.125271,45.272705,45.419998,45.919998,46.080002,46.169998,46.169998,46.250000,46.250000,45.919998,45.919998,46,45.919998,45.750000,45.750000,45.419998,45,44.580002,NaN,45.830002,45.830002,45.919998,45.500000,45.669998,45.830002,NaN,41.750000,41.500000,41.500000,41.580002,41.830002,42,42.250000,42.500000,42.830002,42.830002,42.830002,42.580002,42.669998,42.580002,42.250000,42,42,41.750000,NaN,43.250000,43.169998,43.330002,43.330002,43.250000,43.330002,43.500000,44,44.330002,44.169998,43.919998,44,43.919998,43.830002,43.669998,43.250000,NaN,0.079999998,-0.33000001,-0.75000000,-1.0800000,-0.92000002,-0.67000002,-0.41999999,0.079999998,NaN,-41.830002,-42,-42.330002,-42.669998,-43,-43.419998,-43.330002,-42.669998,-42.330002,-41.830002,NaN,-52.580002,-53,-53.330002,-53.669998,-54,-54.250000,-54.500000,-54.669998,-54.669998,-54.919998,-55,-55,-55.250000,-55.250000,-55.669998,-55.419998,-55.500000,-55.330002,-55,-55.169998,-55,-54.669998,-54.669998,-54.419998,-54.419998,-54.080002,-54.080002,-53.830002,-53.580002,-53.330002,-53.250000,-53,-52.750000,-53,-53.250000,-53.580002,-53.830002,-54,-54.169998,-53.669998,-54.169998,-54.190086,-54.210114,-54.230083,-54.250000,-54.125004,-54.000008,-53.875004,-53.750000,-53.687939,-53.625587,-53.562939,-53.500000,-53.330002,-53.500000,-53.330002,-52.830002,-52.830002,-52.580002,-52.669998,-52.580002,NaN,-51.830002,-52,-51.750000,-51.419998,-51.330002,-51.500000,-51.330002,-51.500000,-51.830002,-52,-52.250000,-52.330002,-52.080002,-52,-52.250000,-51.830002,NaN,-54,-54.080002,-54.330002,-54.580002,-54.919998,-54.500000,-54.250000,-54,NaN,10,10.170000,10.580000,10.670000,10.750000,10.250000,10,10,NaN,18.170000,18.330000,18.500000,18.420000,18.330000,18.170000,17.830000,17.830000,17.920000,17.750000,17.830000,18.170000,18.170000,NaN,21.770000,21.980000,21.820000,21.747513,21.675016,21.602512,21.530001,21.505060,21.480082,21.455061,21.430000,21.469999,21.600000,21.770000,NaN,21.830000,22,22.330000,22.580000,22.830000,22.920000,23,23.170000,23.170000,23,23,22.830000,22.670000,22.330000,22.330000,22.170000,21.920000,21.670000,21.500000,21.170000,21.080000,21,20.580000,20.670000,20.580000,20.250000,20.250000,20.080000,20.080000,20,19.830000,19.830000,19.920000,19.920000,19.830000,19.830235,19.830313,19.830235,19.830000,19.892532,19.955044,20.017532,20.080000,20.330000,20.670000,20.670000,21,21.420000,21.580000,21.500000,21.670000,21.750000,22,22,22.080000,22.330000,22.500000,22.580000,22.670000,22.420000,22.170000,22.170000,22.085016,22.000021,21.915016,21.830000,21.830246,21.830328,21.830246,21.830000,NaN,18.330000,18.580000,18.500000,18.330000,18.330000,18.392586,18.455116,18.517588,18.580000,18.685087,18.790117,18.895088,19,19.330000,19.670000,19.670000,19.670000,19.920000,19.920000,19.670000,19.830000,19.830000,19.750000,19.670000,19.330000,19.330000,19.080000,18.920000,18.500000,18.080000,18.420000,18.420000,18.250000,18.170000,18.420000,18.250000,18,17.580000,18.080000,18.170000,18.080000,18.170000,18.170000,18,18.330000,NaN,18,18.500000,18.500000,18.500000,18.250000,18,18,17.920000,18,NaN,16.368876,16.281084,16.458225,16.502964,16.471733,16.367208,16.265434,16.177479,16.236788,16.038425,15.954261,16.068899,16.329487,16.368876,NaN,14.548387,14.855312,14.965632,14.961621,14.780305,14.540425,14.548387,NaN,25.170000,25.170000,24.670000,24.330000,24.247538,24.165051,24.082539,24,23.917517,23.835024,23.752518,23.670000,24.170000,24.580000,24.830000,25.170000,NaN,20.920000,21.170000,21.080000,21.330000,20.920000,20.920000,NaN,26.565067,26.591459,26.800030,26.746765,26.747498,26.603350,26.625160,26.475895,26.565067,NaN,26.887417,26.932390,26.909651,26.553053,26.288774,26.260998,25.878109,25.848993,25.995365,26.119013,26.183361,26.270609,26.437401,26.553743,26.615993,26.852219,26.887417,NaN,25.564178,25.563662,25.489418,25.297565,25.148275,25.049494,24.752029,24.640400,24.746243,24.797119,24.839926,24.919060,25.018141,25.132404,25.256622,25.423887,25.564178,NaN,24.684805,24.631353,24.145220,24.170549,24.126799,24.218735,24.489990,24.516300,24.684805,NaN,23.692522,23.371677,23.162100,23.130779,22.905905,22.856956,23.065800,23.143841,23.354691,23.619373,23.692522,NaN,22.738977,22.561037,22.315899,22.250759,22.316050,22.380600,22.470383,22.560038,22.734215,22.854620,22.696627,22.738977,NaN,40.580002,40.830002,40.919998,41,41.169998,41,40.750000,40.669998,40.580002,NaN,49.830002,49.830002,49.750000,49.580002,49.419998,49.080002,49.080002,49.169998,49.330002,49.580002,49.830002,NaN,46.669998,46.919998,46.580002,46.419998,46.419998,46.500000,46.250000,45.919998,46.169998,46.419998,46.669998,NaN,62.169998,62.580002,62.750000,62.750000,62.669998,62.250000,62.169998,NaN,62.330002,62.330002,61.919998,61.500000,61.750000,62.330002,NaN,56.250000,56.580002,56.330002,55.750000,56.169998,55.919998,55.920254,55.920341,55.920254,55.919998,56.022827,56.125439,56.227829,56.330002,56.250000,NaN,53,53.169998,53.080002,52.669998,52.830002,53,NaN,47.919998,48.169998,48.500000,48.580002,49,49.500000,50.080002,50.580002,51,51.330002,51.580002,51.580002,51.080002,50.580002,50.250000,49.750000,50.080002,49.919998,49.669998,49.330002,49.419998,49.419998,49.419998,49.250000,48.830002,48.500000,48.580002,48.080002,47.750000,47.580002,48,48.080002,47.580002,47.669998,47.169998,46.669998,46.669998,47.080002,46.830002,47.330002,47.419998,47.330002,46.830002,46.919998,47.169998,47.500000,47.580002,47.580002,47.580002,47.669998,47.500000,47.919998,NaN,63.669998,64.080002,64.669998,65.250000,65.669998,66.080002,65.580002,65.169998,64.830002,64.500000,64.080002,63.830002,63.419998,63.750000,64,64,63.669998,63.250000,63.169998,63.669998,63.669998,NaN,67.669998,68.250000,68.250000,67.919998,67.500000,67.250000,67.169998,67.669998,NaN,71.750000,72.330002,72.750000,73.169998,73.580002,73.830002,73.830002,73.823387,73.816177,73.808380,73.800003,73.733498,73.666328,73.598488,73.529999,73.250000,72.830002,72.419998,72,71.669998,72.080002,72.500000,73,73.419998,73.750000,73.830002,73.580002,73.129997,72.669998,72.169998,72.169998,72.470001,72.470001,72.800003,72.699997,72.500000,72.580002,72.250000,71.750000,71.669998,71.419998,70.830002,70.500000,70.375359,70.250481,70.125359,70,69.895096,69.790123,69.685097,69.580002,69.478241,69.375984,69.273232,69.169998,69.128464,69.086288,69.043465,69,68.500000,68.080002,68.080002,67.669998,67.330002,67,66.669998,66.080002,65.669998,65.500000,65,65.330002,65.919998,66.419998,66.419998,65.750000,65.250000,64.830002,64.500000,64,63.580002,62.919998,62.919998,63.250000,63.580002,63.830002,63.419998,63.080002,62.669998,62.330002,61.919998,62,62.169998,62.419998,62.669998,62.830002,63,63.330002,63.750000,64,64.169998,64.419998,64.500000,64.250000,64.250000,64.250000,64.669998,65.080002,65.169998,65.500000,65.330002,65.330002,65.669998,66.169998,66.500000,66.919998,67.002762,67.085350,67.167763,67.250000,67.355064,67.460091,67.565063,67.669998,68.169998,68.500000,69,68.669998,69.330002,69.830002,70.250000,69.750000,69.580002,70,69.919998,70.080002,70.080002,70.419998,70.830002,71.330002,71.750000,NaN,73.750000,73.830002,73.779999,73.580002,73.169998,72.870003,72.980003,72.830002,72.980003,73.419998,73.750000,NaN,75,75.550003,75.550003,75.199997,74.669998,74.820000,75,NaN,77.029999,76.919998,76.650002,76.650002,76.370003,76.320442,76.270584,76.220436,76.169998,76.122597,76.075127,76.027596,75.980003,75.910789,75.841042,75.770775,75.699997,75.580002,75.820000,75.720001,75.720001,75.470001,75.080002,74.669998,74.500000,74.750000,74.419998,74.419998,74.470001,74.529999,74.750000,75.250000,75.669998,76.080002,76.330002,76.250000,76.669998,77.029999,NaN,80,80.449997,80.800003,81.250000,81.250000,80.800003,80.500000,80.419998,80.357689,80.295250,80.232689,80.169998,80.065071,79.960091,79.855072,79.750000,79.720886,79.691177,79.660881,79.629997,79.250000,79,78.529999,78.169998,78.169998,78.529999,78.980003,79.330002,79.720001,80,NaN,81.500000,81.919998,81.919998,81.919998,82.129997,82.330002,82.580002,82.919998,83.050003,82.980003,83.080002,83.080002,82.919998,82.800003,82.550003,82.419998,82.199997,81.949997,81.669998,81.419998,80.949997,80.580002,80.199997,79.720001,79.500000,79,78.500000,78,77.919998,77.580002,77.250000,76.830002,76.419998,76.169998,76.169998,76.500000,76.330002,76.419998,76.250000,76.330002,76.419998,76.830002,77.129997,77.160484,77.190643,77.220482,77.250000,77.292847,77.335464,77.377853,77.419998,77.830002,77.854462,77.877625,77.899475,77.919998,77.983818,78.046768,78.108833,78.124207,78.139526,78.154793,78.169998,78.206497,78.242958,78.279388,78.315788,78.461067,78.605812,78.750000,78.780624,78.810837,78.840630,78.870003,78.965103,79.060143,79.155106,79.250000,79.699997,79.870003,80.419998,80.250000,80.470001,80.629997,80.919998,80.800003,80.800003,80.669998,80.669998,81,81.500000,NaN,79.900002,80.169998,79.750000,79.900002,NaN,79.199997,79.379997,79.379997,79.199997,79.199997,78.879997,78.480003,78.129997,78.080002,78.480003,78.900002,78.550003,78.300003,78,77.970001,77.919998,77.750000,78.169998,78.169998,78.300003,78.529999,78.830002,79,79.199997,NaN,77.669998,77.830002,77.800003,77.570000,77.349998,77.470001,77.669998,NaN,77.669998,77.750000,77.430000,77.080002,77.180000,77.669998,NaN,76.580002,76.629997,76.370003,76,76.419998,76.699997,76.669998,76.379997,76,75.580002,75.070000,75.070000,75.629997,75.419998,75.830002,76.169998,76.580002,NaN,75.120003,75.470001,75.129997,75.120003,NaN,72.919998,73.070000,73.029999,73.500000,73.830002,74,73.919998,74.129997,74.005196,73.880264,73.755196,73.629997,73.515450,73.400597,73.285446,73.169998,73.123405,73.076210,73.028404,72.980003,72.419998,71.830002,71.669998,71.330002,71.830002,72.250000,72.250000,72.629997,72.919998,NaN,78.250000,78.500000,78.580002,78.379997,78.199997,78.169998,78.300003,78.250000,NaN,77.919998,78.080002,77.750000,77.699997,77.919998,NaN,77.750000,77.870003,78.019997,78.022888,78.025513,78.027885,78.029999,77.917511,77.805016,77.692513,77.580002,77.330002,77.419998,77.750000,NaN,75.580002,75.900002,76.129997,75.750000,75.480003,75.580002,NaN,76.250000,76.500000,76.879997,77.150002,77.330002,77.300003,77.580002,77.330002,77.080002,76.720001,76.300003,76.500000,76.169998,75.830002,75.919998,75.870003,76.250000,NaN,75.250000,75.669998,75.669998,76.129997,76.470001,76.419998,76.169998,75.919998,75.570000,75.554085,75.537109,75.519081,75.500000,75.582672,75.665230,75.747673,75.830002,75.897522,75.965034,76.032524,76.099998,76.137817,76.175430,76.212822,76.250000,76.332710,76.415283,76.497711,76.580002,76.800003,76.330002,76.019997,75.870003,75.470001,75.029999,74.949997,75,74.800003,74.529999,74.419998,74.500000,74.720001,74.919998,75.250000,74.970001,75.129997,75.250000,NaN,71.599998,72.029999,72.300003,72.580002,72.830002,73.019997,73.300003,73.300003,72.720001,73.080002,72.849998,73,72.669998,73.169998,73.669998,73.699997,73.419998,73.050003,72.580002,72.169998,71.629997,71.629997,71.050003,70.669998,70.400002,70.220001,69.750000,69.669998,69.300003,69,68.870003,69.150002,69.500000,69.169998,69,68.750000,68.650002,68.580002,69.250000,69.250000,69.500000,70.120003,70.169998,70.169998,70.419998,70.699997,70.669998,70.750000,71.029999,71.370003,71.599998,NaN,72.080002,72.500000,72.980003,73.500000,74.080002,74.250000,74.500000,74.250000,74.250000,73.830002,73.500000,73.199997,72.919998,72.580002,71.919998,71.419998,71.330002,71.080002,71.669998,72.080002,NaN,55.337139,55.371967,55.220909,54.897488,54.718967,54.747952,54.870407,54.861805,55.099033,55.146122,55.337139,NaN,52.919998,53,52.830002,52.750000,52.919998,NaN,51.713287,51.760422,51.886799,51.913162,51.866077,51.746857,51.713287,NaN,51.669998,51.919998,51.750000,51.669998,NaN,52.072304,52.090660,52.202759,52.271770,52.418468,52.174305,52.072304,NaN,52.750000,53.500000,53.580002,53.330002,53.169998,52.750000,NaN,53.330002,53.669998,54,54,53.700001,53.500000,53.330002,NaN,63.669998,63.669998,63.419998,63.330002,63.080002,63.419998,63.330002,63.669998,NaN,60.169998,60.250000,60.330002,60.250000,60,59.830002,59.919998,60.169998,NaN,57.250000,57.750000,58.080002,58.419998,58.169998,58.108124,58.045830,57.983120,57.919998,57.897686,57.875244,57.852684,57.830002,57.500000,57.330002,57,56.750000,57.250000,NaN,54.169998,54.080002,54.080002,53.580002,53.080002,52.750000,52.500000,52,52.419998,52.830002,53.330002,53.580002,54.169998,NaN,50.669998,50.830002,50.580002,50.419998,50.250000,49.750000,49.330002,48.919998,48.500000,48.330002,48.500000,48.750000,49,49,49.250000,49.419998,49.669998,49.919998,50.169998,50.669998,NaN,78.169998,78.580002,78.750000,79.019997,79.199997,79.750000,80.080002,80.080002,80.081978,80.082642,80.081978,80.080002,80.192726,80.305305,80.417732,80.529999,80.919998,81.180000,81.129997,81.419998,81.750000,82.080002,82.330002,82,82.470001,82.419998,82.830002,83.199997,83.419998,83.650002,83.580002,83.550003,83.250000,82.980003,82.849998,82.780579,82.710762,82.640572,82.570000,82.508514,82.446335,82.383499,82.320000,82.220001,82.229057,82.237083,82.244064,82.250000,82.205559,82.160736,82.115547,82.070000,82.074524,82.076035,82.074524,82.070000,81.972504,81.875000,81.777496,81.680000,81.750000,82.029999,82.029999,82.080002,81.800003,81.629997,81.370003,80.919998,81.080002,81.320000,81.580002,81.480003,81.800003,81.680000,81.590607,81.500793,81.410591,81.320000,81.179306,81.037376,80.894249,80.750000,80.419998,79.970001,79.529999,79.129997,78.830002,78.419998,77.919998,77.580002,77.080002,76.750000,76.919998,76.669998,76.300003,76.199997,75.699997,75.199997,74.669998,74.669998,74.669998,74.250000,74,73.830002,73.470001,73.419998,73.250000,73.200317,73.150414,73.100311,73.050003,73.017960,72.985611,72.952957,72.919998,72.419998,72.080002,72.300003,72.500000,72.169998,71.830002,71.419998,71,70.500000,70.419998,70.580002,71,71.330002,71.169998,70.669998,70.419998,70.169998,70.419998,70.169998,70.148315,70.126091,70.103317,70.080002,69.997734,69.915314,69.832733,69.750000,69.750000,69.419998,69.080002,68.830002,68.580002,68.419998,68.169998,68.169998,67.919998,67.500000,67.080002,66.669998,66.330002,66,65.669998,65.669998,65.500000,65.080002,65.169998,64.500000,64,63.500000,63,62.669998,62,61.500000,61,60.500000,60,59.830002,60.169998,60.169998,60.580002,60.750000,60.830002,61.419998,61.919998,62.500000,62.830002,63.580002,64,64.330002,64.919998,65.500000,66,66.500000,67,67.580002,68.169998,68.580002,68.580002,69.330002,69.919998,69.470001,69.300003,69.669998,70.250000,70.830002,70.800003,70.500000,71,71.169998,71.169998,71.750000,71.419998,71.419998,71.680000,72.169998,72.580002,73.169998,73.580002,74,74.500000,74.970001,75.320000,75.669998,75.820000,76.169998,76.169998,76.129997,75.919998,76.129997,76.379997,76.599998,76.800003,77.019997,77.250000,77.349998,77.580002,77.919998,77.870003,78.169998,NaN,65.500000,65.830002,66.169998,66.169998,66.419998,66.330002,66,65.419998,65.419998,65.580002,66.080002,65.830002,66.080002,66.169998,66,66.169998,66.500000,66.250000,66.330002,65.750000,65.500000,64.919998,64.419998,64.169998,63.830002,63.750000,63.419998,63.580002,63.830002,63.831982,63.832645,63.831982,63.830002,63.935360,64.040482,64.145363,64.250000,64.375214,64.500282,64.625214,64.750000,64.750000,65.080002,65.165352,65.250465,65.335350,65.419998,65.460274,65.500366,65.540276,65.580002,65.419998,65.500000,NaN,70.894814,71.017418,71.150528,71.152145,70.990669,70.922333,70.907082,70.806465,70.894814,NaN,75.400002,75.050003,75,75.400002,NaN,0,0.50000000,0.92000002,1.0800000,1.5000000,1.9200000,2.5000000,3.0799999,3.5000000,3.9200001,4,4.5000000,4.5000000,4.4200001,4.4200001,4.3299999,4.2500000,4.2500000,4.5799999,5.2500000,5.9200001,6.3299999,6.5000000,6.5000000,6.4200001,6.4200001,6.3299999,6.3299999,6.1700001,5.8299999,5.8299999,5.5000000,5.2500000,5.1700001,5,4.7500000,5,5.0799999,5.2500000,5.2500000,5.1700001,5.0799999,5,4.6700001,4.5799999,4.2500000,4.3299999,4.5000000,4.9200001,5.2500000,5.5799999,6.0799999,6.4200001,6.8299999,7.0799999,7.3299999,7.8299999,8.2500000,8.2500000,8.6700001,9.1700001,9.5799999,10,10.250000,10.670000,11.080000,11.250000,11.920000,11.830000,12.080000,12.330000,12.920000,13.420000,14,14.500000,14.750000,15,15.420000,15.830000,16.500000,17,17.500000,18,18.500000,19,19.500000,19.830000,20.330000,20.750000,20.750000,21.080000,21.580000,22.080000,22.330000,22.750000,23.420000,23.830000,24.250000,24.670000,25.250000,25.670000,26.170000,26.420000,26.670000,27,27.500000,27.920000,28,28.250000,28.670000,28.920000,29.330000,29.750000,30.330000,30.670000,31.500000,31.750000,32.169998,32.500000,32.830002,32.830002,33.250000,33.500000,33.669998,34,34.419998,34.830002,35.250000,35.750000,35.830002,35.500000,35.169998,35.250000,35.250000,35.330002,35.080002,35.169998,35.419998,35.750000,35.830002,35.919998,36.250000,36.500000,36.580002,36.669998,36.830002,36.830002,36.919998,36.919998,36.830002,36.669998,36.669998,36.750000,37,36.830002,37,36.830002,36.919998,37.169998,37.250000,37.169998,36.669998,36.919998,36.500000,36.330002,35.750000,35.580002,35.169998,34.750000,34.419998,34.169998,33.750000,33.580002,33.669998,33.250000,33,32.830002,32.830002,32.750000,32.669998,32.419998,32.250000,32.250000,31.750000,31.500000,31.250000,31.170000,31,30.670000,30.330000,30.250000,30.420000,30.670000,31.080000,31.500000,31.582521,31.665028,31.747520,31.830000,31.915047,32.000061,32.085045,32.169998,32.580002,32.750000,32.830002,32.750000,32.580002,32.169998,32.080002,31.920000,31.920000,31.500000,31.580000,31.500000,31.420000,31.250000,31.080000,31.080000,31.080000,30.830000,30.920000,31.170000,31.420000,31.500000,31.420000,31.080000,30.920000,30.690121,30.460159,30.230120,30,29.957544,29.915058,29.872543,29.830000,29.727545,29.625059,29.522543,29.420000,29,28.580000,28.170000,27.830000,27.420000,27.080000,26.670000,26.170000,25.750000,25.250000,24.830000,24.330000,24,23.580000,23.250000,22.750000,22.500000,22.250000,22.080000,21.500000,21.080000,20.750000,20.250000,19.670000,19.250000,18.670000,18.420000,18.420000,18,17.580000,17.080000,16.500000,16,15.580000,15.500000,15,14.750000,14.580000,14.080000,13.670000,13.250000,12.830000,12.420000,11.920000,11.670000,11.420000,11.080000,10.670000,10.420000,10.330000,10.500000,10.750000,10.670000,10.750000,11.080000,11.080000,11.250000,11.170000,11.170000,11.330000,11.500000,11.920000,11.750000,11,10.420000,10,9.4200001,8.9200001,8.5000000,8.1700001,7.6700001,7.2500000,6.7500000,6.3299999,5.7500000,5.4200001,5.0799999,4.5799999,4.1700001,3.7500000,3.4200001,3,2.5799999,2.2500000,1.9200000,1.7500000,1.4200000,1,0.75000000,0.75000000,0.41999999,0,-0.41999999,-0.92000002,-1.2500000,-1.7500000,-2.0799999,-2.5000000,-2.4200001,-3,-3.5799999,-4.1700001,-4.5799999,-5.0799999,-5.5799999,-6.0799999,-6.5799999,-7.0799999,-7.5799999,-8.1700001,-8.8299999,-9.4200001,-9.9200001,-10.170000,-10.500000,-11,-12.500000,-12,-12.420000,-13,-13,-13.580000,-14.080000,-14.670000,-15.170000,-15.580000,-16,-16.330000,-16.750000,-17.080000,-17.170000,-17.330000,-17.500000,-17.920000,-18.330000,-18.830000,-19,-19.420000,-19.670000,-20,-20.500000,-20.830000,-21.420000,-22.080000,-22.500000,-23.080000,-23.500000,-24,-24.500000,-24.750000,-24.920000,-24.920000,-25.170000,-25.330000,-25.500000,-26.080000,-26.250000,-26.580000,-27,-27.500000,-28.080000,-28.580000,-28.830000,-29.170000,-29.580000,-30,-30.500000,-30.920000,-31.330000,-31.670000,-32,-32.419998,-32.750000,-33,-33.330002,-33.669998,-33.750000,-33.750000,-34,-34,-34.250000,-34.169998,-34.169998,-34,-34.169998,-34.080002,-34.169998,-34.419998,-34.419998,-34.500000,-34.750000,-34.750000,-34.419998,-34.080002,-34.250000,-33.830002,-33.419998,-32.830002,-32.830002,-32.580002,-32,-31.420000,-31,-30.580000,-30,-29.580000,-29,-28.580000,-28.250000,-27.830000,-27.500000,-27,-26.420000,-26.420000,-25.920000,-25.500000,-25,-24.420000,-24,-23.500000,-22.920000,-22.500000,-22.080000,-21.670000,-21.250000,-20.830000,-20.250000,-19.750000,-19.250000,-18.830000,-18.500000,-17.920000,-17.420000,-17,-16.500000,-16,-15.500000,-15,-14.500000,-13.920000,-13.330000,-12.920000,-12.670000,-12.250000,-12.250000,-11.830000,-11.250000,-10.670000,-10.330000,-9.9200001,-9.4200001,-9.1700001,-8.6700001,-8.1700001,-7.7500000,-7.2500000,-6.7500000,-6.4200001,-6,-5.7500000,-5.3299999,-4.9200001,-4.5000000,-4.0799999,-3.7500000,-3.4200001,-3.0799999,-2.7500000,-2.2500000,-1.8300000,-1.3300000,-0.82999998,-0.50000000,0,NaN,30,30.920000,31.250000,31,31.080000,31.170000,31.500000,32,32.500000,33,33.500000,34.080002,34.500000,35,35.669998,36,36.330002,36.669998,36.919998,36.580002,36.580002,36.830002,36.500000,36.169998,36.169998,36.169998,36,36.169998,36.500000,36.750000,36.830002,36.419998,36.169998,36.330002,36.750000,36.750000,37,37,37.000198,37.000263,37.000198,37,37.082584,37.165115,37.247585,37.330002,37.392639,37.455185,37.517639,37.580002,37.919998,38.080002,38.250000,38.580002,38.330002,38.419998,38.669998,39.250000,39.500000,39.419998,40,40.250000,40.580002,40.500000,40.830002,40.919998,40.830002,40.919998,40.669998,40.669998,40.419998,40.169998,40.169998,40.580002,40,39.580002,39.250000,38.919998,38.669998,38.500000,38.169998,38.169998,38,38.169998,37.580002,37.919998,38,38.330002,38.299999,38.330002,38.750000,39.250000,39.580002,40,40.250000,40.750000,41.330002,41.750000,42,42.330002,42.580002,43,43.419998,43.500000,43.750000,44,44.330002,44.580002,45,45.330002,45,44.830002,44.830002,45.080002,45.419998,45.669998,45.750000,45.500000,45.500000,45.169998,44.919998,44.580002,44.250000,43.919998,43.669998,43.419998,43,42.580002,42.330002,42.080002,41.830002,41.830002,41.500000,41.330002,41.080002,40.830002,40.580002,40.169998,39.830002,39.919998,40.250000,40.330002,40.500000,40.500000,40.169998,39.669998,39.419998,39,38.830002,38.419998,38.169998,37.919998,37.919998,38.169998,38.580002,38.830002,39.250000,39.669998,40,40.169998,40.580002,40.669998,40.919998,41.250000,41.250000,41.500000,41.919998,42.330002,42.330002,42.669998,43.080002,43.500000,44,44.080002,44.080002,44.250000,44.330002,44.169998,43.830002,43.669998,43.419998,43.080002,43,43.250000,43.330002,43.500000,43.250000,43,42.500000,41.919998,41.669998,41.330002,41.169998,41,40.419998,39.919998,39.500000,39.080002,38.997700,38.915268,38.832699,38.750000,38.667770,38.585358,38.502769,38.419998,38.080002,37.669998,37.669998,37.169998,36.750000,36.750000,36.750000,36.750000,36.750000,36.669998,36.500000,36.080002,36.250000,36.750000,37,37.250000,37.250000,37.080002,37.169998,37.080002,37.500000,38,38.500000,38.500000,38.830002,39.330002,39.669998,40.250000,40.750000,41.169998,41.669998,42,42.419998,43,43.250000,43.330002,43.330002,43.750000,43.500000,43.500000,43.580002,43.500000,43.330002,43.500000,43.419998,43.330002,43.419998,43.669998,44.250000,44.669998,45.250000,45.830002,46.250000,46.500000,46.750000,47,47.330002,47.500000,47.580002,47.830002,47.830002,48,48.500000,48.580002,48.750000,48.830002,48.500000,48.500000,48.580002,48.580002,49.169998,49.669998,49.669998,49.250000,49.330002,49.250000,49.669998,49.830002,49.919998,50.080002,50.500000,50.830002,51,51.250000,51.419998,51.750000,52.080002,52.419998,52.830002,52.919998,52.419998,52.250000,52.500000,52.750000,52.830002,53.250000,53.419998,53.419998,53.419998,53.669998,53.669998,53.500000,53.830002,54.080002,54.330002,54.500000,54.830002,55.330002,55.580002,56,56.500000,56.830002,57.080002,57.169998,57.500000,57.580002,57.250000,56.830002,56.500000,56.500000,56.169998,56,55.500000,55,54.750000,54.500000,54.250000,53.919998,53.919998,53.919998,54.169998,54.330002,54.419998,54.669998,54.330002,54.169998,54,53.919998,54.169998,54.250000,54.580002,54.750000,54.830002,54.330002,54.330002,54.500000,54.919998,55.169998,55.669998,56.169998,56.750000,57.080002,57.580002,57.669998,57.419998,57.080002,57,57.250000,57.750000,58.250000,58.250000,58.330002,58.750000,59.169998,59.419998,59.500000,59.580002,59.419998,59.419998,59.669998,60,59.958210,59.915947,59.873207,59.830002,59.935123,60.040165,60.145126,60.250000,60.169998,60.580002,60.580002,60.419998,60.250000,60.080002,60,60.169998,60.419998,60.669998,61,61.500000,62,62.500000,63,63.419998,63.919998,64.330002,64.330002,64.830002,65,65.500000,65.830002,65.750000,65.750000,65.830002,65.500000,65.330002,65.080002,64.750000,64.500000,64.169998,63.830002,63.580002,63.330002,63,62.500000,62.250000,61.750000,61.250000,60.830002,60.500000,60.169998,59.830002,59.580002,59.330002,59.169998,58.919998,58.580002,58.580002,58.250000,57.750000,57.330002,56.750000,56.169998,56.169998,56.169998,55.750000,55.419998,55.419998,55.419998,55.750000,56.169998,56.500000,56.919998,57.419998,58,58.500000,59.080002,59.330002,59,59,58.580002,58.250000,58,58.080002,58.330002,58.580002,59,59.330002,59.330002,59.250000,59.580002,59.919998,60.330002,60.750000,60.855019,60.960026,61.065022,61.169998,61.252621,61.335163,61.417622,61.500000,61.582573,61.665100,61.747574,61.830002,61.915379,62.000507,62.085384,62.169998,62.500000,62.919998,63,63.330002,63.750000,63.500000,63.919998,64.330002,64.919998,65.250000,65.750000,66.169998,66.580002,67,67.419998,67.830002,68.330002,68.250000,68.169998,67.830002,68.250000,68.250000,68.293488,68.336327,68.378494,68.419998,68.482689,68.545250,68.607689,68.669998,68.732956,68.795609,68.857956,68.919998,69.250000,68.750000,69,68.669998,68.752953,68.835609,68.917961,69,69.020187,69.040245,69.060181,69.080002,69.419998,69.580002,70.080002,70.080002,70.250000,70.669998,70.919998,70.669998,71,71.169998,70.580002,70.919998,70.500000,71.080002,70.919998,70.669998,70.419998,70.080002,70.103317,70.126091,70.148315,70.169998,70.085823,70.001099,69.915817,69.830002,69.750000,69.750000,69.919998,69.750000,69.419998,69.330002,69.169998,68.919998,68.580002,68.250000,68,67.669998,67.250000,66.750000,66.419998,66.169998,66.080002,66.250000,66.330002,66.419998,66.669998,66.830002,66.915497,67.000664,67.085503,67.169998,67.045197,66.920265,66.795197,66.669998,66.419998,66,65.500000,65.080002,64.580002,64.330002,63.919998,63.919998,63.919998,64.419998,64.419998,64.830002,65.169998,65.080002,64.830002,64.669998,64.580002,65.080002,65.185158,65.290207,65.395157,65.500000,65.582924,65.665565,65.747925,65.830002,66.080002,66.419998,66.330002,66.169998,66.500000,67,67.169998,67.669998,68.250000,68.669998,68.500000,68.500000,68.250000,67.830002,67.750000,67.645195,67.540260,67.435196,67.330002,67.290482,67.250641,67.210480,67.169998,66.830002,66.830002,66.830002,67.080002,67.669998,67.830002,68.080002,68.330002,68.500000,68.750000,69,68.500000,68.169998,68.500000,68.580002,68.500000,68.830002,69,68.419998,68.330002,68.669998,68.750000,69,69.330002,69.669998,69.919998,70.169998,70.500000,70.080002,69.750000,69.669998,69.330002,69.250000,69.250000,69,68.830002,68.500000,68.250000,68.750000,69,69.500000,69.669998,70,70.419998,70.830002,71.250000,71.580002,72,72.500000,72.919998,73.330002,73.373032,73.415710,73.458031,73.500000,73.417610,73.335152,73.252609,73.169998,73.107552,73.045067,72.982552,72.919998,72.858543,72.796387,72.733536,72.669998,72.584999,72.500000,72.415001,72.330002,72.227577,72.125107,72.022583,71.919998,71.815170,71.710228,71.605171,71.500000,71.395355,71.290466,71.185349,71.080002,70.955002,70.830002,70.705002,70.580002,70.455002,70.330002,70.205002,70.080002,69.935005,69.790009,69.645004,69.500000,69.375000,69.250000,69.125000,69,68.895554,68.790733,68.685547,68.580002,68.580002,68.169998,67.750000,67.330002,67,66.669998,66.250000,66.500000,66.830002,67.250000,67.669998,68.250000,68.750000,68.812965,68.875618,68.937965,69,69.021362,69.041817,69.061363,69.080002,69.669998,70.169998,70.580002,71,71.330002,71.830002,72,72.330002,72.669998,72.919998,73.080002,72.750000,72.250000,71.830002,71.330002,71.169998,71.169998,71,71.250000,71.500000,71.919998,72.080002,71.830002,72,72.083344,72.166122,72.248344,72.330002,72.392761,72.455353,72.517769,72.580002,72.330002,72.330002,72.080002,71.669998,71.710762,71.751015,71.790764,71.830002,71.935211,72.040276,72.145210,72.250000,72.419998,72.919998,73.500000,73.580002,73.669998,73.830002,73.919998,74.330002,74.669998,75,75.330002,75.580002,75.750000,76.080002,76.080002,76.080002,76.144409,76.207558,76.269424,76.330002,76.247543,76.165054,76.082542,76,76.045380,76.088852,76.130394,76.169998,76.252563,76.335091,76.417564,76.500000,76.500000,77,77.419998,77.750000,77.668884,77.586830,77.503868,77.419998,77.336189,77.251572,77.166168,77.080002,77.081093,77.081459,77.081093,77.080002,77.060806,77.041069,77.020805,77,76.875427,76.750565,76.625420,76.500000,76.500740,76.500984,76.500740,76.500000,76.750000,76.750000,76.669998,76.500000,76.169998,75.750000,75.250000,74.919998,74.500000,74.169998,73.750000,73.580002,73.169998,73.169998,73.330002,73.500000,73.500000,73.562698,73.625267,73.687698,73.750000,73.812698,73.875259,73.937698,74,73.830002,73.669998,73.669998,73.500000,73.669998,73.750000,73.580002,73.580002,73.169998,73,72.919998,73,73.330002,73.669998,73.669998,73.419998,73.250000,72.750000,72.250000,71.830002,71.330002,70.919998,70.750000,70.750000,71.080002,71.500000,71.919998,71.500000,71.330002,71.580002,71.669998,71.500000,71.580002,71.561241,71.541656,71.521240,71.500000,71.605118,71.710159,71.815125,71.919998,72.250000,72.500000,72.500000,72.830002,72.750000,72.669998,72.580002,72.330002,72.330002,72.169998,71.669998,71.419998,71.419998,71.169998,70.830002,70.919998,70.919998,71.080002,71,71,70.919998,70.669998,70.565056,70.460075,70.355057,70.250000,70.145134,70.040176,69.935127,69.830002,69.768234,69.705971,69.643227,69.580002,69.580002,69.669998,69.580002,69.419998,69.669998,70,69.830002,69.580002,69.580002,69.250000,69.080002,68.750000,68.830002,69.080002,69.500000,70.080002,70,69.919998,69.830002,69.830002,69.580002,69.419998,69.169998,69.080002,69.080002,68.750000,68.419998,68.169998,67.830002,67.500000,67.080002,67.080002,66.919998,66.500000,66.395607,66.290802,66.185600,66.080002,66.017845,65.955460,65.892845,65.830002,65.500000,65.500000,65,64.669998,64.250000,64.419998,64.750000,65,65.419998,65.580002,65.419998,65.500000,65.919998,66.330002,66,65.669998,65.169998,65.050003,65.050003,64.919998,64.669998,64.750000,64.330002,64.330002,64,63.500000,63,62.669998,62.250000,62.500000,62.500000,62.250000,62.080002,61.750000,61.669998,61.330002,61,60.669998,60.419998,60.419998,59.919998,60.250000,60.500000,60.580002,60.419998,60.169998,59.750000,60.330002,60.169998,59.830002,60,59.830002,59.419998,59,58.580002,58.169998,57.750000,57.919998,57.669998,57.250000,56.830002,56.669998,56.169998,56,56.250000,56.080002,55.669998,55.169998,54.750000,54.500000,54.500000,54.580002,54.419998,54.080002,53.580002,53.169998,53.169998,52.830002,52.250000,51.669998,51.250000,50.919998,51.250000,51.669998,52.169998,52.750000,53.330002,53.919998,54.330002,54.830002,55.250000,55.830002,56.330002,56.830002,57,57.419998,57.750000,57.750000,58,58.419998,58.830002,58.830002,59.250000,59.669998,60.080002,60.419998,60.669998,60.830002,61.169998,61.750000,62.250000,62.500000,62.669998,62.500000,62.080002,61.669998,61.580002,61.250000,60.919998,60.580002,60.919998,61.250000,61.395172,61.540230,61.685173,61.830002,61.790470,61.750626,61.710468,61.669998,61.830002,61.750000,61.580002,61.169998,60.750000,60.419998,60,59.500000,59.500000,59.419998,59.357582,59.295113,59.232582,59.169998,59.148487,59.126316,59.103485,59.080002,59.169998,59,58.830002,58.830002,59.080002,59.330002,59.580002,59.500000,59.580002,59.750000,59.669998,59.419998,59.250000,59.330002,59.250000,59.419998,59.169998,59.330002,59.330002,59.330002,59.250000,59,58.669998,58.419998,58.080002,57.750000,57.500000,57.500000,57.169998,56.830002,56.330002,55.919998,55.580002,55.169998,54.919998,54.669998,54.500000,54.580002,54.169998,53.750000,54.169998,54.250000,53.830002,53.747589,53.665119,53.582588,53.500000,53.543159,53.585880,53.628162,53.669998,54.169998,54.169998,54,53.750000,53.500000,53.250000,52.830002,52.419998,52.169998,51.830002,51.419998,51,50.500000,50.500000,50,49.419998,49,48.500000,48,47.500000,47.080002,46.500000,46.080002,45.669998,45.250000,44.750000,44.330002,43.919998,43.419998,43.169998,42.830002,42.669998,42.919998,43.250000,43.250000,43,42.580002,42.580002,42.250000,42.080002,41.580002,41.330002,40.830002,40.669998,40.669998,40.330002,40.080002,39.919998,39.897701,39.875267,39.852699,39.830002,39.767525,39.705032,39.642525,39.626892,39.611263,39.595631,39.580002,39.559383,39.538765,39.518143,39.497524,39.415031,39.332523,39.250000,39.187702,39.125267,39.062698,39,38.669998,38.250000,37.919998,37.500000,37,36.500000,36,35.580002,35.169998,34.919998,34.830002,34.669998,34.330002,34.830002,35.330002,35.750000,36.330002,36.919998,37,37.419998,37.750000,37.669998,38.080002,38.080002,38.500000,38.919998,39.419998,39.580002,39.669998,39.830002,39.750000,39.580002,39.419998,39.080002,38.830002,38.750000,39.169998,39.500000,39.750000,40,40.419998,40.830002,40.919998,40.580002,40.169998,40,39.750000,39.419998,39.169998,39.080002,39.250000,38.919998,38.580002,38.250000,38.250000,38,37.750000,37.330002,37.080002,37.080002,37.330002,37.580002,37.750000,37.500000,37.419998,37.419998,37.397697,37.375263,37.352695,37.330002,37.205048,37.080067,36.955048,36.830002,37,36.750000,36.580002,36.169998,35.919998,35.580002,35.250000,34.830002,34.580002,34.330002,33.830002,33.419998,33,32.580002,32.419998,32.080002,31.670000,31.670000,31.670000,31.250000,30.920000,30.830000,30.670000,30.420000,30.330000,30.170000,30.250000,30.080000,30,29.750000,29.170000,29.170000,28.670000,28.420000,28.170000,28.170000,27.830000,27.420000,27,26.670000,26.750000,26.330000,26,25.580000,25.250000,25,24.580000,24.580000,24.580000,24.250000,24,23.670000,23.420000,23.080000,22.830000,22.750000,22.670000,22.670000,22.250000,22.670000,22.170000,22.500000,22,21.830000,21.750000,21.500000,21.420000,21.250000,20.920000,20.500000,20.330000,20.330000,20.750000,21,21.420000,21.420000,21.670000,21.670000,21.500000,21.500000,21.250000,21,20.670000,20.250000,19.920000,19.500000,19,18.420000,18.080000,17.750000,17.330000,16.920000,16.500000,16.170000,15.750000,15.330000,14.750000,14.250000,13.750000,13.250000,12.830000,12.170000,11.750000,11.420000,11.170000,10.920000,10.670000,10.420000,10.420000,9.8299999,9.8299999,9.4200001,9.3299999,9,8.6700001,9.0799999,9.5799999,9.7050076,9.8300104,9.9550076,10.080000,10.122571,10.165094,10.207571,10.250000,10.580000,10.580000,10.920000,11.330000,11.750000,12.080000,12.250000,12.670000,12.670000,12.750000,13.330000,13.500000,13.330000,12.750000,12.080000,11.670000,11.170000,10.830000,10.250000,9.6700001,9.1700001,9.2500000,9.2500000,8.5799999,8.2500000,7.7500000,7.1700001,6.9200001,6.8299999,6.4200001,6.0799999,5.7500000,5.4200001,4.9200001,4.4200001,3.9200001,3.4200001,2.9200001,2.5799999,2,1.4200000,1.4200000,1.6700000,1.9200000,2.1700001,2.5000000,2.8299999,3.3299999,3.7500000,4.2500000,4.7500000,5.0799999,5.6700001,5.6700001,6.0799999,6.6700001,7,7.3299999,7.8299999,8.2500000,8.0799999,8.5000000,9,9.5799999,10.170000,10.670000,11,11.420000,11.920000,12.500000,13.080000,13.670000,14.250000,14.750000,15.330000,15.830000,16.330000,16.750000,16.920000,16.580000,16.330000,16.080000,15.750000,15.750000,15.750000,15.830000,16.080000,16.580000,17.170000,17.750000,18.330000,18.830000,18.830000,19.250000,19.500000,19.920000,19.920000,20.250000,20.670000,21.080000,21.500000,21.920000,22.330000,22.750000,22.420000,22.170000,21.830000,21.750000,21.670000,21.580000,21.500000,22.080000,21.750000,21.580000,21.420000,21.420000,21.080000,20.750000,20.330000,19.920000,19.750000,19.670000,19.330000,19,18.580000,18.250000,18.080000,17.830000,17.420000,17.170000,17,16.580000,16.330000,16.250000,16.170000,15.750000,15.830000,15.420000,15,14.420000,13.830000,13.250000,12.670000,12.170000,11.750000,11.250000,11.250000,10.830000,10.250000,10.250000,9.7500000,9.2500000,9.1700001,8.9200001,8.3299999,8.0799999,8.2500000,8.5799999,9,9.5799999,10.170000,10.670000,11.170000,11.580000,12,12.420000,13,13.500000,14,14.500000,15,15.500000,16,16.420000,17,17.500000,18.080000,18.080000,18.670000,19,19.250000,19.750000,20.250000,20.830000,21.250000,21.670000,22.170000,22.250000,21.830000,21.250000,20.920000,20.750000,20.750000,21,21.420000,21.750000,22.250000,22.250000,22.420000,22.920000,22.750000,22.750000,23.080000,23.500000,23.750000,23.920000,24.330000,24.750000,24.750000,25,25.330000,25.420000,25.330000,25.250000,25.170000,25.250000,25.420000,25.250000,25.250000,25.170000,25.080000,25.170000,25.250000,25.330000,25.330000,25.420000,25.580000,25.670000,25.750000,26.250000,26.670000,27,27,26.830000,26.670000,26.420000,26.670000,26.580000,26.920000,26.920000,27,27.420000,27.670000,27.830000,28.250000,28.750000,29.250000,29.830000,30.170000,30,30.250000,30.500000,30,29.580000,29.420000,29.250000,28.750000,28.250000,27.830000,27.420000,27,26.670000,26.250000,25.830000,25.420000,25.170000,25.580000,26,26.080000,25.750000,25.750000,25.250000,24.750000,24.250000,24.250000,24,23.920000,24.170000,24.170000,24.080000,24.170000,24.580000,24.920000,25.250000,25.580000,25.830000,26.170000,26.080000,25.830000,25.330000,24.750000,24.330000,24,23.750000,23.670000,23.500000,23.080000,22.670000,22.420000,21.920000,21.420000,21.420000,21.170000,20.830000,20.420000,20.420000,20,19.500000,19.080000,18.920000,18.830000,18.580000,18.080000,17.920000,17.830000,17.670000,17.170000,16.920000,17,16.920000,16.670000,16.500000,16.250000,15.920000,15.580000,15.420000,15.250000,15.080000,14.920000,14.750000,14.500000,14.080000,14.080000,13.920000,13.920000,13.580000,13.330000,13.250000,13.330000,13.330000,13,12.830000,12.750000,12.670000,12.750000,13.250000,13.750000,14,14.580000,15.170000,15.670000,16.080000,16.500000,17,17.500000,17.750000,18.170000,18.670000,19.170000,19.670000,20.080000,20.250000,20.580000,20.580000,20.920000,21.500000,21.920000,22.250000,22.750000,23.250000,23.750000,24.080000,24.330000,24.830000,25.330000,25.830000,26.170000,26.670000,27.170000,27.580000,28,28,28.500000,29,29.500000,28.920000,28.330000,27.920000,27.750000,28.080000,28.420000,28.750000,29.080000,29.580000,29.580000,30,NaN,74.080002,74.330002,74.500000,74.419998,74.080002,NaN,40.330002,40.330002,40.330002,40.330002,40.330002,40.330002,40.580002,40.669998,41,41,40.919998,40.669998,40.330002,NaN,14.080000,13.750000,13.330000,13.080000,12.750000,12.500000,12.750000,12.920000,13.420000,13.420000,13.500000,13.830000,14.170000,14.250000,14.080000,NaN,-2.0799999,-2.7500000,-2.3299999,-2.5000000,-2.5000000,-2.1700001,-2.0799999,-1.7500000,-1.3300000,-0.75000000,-0.41999999,0.079999998,0.25000000,0.25000000,0.17000000,-0.17000000,-0.75000000,-1.1700000,-1.5800000,-2.0799999,NaN,-6,-6.5000000,-7,-7.4200001,-8.0799999,-8.5799999,-8.7500000,-8.2500000,-7.7500000,-7.1700001,-6.8299999,-6.5000000,-6.4175320,-6.3350420,-6.2525315,-6.1700001,-6.0650105,-5.9600139,-5.8550105,-5.7500000,-5.6050043,-5.4600058,-5.3150043,-5.1700001,-4.5799999,-4,-3.3299999,-4,-4.5000000,-5,-5.5799999,-6,NaN,-12.170000,-12.580000,-13,-13.420000,-13.750000,-14.170000,-14.080000,-14.500000,-13.830000,-13.420000,-12.830000,-12.250000,-12.105010,-11.960012,-11.815009,-11.670000,-11.522534,-11.375046,-11.227534,-11.080000,-10.580000,-9.9200001,-9.5799999,-9.8299999,-10.830000,-11,-11.750000,-12.170000,NaN,42.500000,42.080002,41.669998,41.330002,41.169998,41.080002,41.169998,41.080002,41.330002,41.580002,41.830002,42,41.919998,41.919998,42,41.669998,41.669998,41.250000,41.250000,41,41.080002,40.919998,41,41.080002,41,41.080002,41.419998,41.669998,42,42.330002,42.330002,42.750000,42.919998,43.169998,43.419998,43.669998,44.080002,44.330002,44.419998,44.580002,44.750000,45.080002,45.080002,45,45.080002,44.830002,44.750000,44.500000,44.330002,44.580002,45,45.169998,45.330002,45.750000,45.919998,46.169998,46,46.250000,46.580002,46.580002,46.580002,46.580002,46.169998,45.830002,45.669998,45.169998,44.830002,44.669998,44.330002,43.919998,43.419998,43.330002,42.830002,42.500000,NaN,45.919998,45.750000,45.419998,45.250000,45.419998,45.419998,45.330002,45.830002,46.250000,46.419998,46.669998,46.669998,47,47.080002,47.250000,47.169998,47.080002,46.750000,46.669998,46.419998,46.080002,45.919998,NaN,44.750000,44.419998,44.250000,43.750000,43.419998,43,42.500000,42.080002,41.830002,41.419998,41,40.580002,40.540272,40.500362,40.460270,40.419998,40.397701,40.375271,40.352703,40.330002,40,39.500000,39.169998,39.169998,38.580002,38.080002,37.580002,37.419998,37.330002,37.080002,36.750000,36.580002,36.750000,36.919998,36.830002,37.169998,37.169998,37.830002,38.500000,39.080002,39.169998,39.580002,40,40,40.330002,40.830002,40.669998,40.669998,41,41.330002,41.669998,42.080002,42,41.669998,41.250000,41.750000,41.855007,41.960011,42.065006,42.169998,42.272594,42.375126,42.477596,42.580002,42.642525,42.705032,42.767525,42.830002,42.830002,43.169998,43.669998,44.169998,44.330002,44.580002,44.580002,44.500000,44.500000,45,45.082775,45.165367,45.247776,45.330002,45.352959,45.375614,45.397961,45.419998,45.169998,45.250000,45.250000,45.500000,45.919998,46.419998,46.830002,47.169998,47.169998,47.169998,47.250000,46.830002,46.750000,46.580002,46.330002,46.250000,45.919998,46.080002,45.669998,45.169998,44.750000,NaN,45,44.500000,44.250000,43.669998,43.669998,43.669998,43.500000,43.669998,44.169998,44.669998,44.750000,45,45.330002,45.750000,46,46.419998,46.750000,46.500000,46.669998,46.500000,46.169998,46.330002,45.919998,45.919998,45.830002,45.419998,45,NaN,45.580002,45.250000,44.919998,45.669998,46,46.169998,46.419998,46.580002,46.419998,46.480000,46.330002,46.419998,46.750000,46.750000,46.580002,46.669998,46.580002,46.669998,46.750000,46.669998,46.750000,46.419998,46.169998,45.580002,NaN,51.580002,51.330002,51.500000,51.669998,52.169998,52.500000,52.669998,53,53.500000,54,54.500000,55.080002,55.580002,55.750000,55.500000,55.169998,54.750000,54.330002,53.919998,53.500000,53.080002,52.750000,52.500000,52.169998,51.830002,51.750000,51.580002,NaN,61.080002,60.750000,60.330002,59.919998,59.919998,60.169998,60.169998,60.500000,60.830002,61.169998,61.330002,61.580002,61.580002,61.330002,61.080002,NaN,61.750000,61.500000,61.330002,60.919998,60.919998,61.080002,61.419998,61.669998,62,62.419998,62.669998,62.830002,62.580002,62.500000,62.169998,62.169998,61.750000,NaN,-21.920000,-21.330000,-20.920000,-20.500000,-20,-19.580000,-19,-18.580000,-18,-18,-17.420000,-16.920000,-16.170000,-16.170000,-15.920000,-15.750000,-15.500000,-15.250000,-14.750000,-14.750000,-14.330000,-14.080000,-13.580000,-13.500000,-13.330000,-12.920000,-12.420000,-12,-12.500000,-13,-13.580000,-14.170000,-14.920000,-15.420000,-15.920000,-15.500000,-16.330000,-16.750000,-17,-17.420000,-17.420000,-18,-18.500000,-19.080000,-19.580000,-20.080000,-20.500000,-20.920000,-21.330000,-21.750000,-22.170000,-22.580000,-23,-23.420000,-23.750000,-24.250000,-24.670000,-25.170000,-25.080000,-25.250000,-25.500000,-25.580000,-25.330000,-25,-24.500000,-23.920000,-23.250000,-22.830000,-22.330000,-21.920000,NaN,-21,-20.920000,-21.170000,-21.330000,-21.330000,-21,NaN,-20.500000,-20,-20.170000,-20.500000,-20.500000,NaN,12.420000,12.670000,12.580000,12.500000,12.250000,12.250000,12.420000,NaN,-48.830002,-48.669998,-49,-49.250000,-49.169998,-49.080002,-49.419998,-49.419998,-49.669998,-49.500000,-49.669998,-49.250000,-48.830002,NaN,11.562831,11.821190,12.737682,12.750914,12.612169,11.562831,NaN,12.997019,13.161057,13.407540,13.489984,13.471362,13.187242,12.997019,NaN,2.3663483,2.5132217,2.7189283,2.8555582,2.8823874,2.6184011,2.3663483,NaN,1.3300000,1.5000000,1,0.57999998,1,1.3300000,NaN,-1,-0.92000002,-1.6700000,-1.7500000,-1.5000000,-1,NaN,8.0799999,8.5000000,9,9.4200001,9.8299999,9.5000000,9,8.5000000,8,7.5799999,7,6.5000000,6.1700001,6,6,6.4200001,7.0799999,7.5000000,8.0799999,NaN,19.330000,19.580000,19.920000,20,20,20,19.670000,19.330000,18.830000,18.500000,18.250000,18.250000,18.500000,18.920000,19.330000,NaN,23.670000,24.170000,24.580000,25,25.250000,25.080000,24.580000,24.080000,23.500000,23,22.580000,22,22.420000,22.580000,23.170000,23.670000,NaN,33.250000,33.500000,33.830002,33.919998,33.669998,33.669998,33.250000,32.830002,32.419998,31.920000,31.420000,31.080000,31.250000,31.670000,32.080002,32.330002,32.750000,33.080002,32.750000,32.750000,33.250000,NaN,33.419998,33.669998,34,33.919998,34.250000,34.330002,34.169998,33.830002,33.580002,33.250000,33.500000,33.330002,33.080002,32.750000,32.919998,33.419998,NaN,34.330002,34.500000,34.750000,35.080002,35.500000,35.500000,35.580002,35.669998,35.750000,35.500000,35.669998,36.080002,36.419998,36.830002,37.250000,37.500000,37.080002,36.750000,37,37.169998,37.169998,37.419998,37.830002,38.080002,38.580002,39,39.419998,39.919998,40.330002,40.669998,41.169998,40.919998,40.919998,41.169998,41.169998,41.500000,41.330002,41,40.580002,40.169998,39.669998,39.080002,38.750000,38.330002,38.330002,38.080002,37.580002,37,36.750000,36.169998,35.750000,35.750000,35.500000,35.169998,34.919998,35.500000,35.250000,35.250000,34.580002,35.080002,34.580002,34.580002,35,34.669998,34.330002,33.919998,33.419998,33.500000,33.919998,34.330002,34.750000,34.750000,34.830002,34.580002,34.500000,34.330002,34.250000,33.919998,34,33.919998,34.330002,NaN,42.580002,42.919998,43.250000,43.169998,43.169998,43.419998,43.750000,44,44.330002,44.750000,45.250000,45.500000,45.169998,44.750000,44.750000,44.500000,44.169998,44,43.919998,44.250000,43.750000,43.580002,43.330002,43.419998,43.169998,42.919998,43,42.669998,42.330002,42,42.250000,42.580002,42.500000,42.330002,42.500000,42.500000,42.250000,42.080002,41.830002,41.669998,41.419998,42,42.250000,42.580002,NaN,26.079590,26.318262,26.563335,26.871492,26.827274,26.738194,26.418993,26.122478,26.079590,NaN,28.078142,28.115788,28.266502,28.373316,28.498936,28.442738,28.078142,NaN,43.956451,44.523075,44.450336,43.956451,NaN,44.419998,45,45.330002,45.250000,45.500000,45.080002,44.750000,44.419998,NaN,45.669998,46.080002,46.250000,45.750000,45.669998,NaN,50.270000,50.419998,50.750000,50.500000,50.200001,50,50.270000,NaN,54.830002,55.169998,55,54.580002,54.830002,NaN,58.500000,59,59.169998,58.919998,58.500000,NaN,53.330002,53.580002,53.642548,53.705067,53.767548,53.830002,53.935047,54.040066,54.145050,54.250000,54.270138,54.290184,54.310139,54.330002,54,53.500000,53,52.500000,52,51.500000,51,50.500000,50,49.500000,49.080002,49.330002,49.330002,49.330002,49.080002,48.750000,48.330002,47.830002,47.500000,47.250000,46.919998,46.750000,46.250000,46.580002,46.669998,46.419998,45.919998,46.580002,47,47.580002,48,48.500000,48.750000,49.080002,49.500000,50,50.500000,51,51.419998,51.750000,52.250000,52.750000,53.330002,NaN,71,70.830002,71.120003,71.529999,71.529999,71.440346,71.350456,71.260338,71.169998,71.104042,71.037056,70.969032,70.900002,71,NaN,73.500000,73.830002,73.919998,73.500000,73.169998,73.250000,73.500000,NaN,74.250000,74.250000,74,73.919998,74.250000,NaN,75.580002,75.419998,75.330002,75.169998,74.750000,74.750000,75.080002,75.580002,NaN,75.250000,75.919998,76.169998,75.750000,76.169998,75.830002,75.830002,75.669998,75.419998,75.080002,74.830002,75,74.830002,74.669998,74.750000,75.250000,NaN,77.919998,78.330002,78.830002,79.250000,79.419998,79.169998,78.830002,78.330002,78.169998,78.169998,77.919998,NaN,80.080002,80.500000,80.919998,81.250000,81,80.937798,80.875397,80.812798,80.750000,80.687569,80.625084,80.562569,80.500000,80.417595,80.335121,80.252594,80.169998,80,79.917740,79.835320,79.752739,79.669998,79.565132,79.460175,79.355133,79.250000,78.830002,78.750000,78.919998,79.080002,79.500000,79.669998,80.080002,NaN,71.580002,71.705002,71.830002,71.955002,72.080002,72.143051,72.205742,72.268059,72.330002,72.415031,72.500038,72.585030,72.669998,72.701332,72.732651,72.763962,72.795258,72.826546,72.857819,72.889091,72.920341,73.045258,73.169998,73.233025,73.295700,73.358025,73.419998,73.502609,73.585144,73.667610,73.750000,74.169998,74.750000,75.080002,75.330002,75.330002,75.580002,75.919998,76.250000,76.250000,76.419998,76.750000,77,76.830002,76.330002,76.080002,75.830002,75.669998,75.330002,75,74.580002,74.169998,73.750000,73.330002,72.919998,72.500000,72,71.500000,71.080002,70.998413,70.916214,70.833405,70.750000,70.707787,70.665382,70.622787,70.580002,70.669998,70.830002,70.915504,71.000671,71.085503,71.169998,71.273163,71.375885,71.478172,71.580002,NaN,68.750000,69.250000,69.580002,69.250000,68.919998,68.750000,NaN,80.666672,80.674561,80.848717,80.937996,81.059013,81.268684,81.160622,81.042694,80.894043,80.774010,80.666672,NaN,80.391472,80.702095,80.824654,80.868927,80.800056,80.808655,80.896675,80.670044,80.557137,80.400421,80.488281,80.391472,NaN,79.872078,79.925812,79.982048,80.115242,80.277893,80.238792,80.181267,79.934357,79.872078,NaN,80.452332,80.427750,80.342857,80.198997,80.037498,80.104271,80.452332,NaN,80.800003,81.029999,81.029999,81.419998,81.750000,81.330002,81,80.800003,80.629997,80.800003,NaN,80.250000,80.500000,80.445274,80.390358,80.335266,80.279999,80.273415,80.266220,80.258415,80.250000,NaN,80.550003,80.900002,80.750000,80.550003,80.779999,80.669998,80.400002,80.120003,80.050003,80.169998,80.419998,80.419998,80.550003,NaN,79.750000,79.830002,79.669998,80.029999,79.919998,80.250000,80.500000,80.169998,80.419998,80.250000,80.250000,80.169998,79.870003,79.419998,79.169998,79.330002,79.699997,79.169998,78.830002,78.419998,78.080002,77.750000,77.250000,77.419998,77.919998,78.180000,78.629997,78.419998,78.029999,77.500000,77,76.500000,77.019997,77.500000,77.949997,78.018150,78.085876,78.153160,78.220001,78.221191,78.221588,78.221191,78.220001,78.699997,79.330002,79.750000,NaN,62.080002,62.299999,62.369999,62,62.080002,NaN,59.948502,60.077919,60.222084,60.386475,60.517910,60.298336,60.168674,59.948502,NaN,58.859596,58.939911,59.039680,59.190880,59.212067,58.982201,58.873478,58.859596,NaN,57.580002,57.830002,58.169998,58.500000,58,57.580002,NaN,55.470001,55.580002,55.369999,55.049999,55.049999,55.470001,NaN,55.700001,55.900002,56.099998,56.000019,55.900024,55.800018,55.700001,55.642628,55.585171,55.527630,55.470001,55.279999,55.130001,55.200001,55.700001,NaN,54.830002,54.919998,54.830002,54.669998,54.580002,54.830002,NaN,57.500000,57.779999,57.930000,57.700001,57.279999,57.080002,57.500000,NaN,58.330002,58.619999,58.500000,58.299999,58.099998,58.330002,NaN,58.880001,59.080002,58.830002,58.720001,58.880001,NaN,50.080002,50.419998,50.750000,51.169998,51.169998,51.169998,51.580002,51.330002,51.580002,51.669998,51.580002,51.642525,51.705032,51.767525,51.830002,51.892776,51.955368,52.017776,52.080002,52.250000,52.750000,52.750000,53.080002,53.330002,53.250000,53.330002,53.750000,54.169998,54.169998,54.500000,54.919998,54.750000,54.580002,54.665085,54.750111,54.835083,54.919998,55.065128,55.210171,55.355129,55.500000,55.582626,55.665173,55.747627,55.830002,55.830002,55.419998,55.750000,55.750000,56.080002,56.500000,56.330002,56.669998,57.169998,57.169998,57.419998,57.580002,57.419998,57.750000,58.080002,58.500000,58.500000,58.580002,58.330002,58,57.580002,57.669998,57.669998,57.669998,57.330002,57,56.580002,56.250000,56,56,55.830002,55.830002,55.500000,55,54.580002,54.419998,54,53.669998,53.419998,53.080002,52.830002,52.669998,52.919998,52.919998,52.750000,52.419998,52,51.750000,51.330002,51.250000,50.830002,50.669998,50.669998,50.750000,50.500000,50.669998,50.580002,50.169998,50.330002,50,50.080002,NaN,52.169998,52.169998,52.669998,53.169998,53.169998,53.500000,53.750000,53.919998,54.250000,54.250000,54.250000,54.500000,54.669998,55.080002,55.250000,55.169998,55.080002,54.750000,54.250000,53.919998,53.500000,53,52.580002,52.169998,52.080002,51.750000,51.580002,51.500000,51.750000,52.169998,NaN,42.500000,42.669998,43,42.500000,42.169998,41.830002,41.330002,41.750000,42.080002,42.500000,NaN,40.919998,40.830002,40.919998,41.250000,40.830002,40.419998,40,39.580002,39.169998,39.169998,38.830002,39.169998,39.669998,40.169998,40.580002,40.919998,NaN,37.919998,38.169998,38.169998,38,38,38.080002,38.250000,37.830002,37.330002,37,36.669998,36.750000,37.080002,37.169998,37.500000,37.500000,37.919998,NaN,37.750000,38.080002,38.250000,38.080002,37.830002,37.330002,37.419998,37,36.419998,36.750000,36.419998,36.750000,36.750000,37,37.419998,37.750000,NaN,35.169998,35.580002,35.500000,35.330002,35.419998,35.299999,35.330002,35.080002,35.250000,34.970001,34.930000,34.900002,35.080002,35.169998,35.169998,NaN,35,35.080002,35.250000,35.330002,35.419998,35.580002,35.169998,34.919998,34.919998,34.700001,34.580002,34.669998,35,NaN,39.580002,39.919998,39.669998,39.270000,39.500000,39.580002,NaN,36.169998,36.450001,36.080002,35.880001,36.169998,NaN,39.007397,39.047951,39.205967,39.103626,39.146931,39.217728,39.274357,39.377464,39.355274,39.136604,39.007397,NaN,38.257084,38.600403,38.567787,38.416481,38.284145,38.257084,NaN,38.512291,38.416687,38.383915,38.399979,38.465508,38.577908,38.512291,NaN,37.697292,37.738205,37.782978,37.924656,37.862782,37.895947,37.788044,37.697292,NaN,28.330000,28.379999,28.580000,28.170000,28,28.330000,NaN,28,28.170000,28.080000,27.830000,27.750000,28,NaN,28.833157,28.941154,29.043455,29.147875,29.137163,29.041817,28.833157,NaN,28.188606,28.359945,28.641903,28.455679,28.338778,28.188606,NaN,3.3299999,3.7500000,3.5799999,3.2500000,3.3299999,NaN,-34.169998,-33.580002,-33.500000,-33.250000,-32.919998,-32.330002,-31.750000,-31.420000,-31,-30.500000,-30,-29.500000,-29.080000,-28.580000,-28.080000,-27.670000,-27,-26.670000,-26.170000,-26.580000,-25.670000,-26.080000,-26.080000,-26.420000,-25.830000,-25.420000,-25,-24.420000,-23.920000,-23.500000,-23.080000,-22.670000,-22.250000,-21.830000,-22.330000,-21.920000,-21.670000,-21.500000,-21.080000,-20.830000,-20.670000,-20.670000,-20.670000,-20.330000,-20.330000,-20,-20,-19.830000,-19.750000,-19.420000,-19.080000,-18.580000,-18.170000,-18.170000,-17.830000,-17.420000,-17,-16.500000,-17.080000,-17.500000,-17,-16.670000,-16.170000,-16.420000,-16,-15.500000,-15.080000,-14.670000,-14.670000,-14.330000,-14.250000,-13.920000,-14,-14.420000,-14.750000,-15.250000,-14.920000,-14.920000,-15.250000,-14.830000,-14.500000,-14.080000,-13.670000,-13.580000,-13.580000,-13.170000,-12.750000,-12.330000,-12.330000,-12.330000,-12.205021,-12.080028,-11.955021,-11.830000,-11.727537,-11.625050,-11.522537,-11.420000,-11.460143,-11.500192,-11.540144,-11.580000,-11.920000,-12,-12.170000,-12.330000,-12.170000,-12.580000,-12.080000,-12.420000,-12.830000,-13.330000,-13.330000,-13.830000,-14.250000,-14.580000,-15,-15.330000,-15.500000,-16,-16,-16.330000,-16.580000,-16.830000,-16.830000,-17,-17.420000,-17.830000,-17.750000,-17.500000,-17,-16.580000,-16.080000,-15.580000,-15.080000,-14.580000,-14.080000,-13.580000,-13,-12.670000,-12.170000,-11.830000,-11.250000,-10.830000,-11.080000,-11.670000,-12.170000,-12.670000,-13.250000,-13.750000,-14.330000,-14.500000,-14.330000,-14.670000,-15,-15,-15.500000,-16,-16.580000,-17,-17.330000,-17.830000,-18.330000,-18.670000,-19,-19.330000,-19.420000,-19.830000,-20.170000,-20.420000,-20.830000,-21.080000,-21.420000,-21.920000,-22.420000,-22.080000,-22.420000,-22.670000,-23.170000,-23.580000,-23.920000,-24.080000,-24.580000,-25.080000,-25.500000,-26.080000,-26.080000,-26.500000,-27.080000,-27.580000,-28.170000,-28.670000,-29,-29.500000,-30,-30.580000,-31,-31.500000,-31.920000,-32.330002,-32.750000,-33,-33.419998,-33.830002,-34.330002,-34.919998,-35.250000,-35.750000,-36.250000,-36.750000,-37.169998,-37.580002,-37.830002,-37.830002,-37.919998,-38.080002,-38.419998,-38.419998,-38.669998,-39.169998,-38.919998,-38.669998,-38.250000,-38.419998,-37.830002,-38.250000,-38.500000,-38.830002,-38.669998,-38.419998,-38.330002,-38.250000,-38.419998,-38.080002,-38,-37.669998,-37.330002,-37,-36.750000,-36.330002,-35.919998,-35.580002,-35.669998,-35.419998,-35,-34.669998,-34.250000,-34.750000,-34.750000,-35.169998,-35.169998,-35.250000,-35,-34.830002,-34.500000,-34,-33.580002,-32.830002,-33.169998,-33.669998,-33.919998,-34.250000,-34.580002,-35,-34.580002,-34.169998,-33.750000,-33.250000,-33,-32.580002,-32.330002,-32.169998,-32,-32,-31.750000,-31.580000,-31.580000,-31.580000,-31.580000,-31.580000,-31.670000,-31.830000,-32.080002,-32.169998,-32.250000,-32.169998,-32.330002,-32.669998,-32.830002,-33,-33.500000,-33.830002,-33.830002,-33.830002,-33.830002,-33.830002,-33.830002,-33.919998,-34,-34.419998,-34.419998,-34.750000,-35,-35,-35,-35,-34.830002,-34.330002,-34.169998,NaN,-11.830000,-11.330000,-11.500000,-11.330000,-11.580000,-12,-11.830000,-11.830000,NaN,-35.919998,-35.750000,-35.669998,-35.919998,-36.169998,-36.169998,-35.919998,NaN,-40.669998,-40.830002,-41.169998,-41.169998,-41,-40.830002,-41,-41.500000,-42,-42.169998,-42.580002,-43.080002,-42.830002,-43.169998,-43.580002,-43.500000,-43.250000,-42.919998,-42.500000,-42.169998,-41.750000,-41.169998,-40.669998,NaN,-36.921432,-37.013824,-36.949623,-36.788486,-36.706081,-36.787884,-37.024902,-37.426277,-37.898804,-37.964458,-37.935249,-37.705379,-37.565189,-37.660568,-37.864277,-38.534275,-38.612968,-38.927704,-39.002041,-39.044811,-39.146229,-39.282467,-39.456154,-39.693077,-39.791309,-40.134537,-41.173149,-41.457249,-41.614918,-41.429008,-41.313484,-40.596809,-40.353436,-40.181389,-39.806709,-39.463078,-39.261368,-39.196835,-38.712940,-38.449120,-38.102776,-37.943024,-37.714756,-37.523201,-37.131695,-36.879608,-36.786057,-36.449959,-36.403111,-36.137440,-35.973015,-36.318542,-36.381416,-36.377792,-35.343845,-35.291740,-35.171700,-35.038254,-34.760109,-34.437622,-34.418064,-34.463402,-34.406933,-34.535267,-34.617863,-34.860382,-34.994087,-34.927326,-34.940552,-35.159733,-35.341850,-35.355145,-35.272354,-35.285645,-35.359615,-35.522106,-35.738503,-35.750603,-35.824627,-35.898689,-35.864883,-36.233055,-36.375332,-36.366734,-36.562893,-36.553856,-36.592037,-36.671444,-36.724110,-36.803658,-36.856396,-36.921432,NaN,-45.919998,-45.419998,-45.080002,-44.750000,-44.419998,-44.080002,-44,-43.669998,-43.330002,-43,-42.669998,-42.250000,-41.830002,-41.669998,-41.330002,-40.919998,-40.669998,-40.669998,-40.919998,-41.330002,-41.169998,-40.919998,-41.250000,-41.330002,-41.830002,-42.169998,-42.580002,-43,-43.169998,-43.500000,-43.750000,-43.750000,-44.080002,-44.330002,-44.669998,-45.080002,-45.500000,-45.919998,-46.250000,-46.500000,-46.669998,-46.500000,-46.419998,-46.169998,-46.250000,-46.169998,-45.919998,NaN,-47.330002,-46.669998,-47,-47.330002,NaN,5.6700001,5.6700001,5.3299999,5.3299999,5.2500000,4.9200001,4.5000000,4.0799999,4.0799999,3.7500000,3.5000000,3.1700001,2.6700001,2.1700001,2.2500000,1.7500000,1.6700000,1.1700000,1.0800000,0.57999998,0.57999998,0.17000000,-0.25000000,-0.67000002,-1,-1,-1.6700000,-1.9200000,-2.3299999,-2.3299999,-2.6700001,-3,-3.5000000,-4.1700001,-4.6700001,-5.2500000,-5.7500000,-5.5000000,-5.5000000,-5.5000000,-5.7500000,-5.5799999,-5.0799999,-4.7500000,-4.2500000,-3.8299999,-3.5000000,-3.1700001,-2.5799999,-2.0799999,-1.6700000,-1.0800000,-0.67000002,-0.25000000,0.079999998,0.33000001,1,1.5000000,1.8300000,2.1700001,2.4200001,2.9200001,3.3299999,3.7500000,3.8299999,4.3299999,4.7500000,5.1700001,5.6700001,NaN,-6.6700001,-6.3299999,-5.8299999,-6,-5.8299999,-5.9200001,-6.1700001,-6.2500000,-6.6700001,-6.7500000,-6.7500000,-6.8299999,-6.8299999,-6.3299999,-6.3299999,-6.5799999,-6.7500000,-6.8299999,-7.0799999,-7.5000000,-7.6700001,-7.5799999,-7.6700001,-8.1700001,-8.5799999,-8.5000000,-8.3299999,-8.1700001,-8.3299999,-8.1700001,-8.1700001,-8.0799999,-8,-7.7500000,-7.6700001,-7.6700001,-7.7500000,-7.6700001,-7.4200001,-7.3299999,-7.2500000,-7,-6.7500000,-6.6700001,NaN,-8.7399998,-8.3900003,-8.2500000,-8.1700001,-8.4099998,-8.7399998,NaN,-8.4110470,-8.3151369,-8.2385025,-8.1411238,-8.0469370,-8.0263233,-8.2045126,-8.1341209,-8.1775513,-8.2454967,-8.4523001,-8.2404766,-8.2229395,-8.3230343,-8.5166016,-8.4976616,-8.5448475,-8.7266922,-8.6348457,-8.6123552,-8.6409388,-8.7109280,-8.7943754,-8.7547894,-8.6307592,-8.6052217,-8.8526182,-8.8352709,-9.0462837,-9.0278111,-9.0882730,-9.0616369,-8.9773884,-8.8501873,-8.7288713,-8.6145573,-8.4295826,-8.4982643,-8.6251144,-8.6928034,-8.5719604,-8.5626955,-8.4766350,-8.4110470,NaN,-8.2171469,-8.3771772,-8.4804726,-8.7889194,-8.7721758,-8.9187975,-8.8424740,-8.9682970,-8.9854021,-8.7701921,-8.7537460,-8.4983110,-8.3880625,-8.2920265,-8.2122087,-8.2638912,-8.5106297,-8.6480007,-8.6523781,-8.5188379,-8.4761457,-8.5570879,-8.5031328,-8.4050694,-8.1727457,-8.0966759,-8.0496292,-8.0744686,-7.9754505,-7.9936333,-8.0806189,-8.2171469,NaN,-8.4803019,-8.3706894,-8.2522860,-8.2499104,-8.3513479,-8.4803019,NaN,-8.8850689,-8.8290844,-8.6812506,-8.4805346,-8.3283491,-8.2826900,-8.3790684,-8.8850689,NaN,-8.4200001,-8.0799999,-8.1226034,-8.1651373,-8.2076035,-8.2500000,-8.2926655,-8.3352203,-8.3776655,-8.4200001,NaN,-7.9200001,-7.5799999,-7.5000000,-7.9200001,-7.9200001,NaN,-9.4200001,-9.3299999,-9.3299999,-9.5799999,-10,-10.250000,-9.9200001,-9.7500000,-9.7500000,-9.4200001,NaN,-10.330000,-9.6700001,-9.3299999,-9.1700001,-9,-8.6700001,-8.5000000,-8.4200001,-8.3299999,-8.3299999,-8.6700001,-8.9200001,-9.0799999,-9.2500000,-9.5799999,-10.080000,-10.250000,-10.330000,NaN,-7.9200001,-7.4200001,-7.0799999,-7.5799999,-7.9200001,NaN,-6.9200001,-6.3299999,-5.8299999,-5.4200001,-5.9200001,-6.5000000,-6.9200001,NaN,-1.9200000,-1.5800000,-1.5000000,-2,-2.4200001,-2.5000000,-3,-2.6199999,-2.2500000,-2,-1.9200000,NaN,-3.0799999,-2.5000000,-2.6700001,-3.1700001,-3.0799999,NaN,-7.1794734,-7.1300364,-6.9800358,-6.9038091,-6.9218135,-6.8552661,-6.8919911,-7.1635327,-7.1794734,NaN,1,1.5800000,2,1.7500000,1.6700000,1.5800000,2.2500000,2.8299999,2.9200001,3,3.3299999,3.7500000,4.0799999,4.0799999,4.6700001,4.9200001,4.9200001,5.3299999,5.8299999,6.2500000,6.5799999,7,6.7500000,6.4200001,5.9200001,5.7500000,5.4200001,5.1700001,5,4.8299999,4.4200001,4.2500000,3.6700001,3.2500000,2.7500000,2.3299999,2,1.5800000,1.2500000,0.92000002,0.82999998,0.82999998,0.50000000,0,0,-0.57999998,-1,-1.3300000,-1.7500000,-2.2500000,-2.9200001,-3.4200001,-3.6700001,-3.9200001,-4.0799999,-3.6700001,-3.3299999,-3.4200001,-3.0799999,-3.3299999,-3.3299999,-3.5000000,-2.7500000,-2.9200001,-3,-2.9200001,-2.3299999,-1.7500000,-1.2500000,-0.75000000,-0.41999999,0.079999998,0.41999999,1,NaN,-2.8299999,-2.4200001,-1.9200000,-1.3300000,-0.92000002,-0.57999998,-0.079999998,0.41999999,0.75000000,0.75000000,1.3300000,1.1700000,1.0800000,1,0.82999998,0.92000002,0.92000002,1.1700000,1.5000000,1.7500000,1.7500000,1.5000000,1.0800000,0.57999998,0.41999999,0.33000001,0.50000000,0.50000000,0.50000000,0.50000000,0.41999999,0.50000000,0.41999999,-0.079999998,-0.67000002,-0.92000002,-1.3300000,-1.3300000,-0.92000002,-0.92000002,-0.75000000,-0.57999998,-0.92000002,-0.92000002,-1.3300000,-1.6700000,-1.9200000,-2.4200001,-2.7500000,-3.1700001,-3.5000000,-3.5000000,-3.8299999,-4.3299999,-4.7500000,-5.3299999,-5.6700001,-5.3299999,-4.5799999,-4.8299999,-4.6700001,-4.0799999,-3.8299999,-3.4200001,-3,-2.6700001,-2.6700001,-3,-3.5000000,-4,-4.5000000,-5,-5.5000000,-5.5799999,-5.5799999,-5.1700001,-4.5799999,-4,-3.5000000,-3.5000000,-2.8299999,NaN,1.0800000,1.5000000,1.9200000,2.1700001,1.7500000,1.3300000,1.5800000,1.0800000,0.82999998,0.50000000,0.50000000,0,-0.41999999,-0.92000002,-0.57999998,-0.17000000,0.25000000,0.67000002,0.77250153,0.87500209,0.97750163,1.0800000,NaN,-3.2500000,-3.0799999,-3.1700001,-3.5799999,-3.8299999,-3.6700001,-3.2500000,NaN,-3.1700001,-2.8299999,-2.8299999,-2.7500000,-3,-3,-3.4200001,-3.8299999,-3.5799999,-3.4200001,-3.3299999,-3.4200001,-3.1700001,NaN,-1.9717121,-1.9359668,-1.7305844,-1.6838264,-1.7835393,-1.8991468,-1.9717121,NaN,-1.6700000,-1.3300000,-1.6700000,-1.6700336,-1.6700449,-1.6700336,-1.6700000,NaN,-0.17000000,0,-0.25000000,-0.41999999,-0.17000000,NaN,-0.67000002,-0.67000002,-1.0800000,-1.1700000,-0.67000002,NaN,-1.3300000,-0.82999998,-0.82999998,-0.67000002,-0.33000001,-0.33000001,-0.67000002,-0.67000002,-1.3300000,-1.8300000,-2.3299999,-2.5000000,-3,-3.3299999,-3.3299999,-2.9200001,-2.5799999,-2.1700001,-2.0799999,-1.6700000,-1.4200000,-1.6700000,-2,-2.1700001,-2.3299999,-2.3299999,-2.5799999,-2.7500000,-2.9200001,-3.0799999,-3.3299999,-3.4200001,-3.6700001,-3.6700001,-3.9200001,-4.2500000,-4.5000000,-4.9200001,-5.5000000,-5.5799999,-5.9200001,-5.8299999,-6.1700001,-6.6700001,-6.7500000,-6.8299999,-7.2500000,-7.7500000,-8,-8.5799999,-9.0799999,-9,-9.4200001,-9.5799999,-9.5800476,-9.5800629,-9.5800476,-9.5799999,-9.6650171,-9.7500229,-9.8350172,-9.9200001,-9.9600496,-10.000066,-10.040050,-10.080000,-10.170000,-10.580000,-10.670000,-10.330000,-10.250000,-10.170000,-10.080000,-10.080000,-10,-9.6700001,-9.3299999,-8.9200001,-8.5000000,-8,-7.9200001,-7.6700001,-7.5000000,-7.5000000,-7.9200001,-8.1700001,-8.3299999,-8.7500000,-9,-9.2500000,-9.0799999,-9.0799999,-9,-8.6700001,-8.3299999,-8,-8.0799999,-8.0799999,-8.3299999,-8.3299999,-7.7500000,-7.3299999,-7.2500000,-6.7500000,-6.7500000,-6.1700001,-5.5799999,-5.2500000,-5,-4.8299999,-4.5799999,-4.4200001,-4.3299999,-4.0799999,-3.8299999,-3.5000000,-4,-4,-3.5799999,-3.2500000,-2.9200001,-2.8299999,-2.6700001,-2.7500000,-2.5000000,-2.5000000,-2,-2.1700001,-2.2500000,-2.2500000,-2,-1.5800000,-1.5000000,-1.3300000,NaN,16.250000,16.080000,16.580000,17.170000,17.580000,18,18.500000,18.580000,18.330000,18.250000,18.500000,17.920000,17.420000,17.335051,17.250067,17.165051,17.080000,16.955013,16.830017,16.705013,16.580000,16.170000,15.750000,15.750000,15.250000,14.580000,14.080000,13.920000,14.170000,14.170000,14,13.750000,13.670000,13.330000,12.920000,12.830000,13,13.580000,13.830000,13.500000,13.080000,13.670000,13.920000,13.580000,13.750000,14.170000,14.500000,14.750000,14.420000,14.750000,15.250000,15.670000,16.250000,NaN,8.4200001,8.9200001,9.2500000,9.6700001,10,10.500000,11.250000,10.500000,10.080000,9.9200001,9.4200001,9.0799999,8.7500000,8.4200001,NaN,13.420000,13.420000,13.330000,13,12.500000,12.170000,12.500000,13,13.420000,NaN,12.500000,12.420000,12.500000,12.080000,11.670000,11.080000,11.080000,10.670000,10.250000,10.170000,10.750000,10.830000,11.420000,11.330000,11.435009,11.540012,11.645009,11.750000,11.812582,11.875110,11.937583,12,12.500000,NaN,10.500000,10.920000,11.420000,11.830000,11.750000,11.500000,11.500000,10.920000,10.830000,10.420000,10.670000,11.080000,10.580000,10.170000,10.080000,9.6700001,9.5799999,9.9200001,9.5799999,9.7500000,9.2500000,9,9.3299999,9.4350166,9.5400219,9.6450167,9.7500000,9.8125467,9.8750620,9.9375467,10,10.420000,10.580000,10.500000,NaN,7.1700001,7.7500000,8,8.1700001,8.5000000,8.6700001,8.5000000,8.0799999,8.4200001,8.5000000,9,8.8299999,9.0799999,9.7500000,9.7500000,9.3299999,8.8299999,8.2500000,7.6700001,7.2500000,6.8299999,6.3299999,6.9200001,7.3299999,7,6.7500000,6.4200001,6.0799999,5.5799999,5.9200001,5.9200001,6.1700001,6.4200001,7,7.3299999,7.5799999,7.7500000,7.4200001,7.3299999,7.7500000,7.6700001,7.2500000,6.8299999,7.1700001,NaN,-5.5000000,-5.5799999,-5.5799999,-5.5000000,-5.5000000,-5.5000000,-4.9200001,-4.9200001,-4.1700001,-4.1700001,-4.6700001,-5,-5.5799999,-5.5799999,-6,-6.2500000,-6.2500000,-6.2500000,-6.1700001,-5.8299999,-5.7500000,-5.5000000,NaN,-2.2157667,-2.1872468,-2.1378863,-1.9867182,-1.9660025,-2.0770741,-2.2157667,NaN,-3.7363453,-4.1665597,-4.2837763,-4.6066051,-4.7454619,-4.7895365,-4.5577283,-4.2550659,-3.7363453,NaN,-3.4572217,-3.4508758,-3.0493569,-2.8361616,-2.7610548,-3.1060345,-3.3567128,-3.4318306,-3.4572217,NaN,-5.4200001,-5.5000000,-6.1700001,-6.5799999,-6.8299999,-6.5000000,-6,-5.4200001,NaN,-7.3080416,-7.3462715,-7.2619190,-6.7943072,-6.6768589,-6.8291655,-7.1162319,-7.3080416,NaN,-8.5310268,-8.5126076,-8.3321571,-8.2924633,-8.2996302,-8.0290079,-7.9699330,-7.9971528,-8.4167299,-8.5310268,NaN,-8.4731197,-7.8870869,-7.6792393,-7.5588923,-7.9647593,-8.2692528,-8.3581371,-8.4731197,NaN,-9.5151434,-9.1630964,-8.9218845,-8.5725803,-8.4711256,-8.4528770,-8.5359926,-9.5151434,NaN,-9.2500000,-9.3299999,-9.6700001,-9.9200001,-9.8299999,-9.8299999,-9.5000000,-9.2500000,NaN,-10.170000,-10.330000,-10.750000,-10.670000,-10.170000,NaN,-15.661796,-14.799587,-14.717137,-14.825510,-15.199539,-15.180332,-14.990297,-15.471173,-15.534534,-15.585616,-15.661796,NaN,-15.920000,-16.420000,-16.500000,-15.920000,NaN,-20.250000,-20.500000,-20.750000,-21.170000,-21.500000,-21.670000,-22,-22.330000,-22.330000,-22,-21.750000,-21.500000,-21.250000,-20.830000,-20.250000,NaN,-43.770000,-43.799999,-44.169998,-43.900002,-43.770000,NaN,-18,-17.580000,-17.330000,-17.330000,-17.580000,-18,-18.170000,-18.170000,-18,NaN,-16.580000,-16.420000,-16.170000,-16.500000,-16.670000,-16.670000,-16.920000,-16.580000,NaN,-17.469999,-17.530001,-17.830000,-17.730000,-17.469999,NaN,22.030001,22.219999,22.219999,21.900000,21.900000,22.030001,NaN,21.580000,21.719999,21.299999,21.299999,21.580000,NaN,21.213406,21.160763,21.042439,21.101700,21.213406,NaN,20.950001,20.900000,20.969999,20.730000,20.620001,20.570000,20.780001,20.950001,NaN,20.270000,20.150000,20.049999,19.920000,19.680000,19.520000,19.330000,19.270000,19.129999,18.930000,19.080000,19.350000,19.770000,19.950001,20.270000];
coastlon = [-180,-178,-174,-170,-166,-163,-158,-152,-146,-147,-151,-153.50000,-153,-154,-154,-154,-154.50000,-153,-150,-146.50000,-145.50000,-148,-150,-152.50000,-155,-157,-157.25542,-157.50719,-157.75536,-158,-157.66580,-157.33273,-157.00079,-156.67000,-154.50000,-154.50000,-154.50000,-156.67000,-158,-158.33000,-158.67000,-157,-154,-153,-150.50000,-148,-146,-146,-146.33000,-146.67000,-144,-142,-140.67000,-140,-138.33000,-136.67000,-135.50000,-133,-132,-130.83000,-129.67000,-128,-127,-126.83000,-126.33000,-125.50000,-124.50000,-124.50000,-123.33000,-123.67000,-122.33000,-121.33000,-120,-120,-119.58419,-119.16723,-118.74915,-118.33000,-117.91502,-117.50000,-117.08498,-116.67000,-116.58561,-116.50082,-116.41561,-116.33000,-116.65982,-116.99306,-117.32978,-117.67000,-117.67000,-117.67000,-117.67000,-117.67000,-117.34308,-117.01085,-116.67319,-116.33000,-115.66772,-115.00352,-114.33755,-113.67000,-112.33000,-112.50000,-112.54350,-112.58631,-112.62848,-112.67000,-112.49999,-112.33167,-112.16502,-112,-111.50000,-111,-110.33000,-108.67000,-108.50000,-109.50000,-109.50000,-108.33000,-108,-108.50000,-107.50000,-106,-104.50000,-104.50000,-104.50000,-102.67000,-101.33000,-100,-99.500000,-101.33000,-100.67000,-101.50000,-101.50000,-100,-99,-100,-101.33000,-102.50000,-101.33000,-101.50000,-99.669998,-98.500000,-98,-97.500000,-97.500000,-96.330002,-96,-96,-97.500000,-98.500000,-99.669998,-100.00586,-100.33948,-100.67085,-101,-100.70552,-100.41235,-100.12051,-99.830002,-98.330002,-98.330002,-97,-95.669998,-95.669998,-94,-92.250000,-90.500000,-88.750000,-87,-85.500000,-84.330002,-83,-81.250000,-79.500000,-78.500000,-78.669998,-78,-76.500000,-75,-74,-74.500000,-73,-71.500000,-70,-68.500000,-67.500000,-67,-67,-67.500000,-67.500000,-68,-68,-68.500000,-68.500000,-67.330002,-66.669998,-67.330002,-66.830002,-66.830002,-67.500000,-67.500000,-68.500000,-69.250000,-69.330002,-68.669998,-67.830002,-67.669998,-67,-66.330002,-66.330002,-65.500000,-65.830002,-65,-64,-64,-63,-62.669998,-61.669998,-61.500000,-61,-59.669998,-58.830002,-58.830002,-58,-57.169998,-56.669998,-57.330002,-57.538609,-57.748146,-57.958607,-58.169998,-57.940002,-57.709999,-57.479996,-57.250000,-57.330002,-58.169998,-58.669998,-59,-59.669998,-60.500000,-61.330002,-62,-62.169998,-62.330002,-62.669998,-63.500000,-64,-63.669998,-64.669998,-65.330002,-65.500000,-65.333855,-65.166801,-64.998856,-64.830002,-64.953979,-65.078636,-65.203972,-65.330002,-65.206741,-65.082329,-64.956757,-64.830002,-63.669998,-62.669998,-62.330002,-62,-62,-61.500000,-61.669998,-61,-60.830002,-61.669998,-60.830002,-61,-60.711578,-60.420456,-60.126602,-59.830002,-59.913792,-59.998383,-60.083782,-60.169998,-61.500000,-61,-60.669998,-61.669998,-61.669998,-63,-63,-63.669998,-65.500000,-67.330002,-65,-62.500000,-60,-57.669998,-56,-53.669998,-51.669998,-49.330002,-47.669998,-44,-41,-41,-38.500000,-36.330002,-35,-33.330002,-31.670000,-30,-28.330000,-27,-26,-24,-23.670000,-22.330000,-20.670000,-19.330000,-17.670000,-16.330000,-14.670000,-13.500000,-12.330000,-11.330000,-11.170000,-12,-12.170000,-11.500000,-11,-10.500000,-9.7500000,-9,-8.6700001,-8.5000000,-8.5000000,-8.2056446,-7.9125228,-7.6206393,-7.3299999,-7.4158363,-7.5011115,-7.5858307,-7.6700001,-7.5838804,-7.4985142,-7.4138904,-7.3299999,-7.4158082,-7.5010743,-7.5858035,-7.6700001,-7.4593706,-7.2491584,-7.0393672,-6.8299999,-5.8299999,-5.8299999,-6,-4.5000000,-3,-3,-3.3299999,-2.5000000,-1.6700000,-1,-1.5000000,-0.67000002,0,1.3300000,2.6700001,3.5000000,4.6700001,6.3299999,7.3299999,8.6700001,10,11.330000,12.670000,14.330000,15.670000,15.670000,17,18.330000,20,21.500000,23,24.670000,25.330000,27,28.330000,30,31.330000,32,33.500000,33.330002,33.500000,34.330002,35,36,37,38.330002,38.669998,39.330002,39.830002,39.830002,40,41.330002,42,43.330002,44.500000,46,46,47,48.169998,48.500000,49.330002,49.830002,50.500000,50.169998,50.500000,51.500000,52.169998,53.669998,55.169998,56,57.169998,57.169998,56.330002,57,58,59,59.330002,60.669998,61.669998,62.669998,63.669998,65,66.330002,67.669998,68.669998,69.500000,69.500000,69.500000,70,70.500000,69.500000,69.830002,69.830002,70.669998,71.669998,71,72.330002,73.500000,74.500000,75.500000,76.169998,77.169998,78,78.330002,79,80.500000,81.669998,82.500000,83.669998,85,86.330002,87.669998,88.500000,89.669998,91,92,93,94,94,95,96,97,97.669998,98.500000,99.330002,100,100.67000,101.50000,102.67000,104,105,106,107,108,109,109.50000,110.33000,110.67000,110.67000,111.67000,112.67000,113.67000,114.50000,115.50000,116.50000,117.67000,119,120.33000,121.50000,121.50000,122.50000,123.33000,124.33000,124.83000,125.83000,126.50000,127,127.67000,128.33000,129,129.50000,130,130,130.83000,132,133.33000,134.33000,135.33000,136.33000,137.33000,138.33000,139.33000,140.50000,142,142.50000,143.33000,144.33000,144.33000,145,146,146,146.83000,147,148.33000,149,150.33000,151,151.50000,152.67000,154.33000,155,156,156.50000,157.50000,158.67000,160,161,161,161.17000,161.67000,162.17000,162.33000,163.33000,163.17000,164.67000,166,167.33000,168.67000,170,170.17000,171,171,170.17000,170.50000,169.67000,168.50000,167,167,166.67000,165.33000,165.33000,164.33000,163,162.67000,162.67000,163,163.33000,163.67000,163.67000,164.67000,164.99380,165.32332,165.65868,166,165.50259,165.00342,164.50253,164,161.50000,160,160,160,160.33000,160.33000,161,162.33000,164,166,166,168.50000,171.50000,176,180,NaN,166.33000,166.67000,168.17000,169.67000,168.17000,166.33000,NaN,-164,-161.67000,-160.67000,-160,-160,-161.67000,-163.67000,-163.67000,-163,-164,NaN,-150.17000,-148.17000,-147.92334,-147.67447,-147.42337,-147.17000,-147.49651,-147.82697,-148.16145,-148.50000,-150.17000,NaN,-76.169998,-74.669998,-73,-71.830002,-71,-70.669998,-71,-71.500000,-71.669998,-71.169998,-70.330002,-69.669998,-69.330002,-68.830002,-68.500000,-68.330002,-68.500000,-68.830002,-70,-71.500000,-73,-73.330002,-74.330002,-75,-76,-76.500000,-76.169998,NaN,-76.169998,-75.669998,-75.750000,-74.500000,-73.669998,-73.750000,-74,-75,-76.169998,NaN,-63.663330,-64.027328,-64.148842,-64.004364,-63.648201,-63.283825,-63.040352,-63.454205,-63.663330,NaN,-62.591366,-62.458946,-62.478111,-62.252499,-62.115147,-62.591366,NaN,-56.500000,-55.830002,-55.624752,-55.418011,-55.209766,-55,-55.249474,-55.499302,-55.749477,-56,-56.500000,NaN,-58.740822,-58.752163,-58.580429,-57.944485,-57.824783,-57.820793,-58.047646,-58.740822,NaN,-60.233433,-60.302536,-60.780682,-60.773098,-60.326569,-60.034283,-59.960518,-59.950951,-60.233433,NaN,-46.330002,-46,-45.752140,-45.502857,-45.252144,-45,-45.333035,-45.665722,-45.998051,-46.330002,NaN,-80.080002,-80,-79.330002,-78.830002,-79,-78.580002,-78.669998,-78.330002,-77.750000,-77.500000,-77.169998,-77.500000,-77.330002,-77.419998,-77.419998,-77.500000,-77.419998,-77.750000,-78.169998,-78.419998,-78.169998,-78.500000,-78.750000,-79.169998,-79.500000,-79.750000,-80.080002,-80.080002,-80.500000,-80.419998,-80.314941,-80.209915,-80.104942,-80,-80.125053,-80.250069,-80.375053,-80.500000,-80.919998,-81,-81.500000,-81.750000,-82.250000,-82.750000,-83,-83.250000,-83.750000,-83.669998,-84,-84.580002,-84.830002,-85.169998,-85.330002,-85.669998,-85.830002,-85.750000,-85.750000,-86.169998,-86.580002,-87,-87.330002,-87.414894,-87.499855,-87.584892,-87.669998,-87.584999,-87.500000,-87.415001,-87.330002,-87.414894,-87.499855,-87.584892,-87.669998,-87.669998,-87.830002,-88.419998,-88.830002,-89.330002,-89.750000,-90,-90.500000,-91,-91.500000,-92,-92.330002,-92.750000,-93.169998,-93.419998,-93.830002,-94.250000,-94.669998,-95.169998,-95.669998,-96.250000,-96.830002,-97.419998,-98,-98.500000,-99,-99.500000,-100,-100.50000,-101,-101.58000,-101.58000,-102,-102.25000,-102.83000,-103.50000,-103.83000,-104.33000,-104.92000,-105.33000,-105.67000,-105.33000,-105.50000,-105.17000,-105.17000,-105.50000,-105.67000,-106,-106.42000,-106.75000,-107.17000,-107.58000,-108,-108.33000,-109,-109.42000,-109.42000,-109.25000,-109.50000,-109.75000,-110,-110.58000,-110.58000,-110.58000,-111.17000,-111.67000,-112.17000,-112.42000,-112.75000,-112.83000,-113.08000,-113.08000,-113.50000,-113.83000,-114.17000,-114.75000,-114.83000,-114.75000,-114.58000,-114.67000,-114.42000,-114,-113.67000,-113.25000,-112.92000,-112.75000,-112.33000,-112,-111.50000,-111.33000,-111,-111,-110.67000,-110.67000,-110.83000,-110.58000,-110.17000,-109.75000,-109.42000,-110,-110.33000,-110.83000,-111.25000,-111.67000,-112.33000,-112.08000,-112.08000,-112.33000,-112.83000,-113.17000,-113.58000,-114,-114.33000,-114.50000,-115,-114.42000,-114,-114,-114.33000,-114.67000,-115.17000,-115.67000,-115.75000,-116,-116,-116,-116.33000,-116.33000,-116.58000,-116.75000,-117.08000,-117.25000,-117.50000,-118,-118.33000,-118.42000,-118.75000,-119.25000,-119.83000,-120.58000,-120.58000,-121.08000,-121.42000,-121.92000,-121.83000,-121.83000,-122.17000,-122.42000,-122.50000,-122.08000,-122.33000,-122.17000,-122.50000,-122.50000,-123,-123,-122.92000,-123.33000,-123.67000,-123.75000,-123.75000,-124,-124.33000,-124.33000,-124.08000,-124,-124.17000,-124.42000,-124.50000,-124.25000,-124.08000,-124,-124,-123.83000,-123.92000,-123.92000,-123.17000,-123.92000,-124,-124.08000,-124.33000,-124.58000,-124.75000,-124.67000,-123.83000,-123.17000,-123.17000,-122.58000,-123,-122.58000,-122.50000,-122.25000,-122.33199,-122.41432,-122.49699,-122.58000,-122.54009,-122.50013,-122.46010,-122.42000,-122.50198,-122.58431,-122.66698,-122.75000,-123.17000,-123.17000,-123.75000,-124.33000,-124.92000,-125.50000,-126.25000,-127,-127.75000,-127.75000,-128.17000,-128.42000,-129.17000,-129.75000,-130.33000,-130.75000,-130.17000,-130.42000,-130.08000,-130.75000,-131.33000,-131.75000,-131.75000,-132.08000,-132,-132.50000,-133,-132.58000,-132.08000,-132.08000,-132.50000,-133.08000,-133.42000,-133.67000,-133.67000,-134.17000,-134.33000,-133.83000,-133,-133.42000,-133.75000,-134,-134.50000,-134.50000,-134.75000,-134.67000,-135,-135.17000,-135.67000,-135,-135,-134.75000,-134.75000,-134.75000,-135.17000,-135.50000,-136.17000,-136.50000,-137.25000,-137.92000,-138.67000,-139.50000,-139.67000,-140.25000,-141.08000,-142,-143,-144,-145,-146,-146.67000,-147.50000,-148.33000,-148.17000,-148.67000,-149.50000,-150.17000,-150.92000,-151.92000,-151.42000,-151.92000,-151.42000,-151.33000,-150.42000,-150.42000,-150.29597,-150.17131,-150.04597,-149.92000,-150.10750,-150.29500,-150.48250,-150.67000,-151.67000,-152.25000,-152.50000,-153.08000,-153.83000,-154.08000,-153.33000,-153.83000,-154.33000,-155.25000,-156.17000,-156.67000,-157.67000,-158.42000,-158.75000,-159.58000,-160.50000,-161.42000,-162,-162.83000,-163.67000,-164.75000,-164.92000,-163.92000,-162.92000,-162.33000,-161.42000,-160.50000,-160.50000,-159.92000,-159,-158.33000,-157.67000,-157.50000,-157.42000,-158,-158.67000,-158.92000,-159.58000,-161,-161.58000,-161.92000,-161.67000,-162.17000,-163,-163.83000,-164.33000,-164.92000,-165.25000,-166,-165.50000,-164.83000,-164.67000,-163.92000,-163,-162.25000,-161,-160.75000,-161.25000,-161.25000,-161,-161.92000,-162.67000,-163.67000,-164.92000,-166.33000,-166.67000,-166.33000,-167.25000,-167.39433,-167.53911,-167.68433,-167.83000,-167.58305,-167.33408,-167.08307,-166.83000,-165.75000,-164.67000,-163.83000,-163.75000,-162.17000,-161.75000,-162.50000,-163.50000,-164,-165.25000,-166.17000,-166,-164.83000,-163.50000,-163,-162.67000,-161.58000,-160.42000,-159,-159,-157.58000,-156.33000,-154.83000,-154.33000,-152.50000,-151.50000,-150.33000,-149,-147.50000,-146.17000,-145.08000,-144,-142.83000,-141.83000,-141,-139.50000,-138.33000,-137.33000,-136,-135.92000,-135.17000,-134.17000,-133.33000,-132.58000,-131.17000,-129.83000,-129.42000,-128.50000,-128,-126.67000,-126.67000,-126.17000,-125.33000,-124.42000,-124.33000,-123.50000,-123,-121.33000,-120.25000,-118.83000,-117.50000,-116,-114.67000,-114.08000,-115.08000,-115.33000,-114.17000,-113,-111.58000,-110.25000,-109.25000,-108.17000,-107.83000,-109,-108.25000,-106.92000,-105.67000,-104.58000,-103,-101.75000,-100,-100,-98.750000,-98.669998,-98,-99.580002,-98.580002,-97.919998,-96.419998,-95.580002,-96.919998,-96.830002,-95.830002,-95.500000,-95.169998,-94.250000,-94.669998,-94,-95.669998,-96.750000,-96.250000,-95.830002,-95,-95,-95,-95.250000,-95.580002,-95.169998,-93.169998,-91.169998,-90.169998,-90.669998,-90.669998,-91.330002,-91.919998,-93.080002,-94,-93.500000,-94.169998,-93.500000,-92.669998,-91.919998,-91.330002,-92.419998,-91.330002,-90.669998,-89.919998,-88.919998,-88,-88,-88.169998,-87.250000,-86.500000,-86.500000,-85.419998,-85.419998,-85.500000,-85.500000,-84.250000,-82.919998,-82.750000,-81.330002,-81.330002,-81.330002,-82.419998,-82.419998,-81.169998,-81.419998,-82.669998,-83.750000,-85.080002,-85.500000,-86.750000,-86,-87,-87,-87.750000,-88.500000,-90,-90.669998,-90.580002,-91.580002,-92.500000,-92.500000,-93.169998,-93.669998,-94.169998,-94.419998,-94.669998,-94.750000,-94.750000,-94.419998,-93.750000,-93.080002,-93.080002,-92.669998,-92.669998,-92.330002,-92.330002,-91.750000,-91,-90,-89,-88.080002,-87.933807,-87.788414,-87.643814,-87.500000,-87.331947,-87.164268,-86.996948,-86.830002,-86,-85,-84,-83,-82.169998,-82.419998,-82.169998,-82.169998,-82.330002,-81.669998,-81.250000,-80.750000,-80.419998,-79.750000,-79.830002,-79,-78.419998,-78.830002,-78.830002,-78.830002,-78.919998,-79.169998,-79.500000,-78.750000,-78,-77.250000,-76.750000,-76.750000,-77,-77.169998,-77.500000,-78.080002,-78.669998,-78.580002,-77.919998,-77.419998,-77.419998,-77.580002,-78.080002,-77.750000,-77.688110,-77.625816,-77.563118,-77.500000,-77.644119,-77.788826,-77.934120,-78.080002,-78.080002,-77.419998,-76.419998,-75.500000,-74.830002,-73.669998,-72.919998,-72.250000,-72.250000,-71.500000,-71.750000,-71,-70.250000,-69.500000,-69.669998,-69.419998,-69.500000,-69.500000,-69,-68.419998,-67.750000,-66.750000,-66.419998,-65.669998,-65.250000,-65.580002,-65.169998,-64.669998,-64.330002,-63.830002,-63.250000,-62.830002,-62.330002,-61.830002,-61.830002,-61.330002,-61.750000,-61.750000,-61.330002,-61.330002,-60.500000,-60.330002,-59.250000,-58.919998,-58,-57.874424,-57.749233,-57.624424,-57.500000,-57.708752,-57.916664,-58.123749,-58.330002,-58.079597,-57.829456,-57.579590,-57.330002,-57.250000,-56.500000,-55.830002,-56,-55.669998,-56.169998,-56.830002,-57.830002,-58.669998,-59.080002,-59.500000,-60,-60.919998,-61.669998,-62.169998,-62.830002,-63.419998,-64,-64.750000,-65.419998,-66,-66.750000,-66.750000,-67.169998,-67.330002,-68,-68.669998,-69.250000,-69.669998,-70,-70.419998,-70.750000,-71.169998,-70.500000,-70.080002,-69.669998,-69.250000,-68.669998,-68,-67.419998,-66.750000,-66,-65.250000,-64.580002,-64.250000,-64.250000,-64.830002,-65.330002,-66.330002,-65.669998,-64.830002,-65,-64.919998,-64.919998,-64.580002,-64,-63.250000,-62.580002,-62,-61.500000,-61.500000,-61,-60.669998,-60.419998,-60.500000,-60.331745,-60.163994,-59.996746,-59.830002,-59.978157,-60.125874,-60.273155,-60.419998,-61,-61.169998,-62,-63,-63.669998,-64.169998,-64.500000,-65,-65.500000,-66,-66.169998,-65.919998,-65.330002,-64.919998,-64.250000,-64.919998,-64.830002,-64.830002,-65.580002,-66.250000,-67,-67,-67.500000,-68,-68.580002,-68.830002,-69.169998,-69.750000,-70.250000,-70.250000,-70.580002,-70.830002,-70.750000,-71,-70.669998,-70.500000,-70,-70.040001,-69.930000,-70.669998,-70.669998,-71.080002,-71.330002,-71.500000,-72,-72.500000,-73,-73.500000,-73.500000,-74,-74.330002,-74,-74.169998,-74.500000,-75,-75.250000,-75.580002,-75.419998,-75.314362,-75.209145,-75.104362,-75,-75.062660,-75.125214,-75.187660,-75.250000,-75.580002,-75.750000,-76,-75.830002,-75.669998,-76,-75.919998,-76.330002,-76.169998,-76.169998,-76,-76.419998,-76.580002,-76.500000,-76.419998,-76.919998,-76.330002,-76.419998,-76.419998,-76.419998,-76,-75.830002,-75.660004,-75.529999,-75.910004,-76,-76.330002,-76.750000,-76.250000,-75.830002,-75.830002,-76,-76.330002,-76.830002,-76.330002,-76.580002,-77.169998,-77.580002,-78,-78.419998,-78.919998,-79.169998,-79.500000,-80,-80.500000,-81,-81.250000,-81.500000,-81.419998,-81.330002,-81.330002,-81.080002,-80.919998,-80.580002,-80.580002,-80.330002,-80.080002,-80.080002,-80.169998,-80.419998,-80.669998,-81.080002,-81.250000,-81.669998,-81.919998,-82.169998,-82.500000,-82.519951,-82.539940,-82.559952,-82.580002,-82.540138,-82.500183,-82.460136,-82.419998,-82.502548,-82.585068,-82.667549,-82.750000,-82.750000,-82.669998,-82.830002,-83.080002,-83.500000,-83.919998,-84.419998,-84.830002,-85.330002,-85.500000,-86,-86,-86.330002,-86.830002,-87.330002,-87.830002,-88,-88.250000,-88.750000,-89.169998,-89.669998,-90.169998,-90.419998,-90.080002,-89.669998,-89.250000,-89.330002,-89.580002,-89.580002,-89.080002,-89.250000,-89.500000,-89.830002,-90.169998,-90.750000,-91.250000,-91.330002,-91.830002,-92.250000,-92.750000,-93.250000,-93.830002,-93.830002,-94.250000,-94.750000,-94.750000,-94.832596,-94.915131,-94.997597,-95.080002,-95.017303,-94.954742,-94.892303,-94.830002,-94.915154,-95.000206,-95.085152,-95.169998,-95.500000,-96,-96.500000,-97,-97.330002,-97.419998,-97.250000,-97.250000,-97.169998,-97.419998,-97.580002,-97.750000,-97.750000,-97.750000,-97.750000,-97.919998,-97.750000,-97.250000,-97.419998,-97.250000,-97,-96.669998,-96.419998,-96.169998,-96.169998,-95.830002,-95.330002,-94.830002,-94.500000,-94.169998,-93.580002,-93,-92.419998,-91.830002,-91.830002,-91.250000,-91.330002,-91,-90.669998,-90.669998,-90.500000,-90.419998,-90.330002,-90,-89.500000,-89,-88.500000,-88,-87.580002,-87.080002,-86.830002,-86.830002,-87.250000,-87.419998,-87.440048,-87.460060,-87.480049,-87.500000,-87.500000,-87.500000,-87.500000,-87.500000,-87.520042,-87.540062,-87.560043,-87.580002,-87.669998,-87.919998,-88.169998,-88.250000,-88.250000,-88.500000,-89,-88.580002,-88.169998,-87.580002,-87,-86.500000,-86,-85.500000,-85,-84.669998,-84.250000,-83.830002,-83.419998,-83.250000,-83.250000,-83.500000,-83.500000,-83.500000,-83.669998,-83.669998,-83.830002,-83.669998,-83.419998,-83.419998,-83.169998,-82.750000,-82.330002,-82.169998,-81.750000,-81.419998,-80.830002,-80.330002,-79.830002,-79.580002,-79.080002,-78.669998,-78.250000,-77.830002,-77.500000,-77.169998,-76.750000,-76.750000,-76.250000,-76,-75.580002,-75.580002,-75.500000,-75.250000,-74.830002,-74.419998,-74.169998,-73.500000,-73,-72.669998,-72.669998,-72.250000,-72,-71.669998,-71.330002,-71.169998,-71.419998,-71.919998,-71.669998,-71.500000,-71.750000,-72,-71.750000,-71.669998,-71.080002,-71.080002,-71.419998,-71.419998,-71,-70.580002,-70.169998,-70.330002,-69.919998,-69.750000,-69.330002,-68.830002,-68.419998,-68.330002,-68.169998,-67.580002,-67,-67,-66.580002,-66.169998,-66,-65.580002,-65,-64.500000,-64,-63.419998,-62.750000,-62.605000,-62.459999,-62.314999,-62.169998,-62.377586,-62.585114,-62.792587,-63,-62.669998,-62.330002,-62,-61.580002,-61,-60.830002,-61,-60.250000,-59.669998,-59.169998,-58.669998,-58.500000,-58.580002,-58.169998,-57.669998,-57.330002,-57.080002,-56.500000,-56,-56,-55.500000,-55,-54.500000,-54,-53.669998,-53.250000,-52.750000,-52.330002,-51.830002,-51.500000,-51,-51,-50.669998,-50.500000,-49.919998,-50,-50.419998,-50.750000,-51.169998,-51.330002,-51.419998,-50.830002,-50.580002,-50.419998,-50.419998,-50,-49.500000,-49,-48.419998,-48.580002,-48.580002,-48.750000,-48.500000,-48.169998,-47.830002,-47.250000,-46.669998,-46.169998,-45.500000,-45.330002,-44.830002,-44.669998,-44.419998,-44.580002,-44,-43.500000,-43,-42.500000,-42,-41.500000,-41,-40.500000,-40,-39.500000,-39,-38.500000,-38.169998,-37.830002,-37.330002,-37,-36.500000,-36.500000,-36,-35.419998,-35.169998,-35,-34.830002,-34.750000,-34.830002,-35.080002,-35.330002,-35.580002,-36,-36.250000,-36.750000,-37,-37.330002,-37.580002,-38,-38.419998,-38.919998,-39,-39.080002,-39,-39,-38.919998,-39.080002,-39.169998,-39.169998,-39.500000,-39.580002,-39.580002,-39.580002,-39.669998,-40.169998,-40.330002,-40.830002,-41,-41,-41.500000,-42,-42,-42.500000,-43,-43.500000,-44,-44.669998,-44.500000,-45,-45.419998,-45.750000,-46.330002,-46.830002,-47.250000,-47.750000,-48.169998,-48.580002,-48.580002,-48.580002,-48.500000,-48.580002,-48.750000,-49,-49,-49.419998,-49.830002,-50.169998,-50.330002,-50.669998,-51,-51.500000,-52,-52.419998,-52.580002,-53,-53.500000,-53.580002,-54,-54.500000,-55,-55.669998,-56.250000,-56.830002,-57.169998,-57.830002,-58.330002,-58.500000,-58.330002,-57.500000,-57.169998,-57.419998,-57.169998,-56.750000,-56.669998,-56.669998,-57,-57.419998,-57.580002,-58.169998,-58.669998,-59.330002,-60,-60.500000,-61.250000,-62,-62.250000,-62.330002,-62,-62.169998,-62.419998,-62.250000,-62.330002,-63,-63.830002,-64.330002,-64.830002,-64.914757,-64.999680,-65.084763,-65.169998,-65.127747,-65.085327,-65.042747,-65,-65,-64.500000,-63.750000,-63.580002,-63.669998,-64.169998,-64.500000,-64.500000,-65,-64.330002,-65,-65.250000,-65.169998,-65.169998,-65.580002,-65.580002,-66.169998,-66.830002,-67.169998,-67.500000,-67.419998,-67,-66.500000,-65.750000,-65.669998,-65.830002,-66.330002,-67,-67.500000,-67.669998,-67.830002,-68.500000,-69,-69.169998,-69,-68.830002,-68.330002,-69,-69,-69.500000,-69.580002,-70,-70.750000,-70.919998,-70.919998,-71.250000,-72,-72.250000,-71.330002,-71.080002,-71.500000,-72,-72.500000,-73.169998,-73.500000,-73.500000,-74,-74.169998,-74.500000,-75,-75,-74.330002,-74.169998,-74.330002,-74.500000,-74.706650,-74.913864,-75.121651,-75.330002,-75.246948,-75.164261,-75.081947,-75,-74.830002,-74.500000,-74.500000,-74.669998,-74.500000,-75.330002,-75.330002,-75.247177,-75.164574,-75.082176,-75,-75.125175,-75.250237,-75.375175,-75.500000,-75.419998,-75.580002,-75.419998,-75.419998,-75.330002,-74.919998,-74.500000,-74.500000,-74.419998,-74,-74.500000,-75,-75.500000,-75.500000,-74.750000,-75,-74.500000,-74.669998,-74.500000,-74.330002,-74.500000,-74.250000,-73.830002,-73.500000,-73.500000,-73.669998,-73.580002,-73.830002,-73.669998,-73.580002,-73.330002,-73.419998,-73,-73.169998,-72.830002,-73,-72.750000,-72.750000,-72.687378,-72.624840,-72.562378,-72.500000,-72.562622,-72.625168,-72.687622,-72.750000,-72.687256,-72.624680,-72.562256,-72.500000,-72.625244,-72.750328,-72.875244,-73,-73.169998,-73.580002,-73.750000,-73.830002,-73.669998,-73.669998,-73.250000,-73.330002,-73.419998,-73.419998,-73.669998,-73.500000,-73.080002,-73.080002,-73.080002,-72.830002,-72.669998,-72.500000,-72.169998,-71.919998,-71.830002,-71.580002,-71.669998,-71.330002,-71.500000,-71.500000,-71.580002,-71.669998,-71.580002,-71.250000,-71.330002,-71.500000,-71.250000,-71.169998,-70.919998,-70.919998,-70.580002,-70.750000,-70.500000,-70.500000,-70.580002,-70.500000,-70.500000,-70.500000,-70.500000,-70.250000,-70.169998,-70.080002,-70.169998,-70.169998,-70.080002,-70.250000,-70.330002,-70.330002,-70.830002,-71.169998,-71.500000,-72,-72.500000,-72.830002,-73.500000,-74,-74.500000,-75.169998,-75.500000,-75.830002,-76.250000,-76.169998,-76.500000,-76.669998,-77,-77.169998,-77.500000,-77.669998,-78.169998,-78.169998,-78.330002,-78.500000,-78.669998,-79,-79.500000,-79.669998,-80,-80.330002,-80.830002,-81.169998,-80.830002,-81.169998,-81.330002,-81.330002,-80.830002,-80.330002,-80,-79.830002,-79.669998,-80.080002,-80.169998,-80.580002,-80.919998,-80.750000,-80.750000,-80.919998,-80.500000,-80.500000,-80.080002,NaN,-125.08000,-123.58000,-122,-121,-122,-122.75000,-123.25000,-121.75000,-121.58000,-120.67000,-120.50000,-121,-119.33000,-120,-118.42000,-118.08000,-117.67000,-119.08000,-119.43404,-119.78873,-120.14405,-120.50000,-120.31391,-120.12688,-119.93892,-119.75000,-118.92000,-120,-121.33000,-122.67000,-123.83000,-125.08000,NaN,-117,-116,-115.25000,-114.42000,-113.92000,-113.75000,-112.92000,-112.17000,-111.75000,-110.92000,-110.64812,-110.37582,-110.10311,-109.83000,-109.91447,-109.99928,-110.08447,-110.17000,-109.87750,-109.58500,-109.29250,-109,-110,-110.75000,-111.58000,-111.92000,-112.42000,-113.08000,-113.83000,-114.17000,-115.33000,-115.08000,-114.93378,-114.78838,-114.64379,-114.50000,-114.68787,-114.87549,-115.06287,-115.25000,-115.33000,-115.83000,-117,NaN,-111.25000,-110.33000,-110,-109.25000,-108.25000,-108.04327,-107.83603,-107.62827,-107.42000,-107.56445,-107.70927,-107.85445,-108,-108.58000,-109.17000,-109.67000,-110.17000,-110.67000,-111.25000,NaN,-103.08000,-102.17000,-102.17000,-102.17000,-101.58000,-102.08000,-102.50000,-102.58306,-102.66575,-102.74806,-102.83000,-102.74680,-102.66406,-102.58179,-102.50000,-102.56291,-102.62555,-102.68791,-102.75000,-103.08000,NaN,-99.250000,-98.919998,-98.669998,-98.169998,-98.169998,-97.419998,-97.330002,-96.830002,-96.919998,-97,-97,-96.419998,-96.169998,-96.580002,-97,-97.250000,-97.580002,-97.830002,-98.419998,-99,-99.250000,NaN,-92.080002,-91.580002,-90.919998,-90.500000,-89.750000,-89,-88.250000,-87.750000,-88.419998,-88.419998,-87.750000,-87.330002,-86.669998,-85.830002,-85,-85,-84.875000,-84.750000,-84.625000,-84.500000,-84.562134,-84.624512,-84.687134,-84.750000,-84.669998,-85,-85,-85.750000,-86.169998,-86.500000,-87.330002,-88.080002,-88.419998,-89.080002,-89.419998,-89.830002,-89.830002,-90.500000,-91,-91.580002,-92.080002,NaN,-88,-87.813324,-87.626106,-87.438332,-87.250000,-87.312843,-87.375450,-87.437836,-87.500000,-87.520088,-87.540115,-87.560081,-87.580002,-87.750000,-87.919998,-87.830002,-87.830002,-87.747017,-87.664352,-87.582016,-87.500000,-87.394997,-87.290001,-87.184998,-87.080002,-86.669998,-86.419998,-86.250000,-86.330002,-86.500000,-86.500000,-86.250000,-86.080002,-85.330002,-85,-84.875000,-84.750000,-84.625000,-84.500000,-84.394760,-84.289680,-84.184761,-84.080002,-83.580002,-83.330002,-83.330002,-83.830002,-83.830002,-83.419998,-82.919998,-82.669998,-82.669998,-82.419998,-81.750000,-81.750000,-81.500000,-81.330002,-81.500000,-80.919998,-80.080002,-79.997849,-79.915466,-79.832855,-79.750000,-79.874031,-79.998711,-80.124031,-80.250000,-80.750000,-81.669998,-82.330002,-83,-83.669998,-84.169998,-84,-84.830002,-85.250000,-85.750000,-86.750000,-87,-87.330002,-87.669998,-88,NaN,-83.080002,-82.330002,-81.750000,-81.919998,-82.419998,-83.080002,NaN,-83.500000,-82.830002,-82.250000,-81.669998,-81.080002,-80.500000,-79.830002,-79.250000,-78.830002,-79.500000,-80.169998,-80.500000,-80.919998,-81.500000,-81.830002,-82.500000,-83.080002,-83.500000,NaN,-79.750000,-79.250000,-78.580002,-78,-77.419998,-76.830002,-76.169998,-76.250000,-76.080002,-76.669998,-77,-77.669998,-78.169998,-78.830002,-79.419998,-79.750000,NaN,-91.419998,-91.080002,-90.830002,-91.169998,-91.500000,-91.169998,-91.500000,-91.419998,NaN,-74,-73.419998,-73.330002,-73.669998,-73.500000,-73.750000,-74.330002,-74.169998,-74.169998,-74,NaN,-68.750000,-68.250000,-68.169998,-68,-67.419998,-66.750000,-66.330002,-65.830002,-65.169998,-65.250000,-65.669998,-66.500000,-67.330002,-68.169998,-68,-68.669998,-69.330002,-69.830002,-70,-70.500000,-71.169998,-72,-72,-72,-72.500000,-72.669998,-73.330002,-73.330002,-73.830002,-73.500000,-74,-74.500000,-74.669998,-74,-73.330002,-72.500000,-72.080002,-71.330002,-71,-70.500000,-70.330002,-70.247620,-70.165161,-70.082619,-70,-70.020180,-70.040237,-70.060181,-70.080002,-69.891670,-69.703888,-69.516670,-69.330002,-69.419998,-70.169998,-70.419998,-70.250000,-69.750000,-69.500000,-69.169998,-68.750000,NaN,-61.169998,-60.500000,-60.169998,-60.500000,-59.669998,-59,-58.330002,-57.750000,-57.750000,-58.500000,-58.830002,-59.500000,-59.669998,-60,-60.500000,-61.169998,NaN,-38,-37,-36.250000,-35.830002,-36,-36.580002,-37.250000,-38,NaN,-61.830002,-61.500000,-61.500000,-61.669998,-61,-61,-61.250000,-61.830002,NaN,-78.330002,-78.250000,-77.830002,-77.330002,-76.830002,-76.419998,-76.250000,-76.580002,-76.919998,-77.250000,-77.669998,-78,-78.330002,NaN,-83.070000,-82.870003,-82.650002,-82.612442,-82.574928,-82.537445,-82.500000,-82.582542,-82.665054,-82.747543,-82.830002,-83.050003,-82.949997,-83.070000,NaN,-84.830002,-84.330002,-84.330002,-84,-83.500000,-83,-82.500000,-82,-81.500000,-81,-80.500000,-80.080002,-79.669998,-79.330002,-78.830002,-78.330002,-77.830002,-77.419998,-77,-76.500000,-76,-75.580002,-75.669998,-75.330002,-74.830002,-74.500000,-74.250000,-74.169998,-74.169998,-74.669998,-75,-75.500000,-76,-76.500000,-77,-77.167503,-77.334999,-77.502502,-77.669998,-77.607574,-77.545097,-77.482574,-77.419998,-77.080002,-77.250000,-78,-78.500000,-78.580002,-78.750000,-79.250000,-79.750000,-80.169998,-80.500000,-81.250000,-81.750000,-82.080002,-81.580002,-82.250000,-82.750000,-83.080002,-83.419998,-84,-84.042580,-84.085098,-84.127579,-84.169998,-84.334999,-84.500000,-84.665001,-84.830002,NaN,-74.500000,-74.169998,-73.669998,-73.250000,-72.750000,-72.645111,-72.540154,-72.435112,-72.330002,-72.434807,-72.539742,-72.644806,-72.750000,-72.750000,-73,-73,-73.500000,-73.169998,-72.580002,-72,-71.669998,-71,-70.500000,-69.919998,-69.750000,-69.169998,-69.580002,-68.750000,-68.330002,-68.669998,-69,-69.500000,-70.080002,-70.580002,-70.580002,-71.080002,-71.080002,-71.419998,-71.830002,-72.330002,-72.750000,-73.169998,-73.669998,-73.830002,-74.500000,NaN,-67.169998,-67.169998,-66.580002,-66,-65.669998,-65.919998,-66.330002,-66.750000,-67.169998,NaN,-61.751938,-61.552059,-61.543957,-61.494724,-61.427563,-61.391785,-61.189819,-61.463997,-61.594345,-61.566128,-61.691929,-61.760193,-61.790493,-61.751938,NaN,-60.951080,-61.141327,-61.121338,-60.978741,-60.830997,-60.749863,-60.951080,NaN,-78.250000,-78,-77.750000,-77.750000,-77.687378,-77.624840,-77.562378,-77.500000,-77.542580,-77.585106,-77.627579,-77.669998,-77.919998,-78.419998,-78.169998,-78.250000,NaN,-73.669998,-73.500000,-73.169998,-73,-73.169998,-73.669998,NaN,-78.788040,-78.680023,-78.575752,-78.522217,-77.900017,-77.869293,-78.237938,-78.725670,-78.788040,NaN,-77.870705,-77.772308,-77.553215,-77.044395,-76.967758,-77.127869,-77.183792,-77.240105,-77.385902,-77.225426,-77.262589,-77.220886,-77.237236,-77.145256,-77.319855,-77.577332,-77.870705,NaN,-76.707924,-76.647621,-76.614021,-76.279778,-76.118546,-76.097282,-76.164520,-76.131683,-76.209763,-76.289970,-76.194336,-76.204651,-76.135490,-76.183838,-76.296646,-76.749283,-76.707924,NaN,-75.723358,-75.620346,-75.297928,-75.366516,-75.505318,-75.438606,-75.591408,-75.687988,-75.723358,NaN,-75.297142,-75.078094,-75.025642,-74.937355,-74.808800,-74.847206,-74.963882,-75.207672,-75.149353,-75.331413,-75.297142,NaN,-73.857986,-73.808182,-73.956940,-74.165382,-74.149857,-74.036385,-74.016289,-73.894684,-74.273178,-74.347702,-74.027000,-73.857986,NaN,-74,-73.919998,-73.330002,-72.830002,-72.330002,-72,-72.669998,-73.330002,-74,NaN,-64.419998,-63.750000,-63.080002,-62.500000,-62,-61.669998,-62.250000,-62.919998,-63.500000,-63.750000,-64.419998,NaN,-64.250000,-64,-63.919998,-63.330002,-62.750000,-62,-62.500000,-62.500000,-63.330002,-63.919998,-64.250000,NaN,-83.669998,-83.330002,-82.580002,-81.919998,-81.919998,-82.830002,-83.669998,NaN,-80.080002,-79.250000,-79.330002,-79.750000,-80.169998,-80.080002,NaN,-80,-79.169998,-78.919998,-79.169998,-79.169998,-79.500000,-79.644997,-79.790001,-79.934998,-80.080002,-79.916313,-79.751762,-79.586319,-79.419998,-80,NaN,-82,-81.419998,-81,-80.750000,-81.419998,-82,NaN,-59.330002,-58.919998,-58.419998,-58.750000,-58.419998,-57.919998,-57.669998,-57.250000,-57,-56.669998,-56,-55.500000,-55.750000,-56.169998,-56.500000,-56.830002,-56.080002,-55.500000,-55.919998,-55.330002,-54.669998,-54,-54,-53.500000,-54,-53.750000,-53,-53.750000,-53.919998,-53.669998,-53.330002,-53,-53.250000,-52.750000,-52.919998,-53.080002,-53.669998,-53.669998,-54.169998,-53.919998,-54.419998,-54.830002,-55.330002,-55.919998,-55.419998,-55.419998,-56.080002,-56.830002,-57.580002,-58.419998,-59.169998,-59.330002,NaN,-87.169998,-86.169998,-86.419998,-86.250000,-86,-85,-84.669998,-83.669998,-82.500000,-81.750000,-81.250000,-80.250000,-81.169998,-82,-82.830002,-83.580002,-84.169998,-84.830002,-85.750000,-85.830002,-87.169998,NaN,-77.250000,-76.500000,-75.330002,-74.830002,-75,-75.669998,-76.830002,-77.250000,NaN,-90,-90,-89.580002,-89.080002,-88,-87,-85.419998,-85.064529,-84.709358,-84.354507,-84,-84.379524,-84.756027,-85.129517,-85.500000,-86.080002,-86.500000,-86.419998,-86.330002,-85.330002,-85.669998,-85.580002,-85.500000,-84.330002,-82.919998,-81.669998,-81.169998,-81.500000,-80.830002,-81.169998,-81.169998,-80.169998,-79,-77.830002,-76.830002,-75.750000,-74.330002,-74,-74,-72.419998,-71.250000,-69.750000,-68.330002,-68.118698,-67.909958,-67.703735,-67.500000,-67.606575,-67.712090,-67.816559,-67.919998,-67.623314,-67.329437,-67.038345,-66.750000,-67.084427,-67.417580,-67.749443,-68.080002,-68.080002,-66.750000,-65.169998,-64.250000,-63.169998,-62.169998,-61.419998,-62.080002,-62.330002,-63.500000,-63.830002,-65,-65.500000,-67.169998,-67.169998,-67.419998,-66.830002,-65.750000,-65.080002,-65,-64.250000,-64.500000,-65.750000,-66.830002,-67.750000,-68.919998,-68.500000,-67.750000,-66.919998,-66.169998,-66.169998,-67.169998,-68.080002,-69,-69.330002,-70.330002,-71.080002,-71.919998,-71.919998,-72.750000,-73.669998,-74.669998,-75.750000,-76.500000,-78,-78,-78.580002,-78.250000,-77.669998,-77.500000,-76,-74.669998,-73.669998,-74.580002,-73.750000,-73,-72.834206,-72.667282,-72.499214,-72.330002,-72.413879,-72.498497,-72.583870,-72.669998,-73,-74.250000,-75,-76.169998,-75.830002,-77.500000,-78.080002,-79,-79.830002,-81.330002,-82.330002,-84.330002,-85.750000,-87.330002,-88.250000,-89,-90,NaN,-80.500000,-79.250000,-77.830002,-76.750000,-76.419998,-76.580002,-78.169998,-79.169998,-80.500000,-80.830002,-80.500000,NaN,-96.580002,-95.669998,-94.500000,-93.750000,-93.750000,-95.330002,-96.580002,NaN,-96.169998,-94.330002,-93,-91.250000,-90.750000,-90.477104,-90.206146,-89.937111,-89.669998,-89.796257,-89.921669,-90.046249,-90.169998,-89.809830,-89.453125,-89.099854,-88.750000,-86.750000,-84.830002,-83.080002,-81.580002,-79.830002,-79.830002,-80.419998,-82.169998,-83.669998,-84.750000,-86.500000,-88.169998,-90,-92,-92.169998,-91.830002,-92.169998,-93.250000,-95.080002,-96.250000,-96.169998,NaN,-95,-95,-93.750000,-93.580002,-92,-91.330002,-90.250000,-88,-87.788506,-87.579704,-87.373550,-87.169998,-87.298920,-87.425179,-87.548843,-87.669998,-87.228737,-86.789963,-86.353706,-85.919998,-85.919998,-87.250000,-88.080002,-89.250000,-92,-93.330002,-93.669998,-93.169998,-93.830002,-95,NaN,-90.500000,-89,-86.669998,-86.669998,-86.669998,-85,-82.580002,-80.750000,-76.830002,-74.500000,-72.500000,-69.750000,-67.169998,-64.419998,-62.919998,-61.169998,-61.169998,-62.500000,-64.250000,-64.330002,-66.750000,-68.830002,-70,-71.500000,-74,-75,-75,-75.830002,-78,-77.669998,-79.250000,-77.750000,-79,-81,-81,-81.580002,-82.669998,-84,-85.169998,-87.750000,-89.500000,-89.500000,-88.169998,-87.879524,-87.587692,-87.294518,-87,-87.247528,-87.496696,-87.747520,-88,-88,-87.398376,-86.794426,-86.188263,-85.580002,-86.072273,-86.569695,-87.072266,-87.198715,-87.325485,-87.452583,-87.580002,-87.485748,-87.390923,-87.295517,-87.199524,-86.809586,-86.409859,-86,-85.647827,-85.293762,-84.937813,-84.580002,-84.723740,-84.869942,-85.018669,-85.169998,-85.169998,-86.669998,-85.830002,-83.669998,-82.500000,-79.580002,-77.669998,-80.669998,-83.500000,-85.500000,-88.250000,-90,-90.500000,NaN,-99.500000,-98.830002,-97.669998,-99.500000,NaN,-106.33000,-105.67000,-104.25000,-103,-101.42000,-100,-100,-99.580002,-98.580002,-98.169998,-98,-95.830002,-95.419998,-95.830002,-97.169998,-98.830002,-100,-100.83000,-102.17000,-104.17000,-105,-104.17000,-105.92000,-106.33000,NaN,-97,-95,-92.500000,-92.330002,-93.169998,-95.169998,-97,NaN,-105.67000,-104.75000,-104.58000,-104,-105.33000,-105.67000,NaN,-105,-104,-103,-102,-101.92000,-101.25000,-99.500000,-98,-98,-97.830002,-98.330002,-100.58000,-101.50000,-103,-104,-104.25000,-105,NaN,-104.75000,-104.25000,-103.58000,-104.75000,NaN,-102.92000,-102,-100.50000,-101.42000,-101.25000,-100.17000,-98.830002,-97.750000,-97.578682,-97.409943,-97.243736,-97.080002,-97.335083,-97.586731,-97.835022,-98.080002,-97.724625,-97.371155,-97.019615,-96.669998,-96.250000,-96.419998,-97.830002,-99,-99.919998,-100.92000,-102,-102.33000,-102.92000,NaN,-113.75000,-113,-110.75000,-108.92000,-109.58000,-111,-112,-113.75000,NaN,-115.50000,-114.25000,-114.08000,-114.83000,-115.50000,NaN,-113.58000,-112.25000,-111.08000,-110.81017,-110.54022,-110.27016,-110,-110.04367,-110.08655,-110.12865,-110.17000,-111.75000,-113.25000,-113.58000,NaN,-119.50000,-118.92000,-117.75000,-118.08000,-118.50000,-119.50000,NaN,-124.17000,-122.75000,-121.67000,-120.50000,-119.33000,-117.67000,-116.75000,-115.50000,-116.58000,-116.17000,-117.50000,-118.92000,-119.50000,-120.58000,-121.92000,-123.08000,-124.17000,NaN,-117.75000,-117.17000,-117.17000,-116.42000,-115.75000,-114.33000,-112.75000,-112,-111.42000,-110.91826,-110.41763,-109.91819,-109.42000,-109.58222,-109.74628,-109.91219,-110.08000,-110.01838,-109.95618,-109.89339,-109.83000,-110.05817,-110.28755,-110.51817,-110.75000,-110.56583,-110.37947,-110.19087,-110,-109.17000,-108.58000,-107,-105.67000,-106,-106.17000,-107.42000,-109.50000,-110.67000,-111.67000,-112.75000,-114,-114.50000,-113.25000,-114.25000,-115.25000,-116.33000,-117.75000,NaN,-119,-118.83000,-118,-118,-117,-115.75000,-114.83000,-113.67000,-113.25000,-111.92000,-110.83000,-109.58000,-108,-107.42000,-106.58000,-105,-104.17000,-104.67000,-105.50000,-105.17000,-104.58000,-104.58000,-104.75000,-103.75000,-102.33000,-100.67000,-100.83000,-102,-101.50000,-102.58000,-103.83000,-105.08000,-106,-107.08000,-108.42000,-110,-111.67000,-113.08000,-113.75000,-115.17000,-116.42000,-116.75000,-115.50000,-114,-112.67000,-114,-115.42000,-117.08000,-118.08000,-117.75000,-119,NaN,-125.25000,-124.67000,-124,-123.75000,-124.42000,-122.67000,-121.17000,-119.42000,-117.58000,-116.58000,-115.08000,-116.50000,-117.83000,-119.25000,-119.67000,-120.58000,-121.75000,-123.08000,-123.83000,-125.25000,NaN,165.68594,166.22919,166.17490,166.64885,166.61436,166.47490,166.44250,166.29825,165.99333,166.02260,165.68594,NaN,172.50000,172.83000,173.33000,172.92000,172.50000,NaN,-177.91907,-178.23126,-178.30067,-178.17793,-177.90681,-177.80429,-177.91907,NaN,-176.92000,-176.75000,-176.33000,-176.92000,NaN,-174.18573,-174.37958,-174.54735,-174.30161,-174.34758,-173.98396,-174.18573,NaN,-169.17000,-168.50000,-168,-168,-168.33000,-169.17000,NaN,-167.67000,-167.17000,-167.17000,-166.42000,-166.42000,-167,-167.67000,NaN,-171.75000,-170.50000,-169.83000,-168.83000,-169.83000,-170.75000,-171.75000,-171.75000,NaN,-167.42000,-166.75000,-166.08000,-165.50000,-165.50000,-166.17000,-166.83000,-167.42000,NaN,-154.83000,-153.92000,-153.25000,-152.50000,-152.08000,-152.31120,-152.54161,-152.77121,-153,-152.87477,-152.74969,-152.62477,-152.50000,-152.25000,-153.08000,-153.42000,-154.08000,-154.83000,NaN,-133.08000,-132.33000,-131.67000,-132,-131.67000,-131.83000,-131.33000,-131,-131.83000,-132.25000,-132.50000,-133,-133.08000,NaN,-128.33000,-127.92000,-127.17000,-126.25000,-125.50000,-125,-124.42000,-123.67000,-123.17000,-123.67000,-124.25000,-125,-125,-125.50000,-125.92000,-126.50000,-126.42000,-127.08000,-127.75000,-128.33000,NaN,-73,-72.330002,-70.330002,-68.669998,-65.669998,-64.500000,-65,-65,-65.667412,-66.334999,-67.002586,-67.669998,-67.447845,-67.220573,-66.988022,-66.750000,-65,-63.750000,-61.830002,-61.250000,-62,-59.330002,-54.500000,-51.250000,-50.500000,-47.330002,-46.500000,-44,-39.500000,-36,-31.500000,-27.330000,-24.830000,-24,-21.670000,-21.240444,-20.819050,-20.405630,-20,-20.555950,-21.102850,-21.640823,-22.170000,-25.580000,-26.245491,-26.912436,-27.580666,-28.250000,-28.651779,-29.049013,-29.441740,-29.830000,-28.705425,-27.580000,-26.454575,-25.330000,-25.330000,-25.330000,-25.330000,-25.330000,-23.670000,-23.670000,-23.670000,-21.670000,-21.330000,-22,-23.670000,-24.830000,-22.500000,-20.750000,-19.500000,-18.170000,-16.420000,-13.250000,-12.842430,-12.443393,-12.052657,-11.670000,-12.366874,-13.041944,-13.696049,-14.330000,-15.830000,-17.170000,-18.080000,-18.500000,-19.500000,-19.170000,-19.670000,-18.830000,-18.170000,-18.420000,-20.330000,-21.420000,-21.500000,-20,-19.420000,-19.420000,-20.080000,-20.080000,-18.830000,-19.250000,-21.500000,-20.330000,-20.330000,-21.580000,-22.170000,-22.379297,-22.587391,-22.794291,-23,-22.748611,-22.498146,-22.248608,-22,-21.750000,-22,-23.330000,-24.580000,-23.670000,-22.580000,-21.750000,-21.750000,-21.830000,-23.080000,-24,-24.250000,-24.500000,-25.500000,-25.250000,-26.330000,-26.330000,-25.080000,-23.750000,-23.436489,-23.123642,-22.811474,-22.500000,-22.669485,-22.837639,-23.004473,-23.170000,-23.170000,-24.250000,-25.250000,-26.250000,-27.500000,-28.750000,-30,-31.330000,-32.169998,-33,-33.419998,-33.919998,-34.750000,-35.669998,-37,-38.500000,-39.669998,-40,-41,-40.419998,-40.500000,-40.750000,-41.500000,-42.419998,-42,-42.500000,-42.750000,-42.830002,-43.250000,-43.919998,-45.169998,-45.169998,-45.750000,-46.669998,-48,-49,-49.500000,-50.080002,-50.330002,-51.250000,-51.330002,-52,-52,-52.419998,-53.500000,-53.500000,-53.750000,-53.669998,-53.330002,-52.580002,-51,-50.750000,-51.250000,-52.169998,-53.669998,-54.830002,-54.580002,-54.250000,-52.830002,-51.250000,-51.580002,-52.750000,-52.750000,-53.330002,-54,-55.250000,-55.750000,-55.330002,-55.830002,-55.500000,-55.669998,-56.500000,-56.500000,-57.500000,-58.330002,-58.330002,-60,-61.669998,-63.419998,-65.330002,-66.580002,-68.500000,-69.500000,-68.750000,-70.250000,-71.169998,-70,-68.419998,-70,-70.330002,-71.669998,-73,NaN,-24.330000,-23.750000,-23.670000,-23,-23,-22.250000,-21.500000,-21.420000,-21.420000,-20.330000,-20.250000,-19.670000,-19.250000,-18.250000,-17.580000,-16.830000,-16.250000,-15.670000,-14.750000,-14.670000,-13.670000,-13.670000,-14.500000,-15.830000,-16.750000,-17.670000,-18.750000,-20,-21,-21.437479,-21.875000,-22.312521,-22.750000,-22.564610,-22.377823,-22.189625,-22,-22.143019,-22.287348,-22.433001,-22.580000,-24,-22.830000,-22.644306,-22.457413,-22.269314,-22.080000,-22.246731,-22.413973,-22.581730,-22.750000,-23.580000,-24.330000,NaN,-9.0540400,-8.5061646,-8.3080521,-7.9248972,-8.0049992,-8.2556238,-8.6083593,-9.0474310,-9.0540400,NaN,-18.830000,-17.920000,-18.830000,-18.830000,NaN,9.3299999,9.3299999,9.5799999,9.2500000,9.5000000,9.6700001,9.7500000,9.9200001,9.5799999,9.3299999,8.9200001,8.8299999,8.4200001,8,7.5000000,7,6.5000000,6,5.4200001,5.2500000,5,4.5000000,4,3.4200001,2.8299999,2.3299999,1.8300000,1.8300000,1.2500000,1,0.33000001,-0.25000000,-0.67000002,-1.0800000,-1.5800000,-2,-2.5799999,-3.0799999,-3.8299999,-4.3299999,-4.7500000,-5.3299999,-5.9200001,-6.3299999,-6.9200001,-7.4200001,-7.8299999,-8.3299999,-8.9200001,-9.4200001,-9.8299999,-10.330000,-11,-11.420000,-11.920000,-12.420000,-12.920000,-13.080000,-13.080000,-13.170000,-13.250000,-13.580000,-14,-14.420000,-14.670000,-15,-15.420000,-15.500000,-15.920000,-16.330000,-16.750000,-16.750000,-16.670000,-16.750000,-17,-17.420000,-17,-16.750000,-16.420000,-16.420000,-16.250000,-16.080000,-16,-16,-16.170000,-16.500000,-16.170000,-16.170000,-16.580000,-16.580000,-17,-16.920000,-16.830000,-16.500000,-16.250000,-16,-15.750000,-15.420000,-15,-14.750000,-14.580000,-14.420000,-14.170000,-13.670000,-13.420000,-13.250000,-12.920000,-12.170000,-11.500000,-11.170000,-10.580000,-10.170000,-9.8299999,-9.5799999,-9.8299999,-9.8299999,-9.5000000,-9.2500000,-9.2500000,-8.8299999,-8.8299999,-8.5000000,-8,-7.4200001,-6.8299999,-6.5799999,-6.3299999,-6.1700001,-5.9200001,-5.4200001,-5.1700001,-4.5000000,-4.0799999,-3.4200001,-3,-2.4200001,-1.9200000,-1.2500000,-1,-0.50000000,0,0.50000000,1,1.7500000,2.4200001,2.9200001,3.4200001,3.8299999,4.4200001,5,5.3299999,5.3299999,5.8299999,6.2500000,7,7.4200001,8.1700001,8.6700001,9.0799999,9.5799999,10.080000,10.330000,11,10.750000,10.420000,10.580000,10.920000,11,10.750000,10.330000,10,10.080000,10.500000,10.920000,11.080000,11.670000,12.170000,12.830000,13.580000,14.170000,14.750000,15.330000,15.330000,15.330000,15.580000,16.080000,16.670000,17.500000,18.170000,18.670000,19.170000,19.580000,19.920000,20.080000,20,19.957613,19.915152,19.872614,19.830000,19.892326,19.954769,20.017326,20.080000,20.670000,21.250000,21.830000,22.500000,23.080000,23.170000,23.750000,24.330000,24.920000,25.170000,25.750000,26.330000,26.920000,27.330000,27.830000,28.420000,28.420000,29,29.500000,30,30.580000,31.170000,31.830000,31.750000,32.150002,32.253231,32.355968,32.458221,32.560001,32.517422,32.454895,32.392422,32.330002,32.392693,32.455254,32.517689,32.580002,32.669998,32.919998,33.250000,33.580002,33.669998,33.919998,34,34.330002,34.500000,34.750000,35,35.250000,35.580002,35.500000,35.580002,35.830002,36.169998,36.580002,36.919998,36.919998,37.250000,37.250000,37.169998,37.250000,37.330002,37.580002,38.080002,38.080002,38.580002,38.830002,39.080002,39.169998,39.250000,39.500000,39.830002,40.080002,40.669998,41.169998,41.580002,42.080002,42.419998,42.830002,43.250000,43.419998,42.919998,43.250000,43.580002,43.919998,44.250000,44.750000,45.250000,45.750000,46.330002,46.830002,47.419998,48,48.500000,49,49,49.580002,50.169998,50.580002,51.169998,51.080002,51,50.750000,50.750000,50.419998,50.169998,49.919998,49.750000,49.500000,49.250000,49.080002,48.919998,48.500000,48.169998,47.919998,47.669998,47.250000,46.919998,46.500000,46.169998,45.750000,45.330002,44.830002,44.419998,44,43.580002,43.580002,43.169998,42.919998,42.419998,42.080002,41.750000,41.500000,41.080002,40.669998,40.250000,40.250000,39.919998,39.580002,39.330002,39.080002,38.919998,38.750000,39.169998,39.580002,39.330002,39.330002,39.419998,39.669998,39.830002,40.169998,40.500000,40.500000,40.419998,40.500000,40.500000,40.419998,40.419998,40.580002,40.580002,40.750000,40.669998,40.419998,40.080002,39.750000,39.250000,38.919998,38.250000,37.830002,37.330002,37,36.669998,36.250000,35.830002,35.500000,35.169998,34.750000,34.669998,35,35.169998,35.330002,35.500000,35.500000,35.419998,35.500000,35.250000,34.919998,34.419998,34.419998,33.750000,33.419998,32.919998,32.580002,32.919998,32.919998,32.919998,32.750000,32.580002,32.419998,32,31.500000,31.250000,30.920000,30.670000,30.420000,30,29.580000,29.250000,28.830000,28.500000,28.080000,27.500000,27.080000,26.580000,26,25.750000,25.080000,24.750000,24.250000,24.250000,23.670000,23.250000,22.670000,22.080000,21.750000,21.080000,20.500000,20.170000,19.580000,19.170000,18.750000,18.420000,18.420000,18.250000,17.830000,18.080000,18.330000,18.250000,17.920000,17.580000,17.330000,17.170000,16.920000,16.750000,16.420000,15.920000,15.670000,15.330000,15.250000,15.080000,15.080000,14.920000,14.830000,14.830000,14.580000,14.500000,14.500000,14.420000,14.500000,14.330000,13.920000,13.750000,13.420000,13.250000,12.920000,12.670000,12.420000,12.080000,11.830000,11.750000,11.750000,11.830000,11.830000,12.080000,12.170000,12.330000,12.500000,12.670000,13,13.420000,13.670000,13.670000,13.830000,13.920000,13.830000,13.580000,13.330000,13.170000,13,13.420000,13.250000,13,12.920000,12.670000,12.420000,12.330000,12.170000,12.170000,11.920000,11.580000,11.330000,11,10.670000,10.330000,9.8299999,9.5000000,9.1700001,9,8.7500000,9.2500000,9.3299999,NaN,32.580002,32.169998,32.330002,32.669998,33.250000,34,34.330002,34.669998,34.830002,35,35.250000,35.500000,35.830002,35.750000,35.750000,35.919998,35.750000,36.080002,36,35.500000,35.169998,34.500000,34.080002,33.580002,33.580002,33.169998,32.750000,32.250000,32,31.250000,30.670000,30.500000,29.750000,29.250000,28.580000,28,28.170000,27.670000,27.545000,27.420000,27.295000,27.170000,27.252230,27.334641,27.417229,27.500000,27.395264,27.290352,27.185263,27.080000,27.170000,26.750000,26.250000,26.330000,26.670000,26.920000,26.750000,26.670000,26.830000,26,26.170000,26.170000,26.580000,26.080000,25.750000,25.170000,24.750000,24.250000,24,23.500000,23.750000,23.580000,23.080000,22.580000,22.500000,22.830000,23.170000,23.330000,23.670000,24.080000,24.170000,24.170000,24.580000,24,24,23.500000,22.920000,22.580000,21.830000,21.080000,20.670000,20.330000,20.080000,19.750000,19.330000,19.330000,19.420000,19.500000,19,18.500000,17.920000,17.330000,16.580000,16,15.750000,15.170000,15.170000,14.920000,14.830000,14.170000,14.080000,13.750000,13.750000,13.500000,13.420000,13.580000,13.080000,12.580000,12.170000,12.080000,12.330000,12.170000,12.250000,12.670000,13.080000,13.580000,13.830000,13.920000,14.170000,14.670000,15.250000,16.080000,15.830000,16.330000,16.920000,17.420000,17.920000,18.420000,18.250000,17.920000,17.830000,17.330000,16.920000,16.920000,16.670000,16.500000,17,17,16.500000,16.500000,16.170000,16,15.670000,15.670000,15.830000,16.080000,16,15.750000,15.670000,15,14.750000,14.420000,14,13.580000,12.920000,12.420000,12,11.500000,11,10.920000,10.420000,10.170000,10.080000,9.5000000,9.5000000,9.1700001,8.6700001,8.2500000,8,7.4200001,6.8299999,6.4200001,5.8299999,5.2500000,4.5799999,4,3.5799999,3,3.0799999,3.1700001,2.6700001,2.0799999,1.5000000,1,0.50000000,0,-0.33000001,-0.25000000,-0.12456354,0.00058124162,0.12543540,0.25000000,0.10449973,-0.040666334,-0.18549924,-0.33000001,-0.67000002,-0.82999998,-1.3300000,-1.8300000,-2.1700001,-2.1700001,-2.7500000,-3.3299999,-3.9200001,-4.5000000,-5,-5.5000000,-6,-6.3299999,-6.5000000,-7,-7.4200001,-7.8299999,-8.3299999,-8.9200001,-8.7500000,-8.7500000,-8.6700001,-9.0799999,-9.3299999,-9.2500000,-8.9200001,-8.8299999,-8.6700001,-8.5799999,-8.7500000,-8.8299999,-8.7500000,-9.1700001,-8.9200001,-8.3299999,-8.3299999,-8,-7.2500000,-6.5799999,-5.8299999,-5.0799999,-4.4200001,-3.5799999,-2.7500000,-2.1700001,-1.6700000,-1.4200000,-1.2500000,-1.1700000,-1.0800000,-1,-1.2500000,-1.7500000,-2,-1.9200000,-2.3299999,-2.5000000,-3.1700001,-3.7500000,-4.2500000,-4.6700001,-4.7500000,-4.1700001,-3.6700001,-3,-2.6700001,-2.6700001,-2,-1.4200000,-1.5800000,-1.9200000,-1.3300000,-1.0800000,-0.57999998,0,0.17000000,0.57999998,1.0800000,1.5000000,1.5800000,1.7500000,2.3299999,3,3.5799999,4,4.3299999,4.5799999,4.7500000,5.0799999,5.0799999,5.5000000,5.9200001,5.9200001,5.5000000,5.5000000,6.0799999,7,7,7.3299999,8,8.5000000,8.5799999,9,8.6700001,9,8.6700001,8.6700001,8.1700001,8.0799999,8.0799999,8.2500000,8.6700001,9.4200001,9.8299999,10.500000,10.500000,10.250000,10.250000,10.830000,10.830000,10.170000,9.7500000,9.4200001,10,10,10.920000,10.750000,11.330000,11.330000,11.830000,12.250000,12.920000,13.330000,13.670000,13.250000,13.830000,14.330000,15.170000,16,16.670000,17.500000,18.330000,18.670000,19.250000,19.750000,20,20.750000,21.080000,21,21,21.330000,21.670000,22.420000,22.920000,23.250000,23.830000,24.330000,24.330000,24.330000,24.330000,23.750000,23.500000,23.500000,24.170000,25,25.920000,26.830000,27.920000,28.330000,29.170000,29.420958,29.671280,29.920963,30.170000,30.065998,29.961336,29.856005,29.750000,29.080000,28.330000,27.170000,26.250000,25.330000,24.420000,23.500000,22.580000,22.080000,21.330000,21.330000,21.670000,21.250000,21.170000,21.580000,22.420000,23.250000,24.080000,24.080000,24.670000,25.330000,25.330000,24.500000,23.830000,23.170000,22.420000,22,21.420000,21.500000,21,21.670000,21,20.670000,19.830000,19.170000,18.420000,17.750000,17.420000,17.330000,17.170000,17.250000,17.920000,18.580000,18.830000,18.580000,18,18.330000,17.580000,16.830000,16.830000,16.670000,16.670000,16.500000,16.330000,15.920000,15.330000,14.670000,14.170000,14.250000,13.670000,13,13,12.670000,12.920000,12.330000,12,11.670000,11.330000,11.080000,10.580000,10.250000,9.7500000,9,8.5000000,7.6700001,6.8299999,6,5.5799999,5.6700001,6.1700001,6.1700001,5.4200001,5.2500000,5.5799999,5.0799999,5,4.9579191,4.9155612,4.8729224,4.8299999,4.9341726,5.0388937,5.1441684,5.2500000,5.1681590,5.0858812,5.0031629,4.9200001,5.1059337,5.2929072,5.4809275,5.6700001,6.3299999,7,8,8.5000000,8.9200001,9.5000000,10.080000,10.670000,11.330000,12.170000,12.580000,13,13.330000,13.830000,14.670000,15,16.170000,15,14,12.920000,13.670000,13.670000,14.000631,14.332517,14.665644,15,14.856205,14.711610,14.566210,14.420000,14.645583,14.872441,15.100578,15.330000,16.170000,15.920000,16.580000,16.670000,16.894968,17.121616,17.349955,17.580000,17.435396,17.290529,17.145395,17,17,18.080000,18.920000,20.170000,21.500000,22.330000,23.330000,24.250000,24.830000,25.670000,25.580000,26.580000,26.830000,27.750000,29.080000,30.170000,31.170000,30,29.688526,29.376358,29.063511,28.750000,29.066330,29.380095,29.691313,30,31.250000,31.250000,32.080002,33.080002,33.080002,34.500000,35.830002,37,38,39,40,40.919998,41.250000,41.250000,40.580002,39.500000,38.330002,37.250000,36.250000,35.330002,34.330002,33.169998,32.942406,32.713215,32.482418,32.250000,32.397240,32.542969,32.687218,32.830002,33.669998,34.669998,34.669998,34.669998,34.669998,35.750000,36.750000,38,38,38,37.250000,36.500000,36.919998,37.750000,38.669998,39.500000,40.669998,40.169998,40.046486,39.921989,39.796501,39.669998,39.875523,40.082355,40.290512,40.500000,41.500000,42.169998,43.169998,43.919998,44.500000,44.500000,43.830002,44.169998,44.169998,43.250000,44.500000,45.669998,46.250000,46.669998,45.500000,45.353062,45.207428,45.063080,44.919998,45.148636,45.376514,45.603638,45.830002,46.330002,47.330002,47.330002,48.169998,48.169998,49.080002,50.169998,51,52.080002,53,53.919998,54,54.830002,55.169998,56.169998,57.250000,58.169998,59.080002,59.080002,59.830002,59.830002,60.500000,61.080002,60.500000,60.169998,59.169998,58.580002,59.080002,60.169998,61.750000,63,64.080002,65.080002,65.080002,66,67.080002,67.750000,68.580002,69.080002,68.330002,67.830002,66.919998,66.919998,67.330002,66.830002,67,68.250000,68.750000,68.919998,69.500000,70.080002,70.350464,70.622284,70.895462,71.169998,71.296814,71.422401,71.546799,71.669998,71.584084,71.498787,71.414093,71.330002,71.708961,72.085281,72.458961,72.830002,72.830002,72.830002,72.830002,72.830002,72.725784,72.622726,72.520805,72.419998,72.270035,72.121727,71.975060,71.830002,72.043427,72.254547,72.463394,72.669998,72.669998,72.669998,72.669998,72.669998,72.669998,72.669998,72.669998,72.669998,72.647034,72.624382,72.602036,72.580002,72.580002,72.580002,72.580002,72.580002,72.833557,73.084724,73.333527,73.580002,73.580002,73.169998,73.169998,72.500000,71.830002,70.500000,71.580002,72.500000,73.500000,74,74.830002,74.500000,74.580002,74.808052,75.037399,75.268051,75.500000,75.106094,74.711441,74.316063,73.919998,73.669998,73.830002,74.330002,73.830002,73.169998,73.750000,74.669998,75.169998,75.080002,74.169998,74.500000,75.500000,75.750000,75.330002,75.330002,76.919998,76.919998,78.500000,78,76.580002,76.080002,76.919998,77.750000,78.330002,78.001953,77.670952,77.336975,77,77.185562,77.372414,77.560555,77.750000,78.500000,79.500000,80.580002,81.580002,81.890511,82.202354,82.515518,82.830002,82.667786,82.503731,82.337814,82.169998,80.830002,80.830002,80.330002,82,83.750000,85.250000,87,86.500000,86.580002,87.500000,88.669998,90.580002,92.169998,93.250000,94.750000,94.750000,95.304985,95.865005,96.430023,97,96.916046,96.833069,96.751060,96.669998,97.351250,98.036766,98.726402,99.419998,99.316856,99.212486,99.106880,99,101,101,102.50000,104.08000,104.58984,105.09309,105.58978,106.08000,105.61347,105.15300,104.69853,104.25000,104.68748,105.12500,105.56252,106,106.37669,106.75227,107.12672,107.50000,107.22243,106.95000,106.68256,106.42000,106.77248,107.12500,107.47752,107.83000,108.17000,109.58000,111.17000,112.42000,113.50000,113.83000,113.67000,112.50000,111,109.67000,108.33000,107.17000,106.50000,107.58000,108.83000,110.17000,110.17000,110.00436,109.83749,109.66937,109.50000,109.66561,109.83247,110.00060,110.17000,111.17000,112,113,113.67000,114.83000,115.92000,117.25000,118.67000,118.50000,120,122,123.33000,122.83000,123,124.83000,126.92000,128.58000,129.83000,129.50000,128.75000,129.42000,130.33000,131.25000,131.25000,132,132.25000,132.58000,133.50000,134.42000,135,135.83000,136.67000,138.58000,138.97873,139.37666,139.77376,140.17000,140.04707,139.92278,139.79709,139.67000,139.33000,139.75000,141.17000,140.67000,142.42000,143.83000,145.25000,146.83000,148.50000,149.83000,150,150.67000,151.58000,152.42000,152.42000,153.50000,154.58000,156,157.50000,157.50000,158.83000,159.67000,159.75378,159.83670,159.91878,160,159.87309,159.74748,159.62312,159.50000,159.79509,160.08846,160.38008,160.67000,162.25000,164,165.67000,167,167.67000,168.25000,169.42000,169.17000,168.25000,168.33000,169.33000,169.58000,170.42000,171,170.58000,170.58000,172,173.33000,174.67000,176.17000,177.42000,178.67000,179.75000,180,180,180.92000,181.83000,183.08000,184.17000,185,185.50000,186.83000,188.33000,189.17000,189.42314,189.67418,189.92313,190.17000,189.98112,189.79317,189.60612,189.42000,188.92000,187.83000,187.83000,187.25000,187,186,184.92000,184.17000,184,183,182.33000,181.50000,181.17000,181,180.08000,180.75000,180.33000,180,180,179.58000,178.67000,177.50000,177.50000,178.33000,178.58000,178.83000,179.25000,179.67000,179,178.17000,177,176.25000,175.33000,174.58000,173.83000,173.08000,172.33000,171.50000,170.67000,170.67000,170.33000,169.83000,169.17000,168.25000,167.50000,166.83000,166.17000,166.17000,165.33000,164.75000,164.17000,163.33000,163.17000,162.92000,162.33000,161.92000,162.08000,162.58000,163.17000,162.67000,162.67000,163.08000,163.25000,162.83000,162.42000,161.92000,161.58000,161.67000,162.08000,161.67000,161.67000,161.17000,160.42000,159.92000,159.83000,159.92000,159.17000,158.58000,158.42000,157.92000,157.33000,156.67000,156.50000,156.50000,156.42000,156.08000,156,155.83000,155.67000,155.50000,155.42000,155.50000,155.75000,156,156.67000,157,156.83000,157.50000,158.25000,159,159.67000,159.67000,160.08000,160.92000,161.58000,161.92000,162.67000,163.50000,163.75000,163.92000,164.08000,164.75000,164.42000,163.25000,162.92000,162.92000,162.25000,161.67000,161,160.17000,159.92000,159.83000,159.95326,160.07767,160.20325,160.33000,160.12169,159.91393,159.70670,159.50000,158.83000,157.92000,156.92000,156.33000,155.75000,155,154.50000,154.17000,154.17000,154.83000,154.91547,155.00063,155.08546,155.17000,154.87692,154.58423,154.29192,154,153.33000,152.92000,152,151.33000,151.08000,151.67000,151.33000,150.83000,150.17000,149.50000,149,148.92000,148.83000,148.17000,147.42000,146.50000,145.92000,145.58000,144.67000,143.67000,142.67000,142,141.67000,141,140.58000,140.25000,139.67000,139.67000,139,138.50000,137.92000,137.25000,136.58000,135.92000,135.17000,135.25000,135.92000,136.67000,136.67000,136.67000,137.08000,137.67000,137.67000,137.58450,137.49933,137.41451,137.33000,137.55931,137.78908,138.01930,138.25000,138.83000,139.50000,140.17000,140.25000,140.75000,141.33000,141.08000,141.08000,141.33000,141.08000,140.75000,140.50000,140.42000,140.42000,140.50000,140.50000,140.33000,140.17000,139.50000,139,138.50000,138.25000,137.92000,137.50000,136.92000,136.33000,135.67000,135.50000,135,134.33000,133.75000,133.08000,132.33000,132.33000,131.75000,131.50000,131.17000,130.83000,130.67000,130.08000,129.58000,129.67000,129.67000,129.25000,129.25000,128.75000,128.25000,127.83000,127.70488,127.57983,127.45488,127.33000,127.37261,127.41515,127.45762,127.46822,127.47882,127.48941,127.50000,127.48933,127.47866,127.46800,127.45735,127.41480,127.37235,127.33000,127.45533,127.58044,127.70533,127.83000,128.25000,128.50000,128.83000,129.17000,129.33000,129.42000,129.42000,129.33000,129.08000,128.50000,127.75000,127.17000,126.58000,126.33000,126.33000,126.75000,126.50000,126.17000,126.75000,126.58000,126.08000,125.33000,124.75000,124.75000,125,125.17000,125.42000,125.08000,124.67000,124.08000,123.50000,123,122.42000,122.08000,121.58000,121.17000,121.67000,121.33000,121.50000,121.92000,122.25000,121.92000,121.25000,120.83000,120.42000,119.92000,119.42000,119.25000,119,118.42000,118,117.67000,117.58000,117.92000,117.92000,118.33000,118.83000,118.92000,119.33000,119.75000,120,120.33000,120.83000,121.17000,121.58000,122.08000,122.20511,122.33015,122.45512,122.58000,122.51719,122.45459,122.39219,122.33000,122,121.50000,120.83000,120.67000,120.17000,119.67000,119.42000,119.17000,119.75000,120.33000,120.50000,120.67000,120.83000,120.92000,121.25000,121.67000,121.83000,121.83000,121.25000,121.83000,121.92000,121.50000,121.17000,120.92000,120.42000,120.75000,121.33000,121.67000,122.08000,122,121.92000,121.67000,121.50000,121.58000,121.42000,121.08000,120.83000,120.58000,120.33000,120,119.67000,119.75000,119.67000,119.42000,119.17000,118.83000,118.67000,118.17000,118.17000,118.17000,117.83000,117.42000,117,116.50000,116,115.50000,115,114.50000,114.17000,113.67000,113.50000,113.08000,113,112.50000,112,111.50000,110.92000,110.42000,110.25000,110.50000,110.25000,109.92000,109.75000,109.67000,109.75000,109.42000,109,108.50000,108,108,107.58000,107.08000,106.67000,106.42000,105.92000,105.75000,105.58000,105.92000,106.33000,106.42000,106.83000,107.17000,107.67000,108.08000,108.42000,108.83000,109,109.17000,109.25000,109.25000,109.25000,109.17000,109.17000,109,108.50000,108.08000,107.67000,107.25000,106.67000,106.67000,106.67000,106.33000,105.83000,105.42000,105,104.83000,104.83000,104.87245,104.91493,104.95745,105,104.87505,104.75007,104.62505,104.50000,104.25000,103.67000,103.25000,103,102.83000,102.58000,102.25000,101.83000,101.42000,100.92000,100.92000,100.42000,100,99.919998,99.919998,99.750000,99.580002,99.330002,99.169998,99.169998,99.330002,99.830002,99.830002,99.919998,100.25000,100.42000,100.58000,100.92000,101.50000,101.83000,102.25000,102.67000,103.08000,103.42000,103.42000,103.42000,103.42000,103.42000,103.75000,104.08000,104.25000,103.50000,103.17000,102.75000,102.25000,101.92000,101.42000,101.33000,100.92000,100.58000,100.67000,100.42000,100.33000,100.33000,100.33000,100.08000,99.750000,99.419998,99.080002,98.669998,98.419998,98.250000,98.250000,98.500000,98.500000,98.500000,98.750000,98.750000,98.500000,98.750000,98.580002,98.250000,98.080002,97.919998,97.830002,97.750000,97.580002,97.250000,96.919998,96.750000,96.250000,95.830002,95.500000,95.080002,95.080002,94.750000,94.250000,94.419998,94.580002,94.500000,94.330002,94.169998,93.830002,93.580002,93.750000,93.500000,93.169998,92.919998,92.500000,92.169998,92,91.919998,91.750000,91.419998,90.919998,90.580002,90.250000,89.750000,89.250000,88.750000,88.330002,88.169998,88,87.580002,87.080002,87.080002,86.919998,87,86.750000,86.419998,85.919998,85.500000,85.080002,84.830002,84.500000,84.080002,83.669998,83.330002,83,82.580002,82.330002,82.250000,82,81.500000,81.169998,81,80.419998,80.169998,80.080002,80.169998,80.250000,80.330002,80.250000,80,79.750000,79.750000,79.750000,79.830002,79.830002,79.330002,79,79,78.580002,78.169998,78,77.580002,77.169998,76.830002,76.500000,76.330002,76.169998,76,75.830002,75.580002,75.250000,75,74.830002,74.669998,74.500000,74.419998,74.080002,73.750000,73.500000,73.330002,73.250000,73.169998,73,73,72.830002,73,72.830002,72.669998,72.750000,72.830002,72.580002,72.500000,72.580002,72.330002,72.169998,72.080002,71.669998,71.169998,70.580002,70.080002,69.669998,69.330002,69.080002,69.669998,70.169998,70.330002,69.750000,69.169998,68.669998,68.330002,67.919998,67.419998,67.330002,67.169998,67.169998,66.830002,66.580002,66.080002,65.580002,65.169998,64.669998,64.250000,63.830002,63.500000,62.919998,62.419998,61.830002,61.169998,60.750000,60.169998,59.669998,59.169998,58.580002,58,57.330002,57.169998,57.080002,56.750000,56.250000,55.750000,55.330002,54.750000,54.330002,53.830002,53.500000,53.500000,53,52.580002,52.169998,51.500000,51.250000,51.080002,50.669998,50.330002,50,49.580002,49.250000,48.919998,48.580002,48.330002,47.750000,48.169998,48.330002,48.580002,48.830002,49.250000,49.669998,50.080002,50.250000,50.169998,50.500000,50.669998,51,51.080002,51.330002,51.580002,51.580002,51.669998,51.580002,51.250000,51.669998,51.830002,52.419998,52.750000,53.250000,53.830002,54.250000,54.500000,55,55.330002,55.669998,56.080002,56.250000,56.500000,56.419998,56.419998,56.419998,56.830002,57.250000,57.750000,58.250000,58.830002,59.080002,59.419998,59.830002,59.580002,59.330002,59.330002,59,58.750000,58.500000,58.080002,57.830002,57.750000,57.919998,57.500000,57.080002,56.750000,56.580002,56.330002,55.919998,55.419998,55.250000,54.830002,54.419998,53.919998,53.419998,52.919998,52.419998,52.250000,52.250000,51.750000,51.250000,50.750000,50.250000,49.669998,49.169998,48.830002,48.830002,48.330002,47.830002,47.419998,47.080002,46.580002,46.080002,45.669998,45.419998,44.919998,44.419998,43.919998,43.500000,43.169998,43.250000,43.080002,42.919998,42.750000,42.669998,42.750000,42.669998,42.419998,42.080002,41.750000,41.500000,41.250000,41,40.750000,40.330002,39.669998,39.500000,39.500000,39.169998,39.080002,39,39.080002,39,38.750000,38.419998,38,37.500000,37.250000,37.080002,36.750000,36.419998,36.080002,35.750000,35.500000,35.169998,34.669998,34.830002,35,35,34.669998,34.419998,34.419998,34.169998,33.750000,33.419998,33.250000,33,32.750000,32.750000,32.580002,NaN,112.83000,111.58000,112.08000,113.33000,112.83000,NaN,26.580000,27.170000,27.750000,27.750000,28.420000,29,28.920000,29.420000,28.830000,28.170000,27.420000,27.080000,26.580000,NaN,13.080000,13.330000,13.500000,13.830000,13.920000,14.170000,14.580000,15.080000,15.250000,14.750000,14.170000,14.170000,13.920000,13.420000,13.080000,NaN,31.670000,31.830000,32.250000,32.750000,33.419998,33.830002,33.250000,33.580002,33.919998,34.080002,34.250000,34,33.500000,33,32.419998,31.830000,31.670000,31.830000,31.750000,31.670000,NaN,29.250000,29.500000,29.830000,30.330000,30.580000,30.500000,31.080000,31,30.750000,30.500000,30.580000,30.170000,30.064949,29.959932,29.854950,29.750000,29.812536,29.875048,29.937536,30,29.957468,29.914959,29.872469,29.830000,29.670000,29.420000,29.330000,29.080000,29.250000,29.080000,29.330000,29.250000,NaN,34.080002,34.169998,34.330002,34.330002,34.669998,34.750000,35.080002,35.330002,35.250000,34.919998,34.830002,34.830002,34.872570,34.915092,34.957569,35,34.917370,34.834827,34.752373,34.669998,34.580002,34.500000,34.080002,34,34.250000,34.250000,34.419998,34.080002,NaN,27.500000,27.920000,28.080000,28.580000,29.170000,29.830000,30.500000,31.080000,31.580000,32.080002,32.580002,33.250000,33.830002,34.500000,35,35.330002,36,36.330002,36.750000,37.250000,37.669998,38.169998,38.750000,39.330002,39.919998,40.500000,41.080002,41.580002,41.669998,41.419998,41.419998,41.250000,41,40.330002,39.830002,39.500000,39,38.500000,38,37.669998,37.250000,37,36.669998,36.080002,35.580002,35.080002,34.580002,34.250000,33.750000,33.419998,33.580002,33.250000,32.669998,33.080002,33.750000,33.169998,32.580002,31.830000,32.080002,31.420000,30.830000,30.830000,30.580000,30.170000,29.580000,29.670000,29.500000,29,28.670000,28.670000,28.580000,28,27.920000,27.500000,NaN,34.419998,34.750000,35,35.500000,36.080002,36.669998,37.330002,37.750000,38.250000,37.919998,37.669998,38.169998,38.750000,39.330002,39,38.419998,37.580002,36.830002,36.080002,35.419998,35,34.419998,NaN,46.669998,46.669998,47.080002,47.419998,47.419998,47.419998,47.830002,48.250000,48.669998,49,49.169998,49.669998,49.815258,49.960346,50.105259,50.250000,50.124874,49.999832,49.874874,49.750000,49.419998,49.250000,49.169998,48.750000,48.830002,48.919998,49,49.500000,50.169998,50.330002,51,51.580002,52.419998,53.169998,53.919998,54,54,53.750000,53.750000,54,53.580002,53.419998,53.500000,52.750000,52.669998,52.919998,53.500000,54.169998,54.750000,54.330002,53.919998,53.669998,53,52.669998,52.750000,52.419998,52.397610,52.375149,52.352612,52.330002,52.414585,52.499447,52.584583,52.669998,52.627628,52.585171,52.542629,52.500000,51.830002,51.330002,51.169998,50.750000,50.169998,50.250000,50.919998,51.419998,51.419998,51.169998,51.314369,51.459160,51.604370,51.750000,51.937275,52.124702,52.312279,52.500000,53.080002,53.669998,54.250000,53.919998,53.830002,53.669998,53.169998,52.580002,52.080002,51.419998,50.919998,50.169998,49.500000,48.919998,49,48.500000,48.250000,47.580002,47.330002,47,46.669998,NaN,58.169998,58.169998,58.330002,58.330002,59,59.669998,59.830002,60.500000,61.080002,61.080002,61.500000,61.830002,61.500000,61,61,61.330002,61.669998,61,60.750000,60.080002,60.080002,59.750000,59.500000,59,58.669998,58.580002,58.169998,NaN,73.419998,73.830002,74.080002,74.250000,74.169998,74.750000,75.169998,76,76.830002,77.330002,78,78.750000,79.250000,78.750000,78.330002,77.830002,77.330002,76.830002,76.080002,75.250000,74.750000,74.169998,73.669998,73.419998,NaN,103.58000,104.50000,105.25000,105.92000,106.25000,107,107.83000,108.33000,109,109.42000,109.50000,109.67000,109.92000,109.50000,109.25000,109.17000,108.83000,108.50000,108.17000,107.58000,107,106.58000,106.08000,105.67000,105.25000,104.50000,103.58000,NaN,30,30.580000,30.920000,31.080000,31.500000,31.750000,32.500000,32.830002,32.830002,32.500000,31.830000,31.420000,30.750000,30.170000,30,NaN,34.500000,34.830002,35.500000,35.500000,36,36.419998,36.419998,36,35.750000,35.830002,35.250000,34.500000,34.830002,35.330002,35.330002,34.669998,34.500000,NaN,43.250000,43.580002,43.919998,44.080002,44.419998,44.500000,44.250000,44.250000,44,44,43.919998,44.250000,44.500000,44.919998,45.419998,45.919998,46.419998,46.830002,47.250000,47.669998,47.580002,47.919998,47.830002,48.330002,48.750000,48.830002,48.830002,49.250000,49.580002,49.830002,49.919998,50.169998,50.330002,50.419998,50.080002,49.669998,49.750000,49.669998,49.419998,49.419998,49.419998,49.330002,49.250000,49,48.830002,48.669998,48.500000,48.419998,48.250000,48.080002,47.919998,47.830002,47.750000,47.669998,47.500000,47.330002,47.169998,46.830002,46.419998,45.919998,45.500000,45,44.580002,44.169998,43.750000,43.669998,43.580002,43.330002,43.250000,43.250000,NaN,55.169998,55.580002,55.830002,55.750000,55.330002,55.169998,NaN,57.330002,57.500000,57.750000,57.750000,57.330002,NaN,53.330002,53.669998,54.169998,54.580002,54.080002,53.669998,53.330002,NaN,68.830002,69,69.330002,69.669998,70,70.580002,70.419998,70,69.830002,69.500000,68.919998,69.169998,68.830002,NaN,92.680725,92.531227,92.753311,92.914330,92.965225,92.680725,NaN,92.867722,92.827248,92.883194,92.979454,93.064552,93.076912,92.867722,NaN,96.407074,96.080315,95.809090,95.848045,95.973999,96.255836,96.407074,NaN,97.250000,97.500000,98,98,97.580002,97.250000,NaN,98.750000,99,99.419998,99.080002,98.830002,98.750000,NaN,79.750000,79.830002,79.919998,80.169998,80,80.580002,80.919998,81.250000,81.500000,81.830002,81.830002,81.669998,81.250000,80.669998,80.250000,80,79.830002,79.750000,79.750000,NaN,108.67000,109.08000,109.58000,110,110.50000,111,111,110.67000,110.50000,110.17000,109.67000,109.25000,108.75000,108.67000,108.67000,NaN,120.17000,120.50000,120.75000,121.08000,121.58000,121.92000,121.92000,121.67000,121.50000,121.33000,121,120.83000,120.67000,120.33000,120.17000,120.17000,NaN,129.50000,130,130.42000,130.92000,131.08000,131.58000,131.67000,131.92000,131.67000,131.42000,131.33000,130.75000,130.17000,130.17000,130.17000,130.50000,130.50000,130.25000,130.17000,129.75000,129.50000,NaN,132.25000,132.67000,132.83000,133.33000,133.58000,134.08000,134.58000,134.67000,134.33000,134.08000,133.75000,133.25000,133.08000,132.92000,132.42000,132.25000,NaN,130.92000,131.42000,131.83000,132.33000,132.75000,133.25000,134,134.67000,135.25000,135.67000,136,136,136.33000,136.67000,136.75000,137.17000,137,137,137.58000,138.17000,138.17000,138.58000,138.83000,139.33000,139.50000,139.83000,140,140,140,140,140.33000,140.67000,141.08000,141.08000,140.75000,140.83000,141.42000,141.33000,141.42000,141.75000,141.92000,141.83000,141.50000,141.50000,141.08000,140.92000,141,140.92000,140.67000,140.58000,140.75000,140.75000,140.42000,140.33000,139.75000,139.83000,139.58000,139.08000,138.83000,138.67000,138.08000,137.25000,136.75000,136.50000,136.75000,136.17000,135.75000,135.42000,135.17000,135.17000,135.50000,134.92000,134.50000,133.92000,133.50000,132.92000,132.33000,132,131.50000,130.92000,130.92000,NaN,139.83000,140.42000,140.33000,140.75000,141.25000,141.33000,141.25000,141.58000,141.67000,141.75000,141.50000,141.92000,142.33000,142.67000,142.67000,143,143.58000,144.17000,144.67000,145.33000,145,145.25000,145.25000,145.83000,145.33000,144.75000,144.17000,143.67000,143.33000,143.25000,142.50000,141.83000,141.33000,140.92000,140.67000,140.33000,140.25000,140.67000,141.08000,140.50000,140,140,139.75000,139.83000,NaN,127.66799,127.65637,127.81740,128.30327,128.34015,128.34779,127.96155,127.79272,127.66799,NaN,129.29555,129.24274,129.23155,129.29333,129.52495,129.72638,129.29555,NaN,145.44214,146.07005,146.39491,145.44214,NaN,146.92000,147.42000,147.92000,148.33000,148.83000,148.17000,147.50000,146.92000,NaN,149.50000,150,150.50000,149.83000,149.50000,NaN,155.17000,155.67000,156.08000,156.08000,155.83000,155.17000,155.17000,NaN,137.25000,137.50000,138.08000,137.58000,137.25000,NaN,163.33000,163.67000,164.25000,164.42000,163.33000,NaN,141.75000,142.25000,142.31223,142.37463,142.43723,142.50000,142.43797,142.37563,142.31297,142.25000,142.35484,142.45979,142.56485,142.67000,142.92000,143,143.17000,143.17000,143.08000,143.33000,143.50000,143.67000,143.92000,144.17000,144.33000,143.75000,143.25000,143.25000,142.92000,142.83000,142.58000,142.50000,142.67000,143,143.08000,143.42000,143.42000,143,142.58000,142.25000,142,141.75000,142,142,142.17000,142,141.83000,142,142.08000,142.08000,142,142.08000,142,141.67000,141.67000,141.83000,141.75000,NaN,180,178.83000,178.67000,180,181.75000,181.96040,182.16887,182.37538,182.58000,182.13800,181.69901,181.26300,180.83000,180,NaN,140.58000,141,142.25000,143.50000,143.50000,141.58000,140.58000,NaN,140.17000,141,141,140.33000,140.17000,NaN,146.50000,147.33000,149.25000,151,150.50000,149.25000,147.25000,146.50000,NaN,137.17000,137.50000,139,141,142,143.25000,144,145,145,144,142.83000,142,140.50000,139.25000,138.08000,137.17000,NaN,99.330002,99.830002,100.58000,101.25000,102.33000,103.92000,105,105,103.17000,101,99.330002,NaN,91.169998,92.669998,93.169998,95.580002,96.419998,96.695534,96.967339,97.235466,97.500000,97.372505,97.246696,97.122536,97,97.148712,97.294907,97.438644,97.580002,99.250000,99.485580,99.717392,99.945503,100.17000,99.997505,99.828400,99.662598,99.500000,99.830002,98.330002,96.750000,94.669998,93.830002,91.830002,91.169998,NaN,51.669998,51.669998,51.669998,51.669998,51.669998,51.937252,52.206329,52.477242,52.750000,52.688377,52.626175,52.563385,52.500000,52.545643,52.591442,52.637409,52.683533,52.729820,52.776276,52.822891,52.869675,53.058479,53.250000,53.517063,53.786076,54.057049,54.330002,54.206825,54.082443,53.956841,53.830002,54.919998,55.750000,55.750000,57.500000,57.500000,58.169998,59.250000,61.169998,63.169998,65.169998,66,67.750000,69.080002,68.830002,67.250000,65.500000,63.830002,62.250000,60.750000,59.830002,58.669998,57.830002,57,56.169998,55.580002,55.500000,55.750000,56.330002,56.669189,57.005577,57.339176,57.669998,57.481312,57.293415,57.106312,56.919998,55.330002,53.830002,53.583221,53.334309,53.083241,52.830002,52.544598,52.256157,51.964638,51.669998,NaN,48.750000,48.500000,49.169998,50.330002,50,48.750000,NaN,63.248936,62.947983,63.144978,63.367226,64.308342,64.742432,65.141998,65.364555,65.234703,64.840904,63.248936,NaN,59.648144,59.456367,59.579586,59.789795,60.406391,61.367126,61.993614,62.217430,61.858395,61.205341,60.756351,59.648144,NaN,56.639359,56.542294,56.069351,56.100079,56.299641,57.028126,57.043949,56.925987,56.639359,NaN,57.508308,58.450150,59.002480,58.613926,57.728737,57.640331,57.508308,NaN,54.250000,54.830002,56.500000,56.500000,58.500000,58.830002,57.669998,58.500000,56.330002,54.250000,NaN,53.169998,54,54.254272,54.505669,54.754234,55,54.541481,54.083603,53.626427,53.169998,NaN,44.500000,47,48,48,50.330002,51.169998,50,50,48.419998,47,47,45.669998,44.500000,NaN,11,13.830000,15.500000,16.330000,18,18,20,21,23,24.830000,24.830000,27,27,25.670000,23.830000,20.920000,18.750000,19,21.500000,22.170000,23.170000,24.830000,22.670000,20.830000,21.670000,20.670000,20.250000,19,18.920000,18.080000,17.330000,17,15.170000,14,13.670000,14.016616,14.367127,14.721575,15.080000,14.602531,14.125000,13.647469,13.170000,11.670000,11,11,NaN,-7.4200001,-7.2500000,-6.3299999,-6.9200001,-7.4200001,NaN,-1.3834395,-1.4489599,-1.4066745,-1.4821186,-1.2856836,-1.2275578,-1.0810091,-1.3834395,NaN,-3.0374002,-3.2808065,-3.4012024,-3.3346920,-3.1567438,-2.9256713,-2.9666162,-3.0374002,NaN,-7.2500000,-7,-7,-6.1700001,-6.4200001,-7.2500000,NaN,9.7500000,10.280000,10.750000,10.700000,10.080000,9.7500000,NaN,11.080000,11.750000,12.420000,12.460310,12.500412,12.540308,12.580000,12.477049,12.374399,12.272050,12.170000,12.420000,11.830000,11.250000,11.080000,NaN,11,11.580000,12.080000,11.830000,11.330000,11,NaN,18.080000,18.420000,19.170000,18.750000,18.750000,18.250000,18.080000,NaN,21.830000,22.330000,23.170000,22.670000,22.170000,21.830000,NaN,22.330000,22.500000,23,22.420000,22.330000,NaN,-5.5799999,-5,-4.5000000,-4.0799999,-3.5000000,-3,-2.6700001,-3.3299999,-3.8299999,-4.3299999,-5,-5.0423241,-5.0847650,-5.1273236,-5.1700001,-5.0231166,-4.8758225,-4.7281175,-4.5799999,-4.0799999,-4.0799999,-4.6700001,-4.3299999,-4.5000000,-3.5799999,-3,-3,-2.6700001,-3.1700001,-3.5799999,-3.2500000,-4,-4.7500000,-4.8319817,-4.9143071,-4.9969792,-5.0799999,-4.9786158,-4.8764935,-4.7736244,-4.6700001,-4.7718530,-4.8741355,-4.9768505,-5.0799999,-5.0799999,-5.5799999,-5.5799999,-6.1700001,-5.5000000,-5.4200001,-6,-6,-5.5799999,-6.2500000,-6.6700001,-6.3299999,-5.8299999,-5.7500000,-5.3299999,-5,-4.0799999,-3.1700001,-3,-3.8299999,-4.1700001,-3.4200001,-2.7500000,-1.9200000,-1.8300000,-2.0799999,-2.4200001,-2.8299999,-3.3299999,-2.6700001,-2,-2,-1.6700000,-1.5000000,-1.1700000,-0.50000000,-0.25000000,-0.079999998,0.17000000,0.33000001,0,0.25000000,0.57999998,1,1.5800000,1.8300000,1.5800000,1,0.57999998,1.4200000,0.92000002,0.079999998,-0.67000002,-1.4200000,-2.0799999,-2.8299999,-3.5000000,-3.6700001,-4.5000000,-5.0799999,-5.5799999,NaN,-10.330000,-9.7500000,-9.5000000,-9,-9.5000000,-10,-9.5000000,-10,-9.7500000,-9.0799999,-8.5000000,-8.1700001,-8.6700001,-8.2500000,-7.5000000,-6.7500000,-6.0799999,-5.7500000,-5.5799999,-6.2500000,-6.0799999,-6,-6.1700001,-6.3299999,-7.2500000,-8,-8.7500000,-9.5799999,-10.080000,-10.330000,NaN,8.6700001,9.1700001,9.4200001,9.4200001,9.5000000,9.3299999,9.1700001,8.6700001,8.5799999,8.6700001,NaN,8.1700001,8.4200001,8.7500000,9.2500000,9.6700001,9.7500000,9.7500000,9.6700001,9.5000000,9.0799999,8.7500000,8.3299999,8.4200001,8.4200001,8.1700001,8.1700001,NaN,12.330000,12.750000,13.250000,13.670000,14.250000,15,15.670000,15.330000,15.170000,15.330000,15.170000,14.500000,14.170000,13.670000,13,12.670000,12.330000,NaN,21.080000,21.330000,21.830000,22.330000,22.830000,23.170000,22.670000,22.830000,23.080000,22.670000,22.330000,22.080000,21.670000,21.500000,21.580000,21.080000,NaN,23.500000,23.580000,24.170000,24.250000,24.750000,25.170000,25.750000,25.750000,26.250000,26.170000,25.500000,24.830000,24.500000,24,23.500000,NaN,32.250000,32.750000,33,33.419998,33.919998,34.500000,33.919998,34.080002,33.669998,33.500000,33,32.419998,32.250000,NaN,2.2500000,2.9200001,3.4200001,3.0799999,2.7300000,2.2500000,NaN,27.670000,28.250000,28.080000,27.750000,27.670000,NaN,26.421621,26.329967,26.212252,26.029953,25.900337,25.858942,25.889624,26.303318,26.383131,26.509672,26.421621,NaN,26.000242,25.813082,26.017820,26.178562,26.088400,26.000242,NaN,-28.159765,-28.029388,-28.192963,-28.473545,-28.536633,-28.490150,-28.159765,NaN,-25.254848,-25.789749,-25.825817,-25.813961,-25.488266,-25.234943,-25.167929,-25.254848,NaN,-16.830000,-16.500000,-16.170000,-16.330000,-16.580000,-16.830000,NaN,-15.800000,-15.670000,-15.370000,-15.330000,-15.670000,-15.800000,NaN,-13.738705,-13.787071,-13.766937,-13.541560,-13.428255,-13.412160,-13.738705,NaN,-14.209541,-14.182261,-13.961255,-13.898086,-13.933837,-14.209541,NaN,8.5000000,8.6700001,8.9200001,8.7500000,8.5000000,NaN,115.17000,115.17000,115.58000,115.83000,115.75000,115.83000,115.83000,115.58000,115.42000,115.17000,115,115,114.92000,114.58000,114.17000,114.17000,113.92000,113.50000,113.33000,113.83000,113.50000,113.75000,113.75000,114.17000,114.17000,113.92000,113.67000,113.50000,113.42000,113.83000,113.83000,113.67000,113.83000,114.08000,114.33000,114.58000,115.08000,115.50000,115.83000,116.25000,116.75000,117.25000,117.75000,118.25000,118.75000,119.17000,119.75000,120.33000,120.92000,121.33000,121.67000,121.92000,122.33000,122.33000,122.25000,122.17000,122.58000,123,123.25000,123.50000,123.92000,123.58000,123.75000,124.33000,124.58000,124.67000,125.17000,125.25000,125.92000,126.08000,126.58000,126.83000,127.42000,127.83000,128.17000,128.17000,128.67000,129.08000,129.67000,129.83000,129.33000,129.75000,129.92000,130.42000,130.42000,130.25000,130.50000,131.08000,131.75000,132.42000,132.48259,132.54512,132.60759,132.67000,132.58490,132.49988,132.41490,132.33000,132.49742,132.66490,132.83243,133,133.50000,134.08000,134.67000,135.25000,135.83000,136.08000,136.50000,137,136.67000,136.58000,136,136,136,135.75000,135.58000,136,136.42000,136.58000,137.33000,137.75000,138.08000,138.67000,138.67000,139.17000,139.42000,140,140.50000,141,141,141.25000,141.50000,141.58000,141.67000,141.58000,141.58000,141.67000,141.75000,141.75000,141.75000,142.08000,142.08000,142.42000,142.83000,142.92000,143.08000,143.33000,143.58000,143.58000,143.75000,144.08000,144.58000,144.92000,145.33000,145.33000,145.33000,145.50000,145.50000,145.83000,146.08000,146.17000,146.08000,146.33000,146.42000,147,147.50000,147.83000,148.33000,148.83000,148.83000,149.17000,149.33000,149.50000,149.75000,150,150.42000,150.83000,150.83000,151,151.33000,151.83000,152.17000,152.58000,152.83000,153.08000,153.08000,153.08000,153.17000,153.33000,153.50000,153.67000,153.50000,153.42000,153.33000,153.08000,153.08000,152.92000,152.75000,152.50000,152.25000,151.83000,151.50000,151.33000,151.08000,150.83000,150.58000,150.25000,150.17000,150,150,149.92000,149.42000,148.75000,148.17000,147.83000,147.25000,147.25000,146.83000,146.42000,146,145.58000,145.50000,145,144.83000,144.42000,144,143.50000,143.08000,142.67000,142.25000,141.75000,141.42000,141.17000,140.67000,140.25000,139.92000,139.75000,139.92000,139.67000,139.33000,138.83000,138.17000,138.42000,138.58000,138.42000,138.08000,137.92000,137.92000,137.75000,137.33000,136.92000,137,137.42000,137.50000,137.58000,137.92000,137.83000,137.50000,137.25000,136.75000,136.33000,135.92000,135.67000,135.42000,135.25000,135,134.83000,134.17000,134.33000,133.92000,133.42000,132.83000,132.25000,131.83000,131.33000,130.83000,130.33000,129.67000,129.67000,129.08000,128.58000,128,127.50000,126.92000,126.25000,125.83000,125.25000,124.75000,124.08000,124,123.58000,123.08000,122.58000,121.92000,121.33000,120.75000,120.08000,119.75000,119.42000,119,118.58000,118.33000,117.75000,117.17000,116.67000,116.08000,115.67000,115.17000,NaN,130.08000,130.33000,130.75000,131.33000,131.50000,131,130.67000,130.08000,NaN,136.58000,136.83000,137.42000,138.08000,137.58000,136.83000,136.58000,NaN,144.83000,145.50000,146.17000,146.75000,147.33000,148,148.33000,148.33000,148.33000,148.17000,148,147.92000,147.50000,147.17000,146.83000,146.25000,145.75000,145.50000,145.33000,145.25000,145,144.83000,144.83000,NaN,175.18901,175.52013,175.53358,175.44466,175.48058,175.75864,175.89690,176.01027,177.02853,177.25839,177.42522,177.73706,178.13823,178.46703,178.49715,178.31409,177.83994,177.82748,177.77208,177.24406,177.05565,176.93449,176.94547,177.06219,177.06259,176.70338,175.92203,175.58119,175.27380,174.89191,174.76491,175.12189,175.29733,175.28041,174.80734,173.95357,173.77315,173.80620,174.56561,174.64946,174.60986,174.64391,174.81117,174.82228,174.61176,174.65239,174.60092,174.23610,174.28772,174.11028,173.83867,174.10678,174.12810,174.05267,173.23621,173.23676,173.11743,173.12076,172.98090,172.63596,172.70975,172.80241,173.02428,173.06192,172.99442,173.17114,173.35213,173.35954,173.47733,174.02635,174.07925,174.16315,174.22922,174.31305,174.30292,174.40526,174.62242,174.54584,174.51370,174.55339,174.37411,174.78976,174.80663,174.69916,174.91733,174.60602,174.59598,174.84828,174.79503,175.19966,175.12350,175.18901,NaN,166.50000,166.83000,167.08000,167.58000,167.92000,168.33000,168.83000,169.50000,170,170.50000,171.08000,171.33000,171.50000,172,172.17000,172.17000,172.58000,172.58000,173.08000,173.17000,173.50000,173.83000,173.92000,174.33000,174.33000,174,173.58000,173.25000,172.83000,172.75000,173.08000,172.42000,172,171.42000,171.25000,171.08000,170.92000,170.58000,170.17000,169.67000,169,168.33000,167.83000,167.58000,167.25000,166.75000,166.50000,NaN,167.58000,168,168.25000,167.58000,NaN,95.330002,95.919998,96.330002,96.919998,97.580002,98,98.250000,98.580002,98.580002,99,99.500000,100,100.33000,100.75000,101.25000,101.75000,102.25000,102.67000,103.08000,103,103.42000,103.83000,103.75000,103.50000,103.83000,104.42000,104.58000,104.92000,105.08000,105.58000,105.92000,106.17000,105.92000,105.92000,105.92000,105.83000,105.75000,105.33000,104.92000,104.92000,104.75000,104.42000,104,103.50000,102.83000,102.42000,102.25000,101.75000,101.33000,100.92000,100.83000,100.50000,100.42000,100,99.830002,99.250000,99.080002,98.830002,98.830002,98.330002,97.830002,97.669998,97.250000,96.919998,96.580002,96.080002,95.669998,95.419998,95.330002,NaN,105.50000,105.83000,106.08000,106.67000,107.08000,107.42000,107.92000,108.42000,108.67000,109.08000,109.58000,110.08000,110.50000,110.83000,110.83000,111.33000,111.92000,112.42000,112.75000,112.83000,113.42000,113.92000,114.42000,114.42000,114.42000,114,113.58000,113.08000,112.50000,112,111.50000,111,110.50000,110,109.58000,109,108.58000,108,107.58000,107,106.50000,106.58000,106,105.50000,NaN,115.25000,114.70000,114.66000,115.25000,115.66000,115.25000,NaN,118.02806,117.80023,117.77113,117.78201,117.89159,118.02868,118.20986,118.34115,118.49058,118.53816,118.53801,118.68399,118.82256,118.92444,118.93816,119.01688,119.04507,119.03831,118.89791,118.76206,118.70125,118.73455,118.36439,118.30132,118.34040,118.30289,118.07381,117.94427,117.40164,117.24517,117.11122,116.93965,116.80444,116.77352,116.83315,116.79523,117.07780,117.61865,117.66089,117.91784,117.99767,118.12435,118.14438,118.02806,NaN,123.12189,122.81408,122.82875,122.15325,122.01051,121.81964,121.42661,121.28008,121.14025,120.61040,119.97549,119.87721,119.88632,120.05154,120.36526,120.66817,121.24595,121.42947,121.57211,121.70924,122.08563,122.26042,122.45721,122.42648,122.84325,122.89603,122.85657,122.75675,122.82258,123.02674,123.11948,123.12189,NaN,123.55663,123.37527,123.52563,123.86489,123.88664,123.55663,NaN,116.41458,115.95900,116.12578,116.13262,116.23606,116.44192,116.65556,116.41458,NaN,124.33000,124.50000,124.66745,124.83493,125.00245,125.17000,124.96007,124.75009,124.54007,124.33000,NaN,125.83000,126,126.67000,126.42000,125.83000,NaN,119,119.50000,120,120.50000,120.92000,120.42000,120,119.67000,119.17000,119,NaN,123.50000,123.67000,123.92000,124.33000,124.83000,125.08000,125.67000,126.25000,126.75000,127.25000,126.92000,126.42000,125.92000,125.42000,124.92000,124.50000,124,123.50000,NaN,131.17000,131.25000,131.58000,131.58000,131.17000,NaN,134.08000,134.08000,134.25000,134.50000,134.67000,134.50000,134.08000,NaN,105.25000,105.50000,106,106.25000,106.42000,106.75000,106.67000,106,106,105.75000,105.25000,NaN,107.67000,107.75000,108.33000,108.08000,107.67000,NaN,113.05882,112.93040,112.83998,113.00318,113.14203,113.79539,113.95089,113.63936,113.05882,NaN,108.92000,109.08000,109.50000,110,110.58000,111.08000,111.33000,111.50000,112,112.58000,113.08000,113.33000,113.75000,113.75000,114.25000,114.75000,115.42000,115.42000,116,116.17000,116.67000,117,117.25000,117.75000,117.75000,118.25000,118.75000,119.25000,118.75000,118.25000,118.58000,117.92000,117.83000,117.50000,117.75000,118.08000,117.83000,118.25000,118.67000,119,118.42000,117.92000,117.67000,117.50000,117.50000,117.42000,117.17000,116.75000,116.33000,116.67000,116.33000,116.17000,115.67000,115.17000,114.75000,114.67000,114.33000,113.83000,113.25000,112.83000,112.33000,111.83000,111.75000,111.42000,110.92000,110.33000,110.25000,110.08000,110.08000,109.75000,109.25000,109.25000,109,108.92000,NaN,118.83000,119.17000,119.33000,119.33000,119.50000,119.83000,119.83000,119.92000,120,120.67000,120.92000,121.42000,122,122.50000,122.92000,123.33000,123.92000,124.42000,124.75000,125,125,125.25000,125,124.58000,124,123.50000,123,122.50000,122,121.42000,121,120.67000,120.33000,120.08000,120.08000,120.58000,120.67000,121.17000,121.58000,122.08000,122.58000,123.17000,123.50000,122.92000,122.50000,122.08000,121.50000,121.92000,122.17000,122.42000,122.08000,122.08000,122.50000,122.83000,123.17000,123.17000,122.67000,122.33000,122.33000,122,121.58000,121.67000,121.17000,120.92000,121.08000,121.08000,120.67000,120.25000,120.42000,120.42000,120.42000,120.33000,120.42000,119.92000,119.50000,119.42000,119.58000,119.67000,119.50000,119,118.83000,NaN,127.33000,127.50000,127.58000,128,127.83000,128.08000,128.67000,128.67000,128.25000,128.50000,128,127.92000,128,128.42000,127.92000,127.58000,127.67000,127.58000,127.51750,127.45501,127.39250,127.33000,NaN,126,126.50000,127,127.17000,126.83000,126.33000,126,NaN,127.92000,128.25000,128.92000,129.50000,129.92000,130.42000,130.75000,130.75000,130.25000,129.42000,128.92000,128.50000,127.92000,NaN,124.61553,124.50847,124.54877,124.70154,125.19090,125.37168,124.61553,NaN,127.33000,127.58000,128.17000,127.96000,127.75000,127.54000,127.33000,NaN,130.33000,130.75000,131.25000,130.75000,130.33000,NaN,135.33000,135.92000,136.25000,135.83000,135.33000,NaN,130.83000,131.25000,131.25000,131.83000,132.17000,132.83000,133.25000,133.92000,134.17000,134,134.17000,134.58000,134.75000,135.17000,135.58000,135.83000,136.08000,136.50000,137,137.25000,137.92000,138.42000,139,139.50000,140,140.42000,141,141.50000,142,142.42000,143,143.50000,144,144,144.50000,145,145.42000,145.75000,145.75000,146.25000,146.83000,147.42000,147.83000,147.83000,147.42000,147,147.17000,147.67000,148.17000,148.25000,148.58000,149.25000,149.08000,149.58000,149.68500,149.78999,149.89500,150,149.93755,149.87506,149.81255,149.75000,149.85497,149.95995,150.06496,150.17000,150.75000,150.58000,150,149.75000,149.25000,148.67000,148.08000,148.08000,147.58000,147.42000,147,146.50000,146.25000,146,145.58000,145,144.67000,144.17000,143.83000,143.58000,143.17000,143.33000,143.17000,142.58000,142,141.50000,141,140.58000,140.25000,140,139.42000,138.83000,138.25000,137.67000,138,138.25000,138.75000,138.58000,138.58000,138.42000,138.17000,137.83000,137.33000,136.75000,136.17000,135.58000,135,134.58000,134.08000,133.67000,133.25000,132.83000,132.75000,132.67000,132.25000,131.92000,132.17000,132.67000,133.08000,133.67000,133.83000,133.25000,132.75000,132.25000,131.83000,131.83000,131.42000,130.83000,NaN,119.83000,120.33000,120.33000,120.50000,120.33000,120.50000,120.67000,121.08000,121.50000,121.92000,122.33000,122.17000,122.17000,122.25262,122.33515,122.41761,122.50000,122.45741,122.41489,122.37241,122.33000,122,121.58000,121.58000,121.42000,121.67000,121.83000,122.25000,122.58000,122.92000,123.33000,123.92000,123.58000,123.75000,124.17000,123.83000,123.42000,123.08000,122.58000,122.67000,122.67000,122.17000,121.75000,121.25000,120.67000,120.67000,121,120.67000,120.58000,120.08000,120,119.92000,119.83000,NaN,117.25000,117.50000,117.92000,118.42000,118.75000,119.17000,119.50000,119.67000,119.17000,118.83000,118.58000,118.17000,117.92000,117.25000,NaN,120.42000,120.83000,121.25000,121.58000,121.58000,121.17000,120.92000,120.75000,120.42000,NaN,124.33000,124.75000,125.25000,125.50000,125.50000,125.67000,125,125,125.25000,124.75000,124.75000,124.42000,124.42000,124.83000,124.87245,124.91494,124.95745,125,124.87508,124.75011,124.62508,124.50000,124.33000,NaN,121.92000,122,122.08000,121.92000,122.50000,122.58000,123.17000,123.08000,123.50000,123.42000,123.83000,124,124,124,124.50000,124.50000,124,123.75000,123.50000,123.17000,123.33000,123,122.67000,122.60756,122.54507,122.48256,122.42000,122.52244,122.62492,122.72744,122.83000,122.83000,122.50000,121.92000,NaN,122,122.08000,122.33000,122.83000,123.08000,123.50000,123.83000,123.92000,124.25000,124.67000,124.83000,125.17000,125.50000,125.42000,125.42000,126,126.33000,126.33000,126.58000,126.58000,126.33000,126.17000,126,125.75000,125.50000,125.33000,125.58000,125.75000,125.42000,125.08000,124.75000,124.33000,124,124,124.25000,124,123.58000,123.25000,122.92000,122.83000,122.50000,122.25000,122.08000,122,NaN,148.25000,148.83000,149.42000,150,150.42000,150.83000,151.25000,151.67000,151.50000,152.25000,152.42000,152.08000,152,151.58000,151.17000,150.67000,150.17000,149.67000,149.17000,148.83000,148.33000,148.25000,NaN,147.19809,146.71855,146.59590,146.75699,147.09242,147.36635,147.19809,NaN,152.46805,153.06102,153.09235,153.04886,152.95467,152.88103,152.72334,152.72090,152.46805,NaN,152.02249,151.93800,151.30389,151.07172,151.14638,151.62180,152.06683,152.08412,152.02249,NaN,154.67000,155.08000,155.58000,156,155.50000,155.17000,154.83000,154.67000,NaN,157.40843,157.30496,157.03313,156.48753,156.47874,156.88623,157.13939,157.40843,NaN,157.84911,157.69815,157.55157,157.46236,157.30003,157.36214,157.43719,157.56998,157.88452,157.84911,NaN,159.78310,158.72592,158.55373,158.60579,159.16772,159.74144,159.83916,159.78310,NaN,161.28508,160.88991,160.83386,160.66780,160.67760,160.80261,160.90369,161.28508,NaN,159.50000,160.25000,160.83000,160.50000,160.08000,159.67000,159.42000,159.50000,NaN,161.25000,162,162.33000,161.75000,161.25000,NaN,166.77623,166.55884,166.57800,166.71307,166.84460,166.98627,167.06303,167.23775,167.20045,166.91267,166.77623,NaN,167.33000,167.92000,167.50000,167.33000,NaN,164.25000,164.75000,165.33000,165.67000,166,166.50000,166.83000,167.17000,166.67000,166.17000,165.75000,165.42000,165,164.58000,164.25000,NaN,-176.83000,-176.17000,-176.58000,-176.50000,-176.83000,NaN,177.33000,177.42000,177.75000,178.25000,178.67000,178.67000,178.17000,177.75000,177.33000,NaN,178.58000,179.17000,179.83000,179.67000,179.92000,179.33000,178.75000,178.58000,NaN,-149.58000,-149.33000,-149.17000,-149.50000,-149.58000,NaN,-159.82001,-159.58000,-159.30000,-159.38000,-159.62000,-159.82001,NaN,-158.28000,-157.98000,-157.67000,-158.12000,-158.28000,NaN,-157.21269,-156.71635,-156.85754,-157.30046,-157.21269,NaN,-156.67999,-156.47000,-156.28000,-155.98000,-156.20000,-156.42999,-156.47000,-156.67999,NaN,-155.88000,-155.63000,-155.37000,-155.13000,-155.02000,-154.80000,-155,-155.30000,-155.52000,-155.64999,-155.92000,-155.88000,-156.05000,-155.87000,-155.88000];
end
